# -*- coding: utf-8 -*-
#
# NOTE: This file was auto-generated with MetaTools/buildUCD.py.
# Source: https://unicode.org/Public/UNIDATA/Scripts.txt
# License: http://unicode.org/copyright.html#License
#
# Scripts-17.0.0.txt
# Date: 2025-07-24, 13:28:55 GMT
# © 2025 Unicode®, Inc.
# Unicode and the Unicode Logo are registered trademarks of Unicode, Inc. in the U.S. and other countries.
# For terms of use and license, see https://www.unicode.org/terms_of_use.html
#
# Unicode Character Database
#   For documentation, see https://www.unicode.org/reports/tr44/
# For more information, see:
#   UAX #24, Unicode Script Property: https://www.unicode.org/reports/tr24/
#     Especially the sections:
#       https://www.unicode.org/reports/tr24/#Assignment_Script_Values
#       https://www.unicode.org/reports/tr24/#Assignment_ScriptX_Values
#

RANGES = [
    0x0000,  # .. 0x0040 ; Common
    0x0041,  # .. 0x005A ; Latin
    0x005B,  # .. 0x0060 ; Common
    0x0061,  # .. 0x007A ; Latin
    0x007B,  # .. 0x00A9 ; Common
    0x00AA,  # .. 0x00AA ; Latin
    0x00AB,  # .. 0x00B9 ; Common
    0x00BA,  # .. 0x00BA ; Latin
    0x00BB,  # .. 0x00BF ; Common
    0x00C0,  # .. 0x00D6 ; Latin
    0x00D7,  # .. 0x00D7 ; Common
    0x00D8,  # .. 0x00F6 ; Latin
    0x00F7,  # .. 0x00F7 ; Common
    0x00F8,  # .. 0x02B8 ; Latin
    0x02B9,  # .. 0x02DF ; Common
    0x02E0,  # .. 0x02E4 ; Latin
    0x02E5,  # .. 0x02E9 ; Common
    0x02EA,  # .. 0x02EB ; Bopomofo
    0x02EC,  # .. 0x02FF ; Common
    0x0300,  # .. 0x036F ; Inherited
    0x0370,  # .. 0x0373 ; Greek
    0x0374,  # .. 0x0374 ; Common
    0x0375,  # .. 0x0377 ; Greek
    0x0378,  # .. 0x0379 ; Unknown
    0x037A,  # .. 0x037D ; Greek
    0x037E,  # .. 0x037E ; Common
    0x037F,  # .. 0x037F ; Greek
    0x0380,  # .. 0x0383 ; Unknown
    0x0384,  # .. 0x0384 ; Greek
    0x0385,  # .. 0x0385 ; Common
    0x0386,  # .. 0x0386 ; Greek
    0x0387,  # .. 0x0387 ; Common
    0x0388,  # .. 0x038A ; Greek
    0x038B,  # .. 0x038B ; Unknown
    0x038C,  # .. 0x038C ; Greek
    0x038D,  # .. 0x038D ; Unknown
    0x038E,  # .. 0x03A1 ; Greek
    0x03A2,  # .. 0x03A2 ; Unknown
    0x03A3,  # .. 0x03E1 ; Greek
    0x03E2,  # .. 0x03EF ; Coptic
    0x03F0,  # .. 0x03FF ; Greek
    0x0400,  # .. 0x0484 ; Cyrillic
    0x0485,  # .. 0x0486 ; Inherited
    0x0487,  # .. 0x052F ; Cyrillic
    0x0530,  # .. 0x0530 ; Unknown
    0x0531,  # .. 0x0556 ; Armenian
    0x0557,  # .. 0x0558 ; Unknown
    0x0559,  # .. 0x058A ; Armenian
    0x058B,  # .. 0x058C ; Unknown
    0x058D,  # .. 0x058F ; Armenian
    0x0590,  # .. 0x0590 ; Unknown
    0x0591,  # .. 0x05C7 ; Hebrew
    0x05C8,  # .. 0x05CF ; Unknown
    0x05D0,  # .. 0x05EA ; Hebrew
    0x05EB,  # .. 0x05EE ; Unknown
    0x05EF,  # .. 0x05F4 ; Hebrew
    0x05F5,  # .. 0x05FF ; Unknown
    0x0600,  # .. 0x0604 ; Arabic
    0x0605,  # .. 0x0605 ; Common
    0x0606,  # .. 0x060B ; Arabic
    0x060C,  # .. 0x060C ; Common
    0x060D,  # .. 0x061A ; Arabic
    0x061B,  # .. 0x061B ; Common
    0x061C,  # .. 0x061E ; Arabic
    0x061F,  # .. 0x061F ; Common
    0x0620,  # .. 0x063F ; Arabic
    0x0640,  # .. 0x0640 ; Common
    0x0641,  # .. 0x064A ; Arabic
    0x064B,  # .. 0x0655 ; Inherited
    0x0656,  # .. 0x066F ; Arabic
    0x0670,  # .. 0x0670 ; Inherited
    0x0671,  # .. 0x06DC ; Arabic
    0x06DD,  # .. 0x06DD ; Common
    0x06DE,  # .. 0x06FF ; Arabic
    0x0700,  # .. 0x070D ; Syriac
    0x070E,  # .. 0x070E ; Unknown
    0x070F,  # .. 0x074A ; Syriac
    0x074B,  # .. 0x074C ; Unknown
    0x074D,  # .. 0x074F ; Syriac
    0x0750,  # .. 0x077F ; Arabic
    0x0780,  # .. 0x07B1 ; Thaana
    0x07B2,  # .. 0x07BF ; Unknown
    0x07C0,  # .. 0x07FA ; Nko
    0x07FB,  # .. 0x07FC ; Unknown
    0x07FD,  # .. 0x07FF ; Nko
    0x0800,  # .. 0x082D ; Samaritan
    0x082E,  # .. 0x082F ; Unknown
    0x0830,  # .. 0x083E ; Samaritan
    0x083F,  # .. 0x083F ; Unknown
    0x0840,  # .. 0x085B ; Mandaic
    0x085C,  # .. 0x085D ; Unknown
    0x085E,  # .. 0x085E ; Mandaic
    0x085F,  # .. 0x085F ; Unknown
    0x0860,  # .. 0x086A ; Syriac
    0x086B,  # .. 0x086F ; Unknown
    0x0870,  # .. 0x0891 ; Arabic
    0x0892,  # .. 0x0896 ; Unknown
    0x0897,  # .. 0x08E1 ; Arabic
    0x08E2,  # .. 0x08E2 ; Common
    0x08E3,  # .. 0x08FF ; Arabic
    0x0900,  # .. 0x0950 ; Devanagari
    0x0951,  # .. 0x0954 ; Inherited
    0x0955,  # .. 0x0963 ; Devanagari
    0x0964,  # .. 0x0965 ; Common
    0x0966,  # .. 0x097F ; Devanagari
    0x0980,  # .. 0x0983 ; Bengali
    0x0984,  # .. 0x0984 ; Unknown
    0x0985,  # .. 0x098C ; Bengali
    0x098D,  # .. 0x098E ; Unknown
    0x098F,  # .. 0x0990 ; Bengali
    0x0991,  # .. 0x0992 ; Unknown
    0x0993,  # .. 0x09A8 ; Bengali
    0x09A9,  # .. 0x09A9 ; Unknown
    0x09AA,  # .. 0x09B0 ; Bengali
    0x09B1,  # .. 0x09B1 ; Unknown
    0x09B2,  # .. 0x09B2 ; Bengali
    0x09B3,  # .. 0x09B5 ; Unknown
    0x09B6,  # .. 0x09B9 ; Bengali
    0x09BA,  # .. 0x09BB ; Unknown
    0x09BC,  # .. 0x09C4 ; Bengali
    0x09C5,  # .. 0x09C6 ; Unknown
    0x09C7,  # .. 0x09C8 ; Bengali
    0x09C9,  # .. 0x09CA ; Unknown
    0x09CB,  # .. 0x09CE ; Bengali
    0x09CF,  # .. 0x09D6 ; Unknown
    0x09D7,  # .. 0x09D7 ; Bengali
    0x09D8,  # .. 0x09DB ; Unknown
    0x09DC,  # .. 0x09DD ; Bengali
    0x09DE,  # .. 0x09DE ; Unknown
    0x09DF,  # .. 0x09E3 ; Bengali
    0x09E4,  # .. 0x09E5 ; Unknown
    0x09E6,  # .. 0x09FE ; Bengali
    0x09FF,  # .. 0x0A00 ; Unknown
    0x0A01,  # .. 0x0A03 ; Gurmukhi
    0x0A04,  # .. 0x0A04 ; Unknown
    0x0A05,  # .. 0x0A0A ; Gurmukhi
    0x0A0B,  # .. 0x0A0E ; Unknown
    0x0A0F,  # .. 0x0A10 ; Gurmukhi
    0x0A11,  # .. 0x0A12 ; Unknown
    0x0A13,  # .. 0x0A28 ; Gurmukhi
    0x0A29,  # .. 0x0A29 ; Unknown
    0x0A2A,  # .. 0x0A30 ; Gurmukhi
    0x0A31,  # .. 0x0A31 ; Unknown
    0x0A32,  # .. 0x0A33 ; Gurmukhi
    0x0A34,  # .. 0x0A34 ; Unknown
    0x0A35,  # .. 0x0A36 ; Gurmukhi
    0x0A37,  # .. 0x0A37 ; Unknown
    0x0A38,  # .. 0x0A39 ; Gurmukhi
    0x0A3A,  # .. 0x0A3B ; Unknown
    0x0A3C,  # .. 0x0A3C ; Gurmukhi
    0x0A3D,  # .. 0x0A3D ; Unknown
    0x0A3E,  # .. 0x0A42 ; Gurmukhi
    0x0A43,  # .. 0x0A46 ; Unknown
    0x0A47,  # .. 0x0A48 ; Gurmukhi
    0x0A49,  # .. 0x0A4A ; Unknown
    0x0A4B,  # .. 0x0A4D ; Gurmukhi
    0x0A4E,  # .. 0x0A50 ; Unknown
    0x0A51,  # .. 0x0A51 ; Gurmukhi
    0x0A52,  # .. 0x0A58 ; Unknown
    0x0A59,  # .. 0x0A5C ; Gurmukhi
    0x0A5D,  # .. 0x0A5D ; Unknown
    0x0A5E,  # .. 0x0A5E ; Gurmukhi
    0x0A5F,  # .. 0x0A65 ; Unknown
    0x0A66,  # .. 0x0A76 ; Gurmukhi
    0x0A77,  # .. 0x0A80 ; Unknown
    0x0A81,  # .. 0x0A83 ; Gujarati
    0x0A84,  # .. 0x0A84 ; Unknown
    0x0A85,  # .. 0x0A8D ; Gujarati
    0x0A8E,  # .. 0x0A8E ; Unknown
    0x0A8F,  # .. 0x0A91 ; Gujarati
    0x0A92,  # .. 0x0A92 ; Unknown
    0x0A93,  # .. 0x0AA8 ; Gujarati
    0x0AA9,  # .. 0x0AA9 ; Unknown
    0x0AAA,  # .. 0x0AB0 ; Gujarati
    0x0AB1,  # .. 0x0AB1 ; Unknown
    0x0AB2,  # .. 0x0AB3 ; Gujarati
    0x0AB4,  # .. 0x0AB4 ; Unknown
    0x0AB5,  # .. 0x0AB9 ; Gujarati
    0x0ABA,  # .. 0x0ABB ; Unknown
    0x0ABC,  # .. 0x0AC5 ; Gujarati
    0x0AC6,  # .. 0x0AC6 ; Unknown
    0x0AC7,  # .. 0x0AC9 ; Gujarati
    0x0ACA,  # .. 0x0ACA ; Unknown
    0x0ACB,  # .. 0x0ACD ; Gujarati
    0x0ACE,  # .. 0x0ACF ; Unknown
    0x0AD0,  # .. 0x0AD0 ; Gujarati
    0x0AD1,  # .. 0x0ADF ; Unknown
    0x0AE0,  # .. 0x0AE3 ; Gujarati
    0x0AE4,  # .. 0x0AE5 ; Unknown
    0x0AE6,  # .. 0x0AF1 ; Gujarati
    0x0AF2,  # .. 0x0AF8 ; Unknown
    0x0AF9,  # .. 0x0AFF ; Gujarati
    0x0B00,  # .. 0x0B00 ; Unknown
    0x0B01,  # .. 0x0B03 ; Oriya
    0x0B04,  # .. 0x0B04 ; Unknown
    0x0B05,  # .. 0x0B0C ; Oriya
    0x0B0D,  # .. 0x0B0E ; Unknown
    0x0B0F,  # .. 0x0B10 ; Oriya
    0x0B11,  # .. 0x0B12 ; Unknown
    0x0B13,  # .. 0x0B28 ; Oriya
    0x0B29,  # .. 0x0B29 ; Unknown
    0x0B2A,  # .. 0x0B30 ; Oriya
    0x0B31,  # .. 0x0B31 ; Unknown
    0x0B32,  # .. 0x0B33 ; Oriya
    0x0B34,  # .. 0x0B34 ; Unknown
    0x0B35,  # .. 0x0B39 ; Oriya
    0x0B3A,  # .. 0x0B3B ; Unknown
    0x0B3C,  # .. 0x0B44 ; Oriya
    0x0B45,  # .. 0x0B46 ; Unknown
    0x0B47,  # .. 0x0B48 ; Oriya
    0x0B49,  # .. 0x0B4A ; Unknown
    0x0B4B,  # .. 0x0B4D ; Oriya
    0x0B4E,  # .. 0x0B54 ; Unknown
    0x0B55,  # .. 0x0B57 ; Oriya
    0x0B58,  # .. 0x0B5B ; Unknown
    0x0B5C,  # .. 0x0B5D ; Oriya
    0x0B5E,  # .. 0x0B5E ; Unknown
    0x0B5F,  # .. 0x0B63 ; Oriya
    0x0B64,  # .. 0x0B65 ; Unknown
    0x0B66,  # .. 0x0B77 ; Oriya
    0x0B78,  # .. 0x0B81 ; Unknown
    0x0B82,  # .. 0x0B83 ; Tamil
    0x0B84,  # .. 0x0B84 ; Unknown
    0x0B85,  # .. 0x0B8A ; Tamil
    0x0B8B,  # .. 0x0B8D ; Unknown
    0x0B8E,  # .. 0x0B90 ; Tamil
    0x0B91,  # .. 0x0B91 ; Unknown
    0x0B92,  # .. 0x0B95 ; Tamil
    0x0B96,  # .. 0x0B98 ; Unknown
    0x0B99,  # .. 0x0B9A ; Tamil
    0x0B9B,  # .. 0x0B9B ; Unknown
    0x0B9C,  # .. 0x0B9C ; Tamil
    0x0B9D,  # .. 0x0B9D ; Unknown
    0x0B9E,  # .. 0x0B9F ; Tamil
    0x0BA0,  # .. 0x0BA2 ; Unknown
    0x0BA3,  # .. 0x0BA4 ; Tamil
    0x0BA5,  # .. 0x0BA7 ; Unknown
    0x0BA8,  # .. 0x0BAA ; Tamil
    0x0BAB,  # .. 0x0BAD ; Unknown
    0x0BAE,  # .. 0x0BB9 ; Tamil
    0x0BBA,  # .. 0x0BBD ; Unknown
    0x0BBE,  # .. 0x0BC2 ; Tamil
    0x0BC3,  # .. 0x0BC5 ; Unknown
    0x0BC6,  # .. 0x0BC8 ; Tamil
    0x0BC9,  # .. 0x0BC9 ; Unknown
    0x0BCA,  # .. 0x0BCD ; Tamil
    0x0BCE,  # .. 0x0BCF ; Unknown
    0x0BD0,  # .. 0x0BD0 ; Tamil
    0x0BD1,  # .. 0x0BD6 ; Unknown
    0x0BD7,  # .. 0x0BD7 ; Tamil
    0x0BD8,  # .. 0x0BE5 ; Unknown
    0x0BE6,  # .. 0x0BFA ; Tamil
    0x0BFB,  # .. 0x0BFF ; Unknown
    0x0C00,  # .. 0x0C0C ; Telugu
    0x0C0D,  # .. 0x0C0D ; Unknown
    0x0C0E,  # .. 0x0C10 ; Telugu
    0x0C11,  # .. 0x0C11 ; Unknown
    0x0C12,  # .. 0x0C28 ; Telugu
    0x0C29,  # .. 0x0C29 ; Unknown
    0x0C2A,  # .. 0x0C39 ; Telugu
    0x0C3A,  # .. 0x0C3B ; Unknown
    0x0C3C,  # .. 0x0C44 ; Telugu
    0x0C45,  # .. 0x0C45 ; Unknown
    0x0C46,  # .. 0x0C48 ; Telugu
    0x0C49,  # .. 0x0C49 ; Unknown
    0x0C4A,  # .. 0x0C4D ; Telugu
    0x0C4E,  # .. 0x0C54 ; Unknown
    0x0C55,  # .. 0x0C56 ; Telugu
    0x0C57,  # .. 0x0C57 ; Unknown
    0x0C58,  # .. 0x0C5A ; Telugu
    0x0C5B,  # .. 0x0C5B ; Unknown
    0x0C5C,  # .. 0x0C5D ; Telugu
    0x0C5E,  # .. 0x0C5F ; Unknown
    0x0C60,  # .. 0x0C63 ; Telugu
    0x0C64,  # .. 0x0C65 ; Unknown
    0x0C66,  # .. 0x0C6F ; Telugu
    0x0C70,  # .. 0x0C76 ; Unknown
    0x0C77,  # .. 0x0C7F ; Telugu
    0x0C80,  # .. 0x0C8C ; Kannada
    0x0C8D,  # .. 0x0C8D ; Unknown
    0x0C8E,  # .. 0x0C90 ; Kannada
    0x0C91,  # .. 0x0C91 ; Unknown
    0x0C92,  # .. 0x0CA8 ; Kannada
    0x0CA9,  # .. 0x0CA9 ; Unknown
    0x0CAA,  # .. 0x0CB3 ; Kannada
    0x0CB4,  # .. 0x0CB4 ; Unknown
    0x0CB5,  # .. 0x0CB9 ; Kannada
    0x0CBA,  # .. 0x0CBB ; Unknown
    0x0CBC,  # .. 0x0CC4 ; Kannada
    0x0CC5,  # .. 0x0CC5 ; Unknown
    0x0CC6,  # .. 0x0CC8 ; Kannada
    0x0CC9,  # .. 0x0CC9 ; Unknown
    0x0CCA,  # .. 0x0CCD ; Kannada
    0x0CCE,  # .. 0x0CD4 ; Unknown
    0x0CD5,  # .. 0x0CD6 ; Kannada
    0x0CD7,  # .. 0x0CDB ; Unknown
    0x0CDC,  # .. 0x0CDE ; Kannada
    0x0CDF,  # .. 0x0CDF ; Unknown
    0x0CE0,  # .. 0x0CE3 ; Kannada
    0x0CE4,  # .. 0x0CE5 ; Unknown
    0x0CE6,  # .. 0x0CEF ; Kannada
    0x0CF0,  # .. 0x0CF0 ; Unknown
    0x0CF1,  # .. 0x0CF3 ; Kannada
    0x0CF4,  # .. 0x0CFF ; Unknown
    0x0D00,  # .. 0x0D0C ; Malayalam
    0x0D0D,  # .. 0x0D0D ; Unknown
    0x0D0E,  # .. 0x0D10 ; Malayalam
    0x0D11,  # .. 0x0D11 ; Unknown
    0x0D12,  # .. 0x0D44 ; Malayalam
    0x0D45,  # .. 0x0D45 ; Unknown
    0x0D46,  # .. 0x0D48 ; Malayalam
    0x0D49,  # .. 0x0D49 ; Unknown
    0x0D4A,  # .. 0x0D4F ; Malayalam
    0x0D50,  # .. 0x0D53 ; Unknown
    0x0D54,  # .. 0x0D63 ; Malayalam
    0x0D64,  # .. 0x0D65 ; Unknown
    0x0D66,  # .. 0x0D7F ; Malayalam
    0x0D80,  # .. 0x0D80 ; Unknown
    0x0D81,  # .. 0x0D83 ; Sinhala
    0x0D84,  # .. 0x0D84 ; Unknown
    0x0D85,  # .. 0x0D96 ; Sinhala
    0x0D97,  # .. 0x0D99 ; Unknown
    0x0D9A,  # .. 0x0DB1 ; Sinhala
    0x0DB2,  # .. 0x0DB2 ; Unknown
    0x0DB3,  # .. 0x0DBB ; Sinhala
    0x0DBC,  # .. 0x0DBC ; Unknown
    0x0DBD,  # .. 0x0DBD ; Sinhala
    0x0DBE,  # .. 0x0DBF ; Unknown
    0x0DC0,  # .. 0x0DC6 ; Sinhala
    0x0DC7,  # .. 0x0DC9 ; Unknown
    0x0DCA,  # .. 0x0DCA ; Sinhala
    0x0DCB,  # .. 0x0DCE ; Unknown
    0x0DCF,  # .. 0x0DD4 ; Sinhala
    0x0DD5,  # .. 0x0DD5 ; Unknown
    0x0DD6,  # .. 0x0DD6 ; Sinhala
    0x0DD7,  # .. 0x0DD7 ; Unknown
    0x0DD8,  # .. 0x0DDF ; Sinhala
    0x0DE0,  # .. 0x0DE5 ; Unknown
    0x0DE6,  # .. 0x0DEF ; Sinhala
    0x0DF0,  # .. 0x0DF1 ; Unknown
    0x0DF2,  # .. 0x0DF4 ; Sinhala
    0x0DF5,  # .. 0x0E00 ; Unknown
    0x0E01,  # .. 0x0E3A ; Thai
    0x0E3B,  # .. 0x0E3E ; Unknown
    0x0E3F,  # .. 0x0E3F ; Common
    0x0E40,  # .. 0x0E5B ; Thai
    0x0E5C,  # .. 0x0E80 ; Unknown
    0x0E81,  # .. 0x0E82 ; Lao
    0x0E83,  # .. 0x0E83 ; Unknown
    0x0E84,  # .. 0x0E84 ; Lao
    0x0E85,  # .. 0x0E85 ; Unknown
    0x0E86,  # .. 0x0E8A ; Lao
    0x0E8B,  # .. 0x0E8B ; Unknown
    0x0E8C,  # .. 0x0EA3 ; Lao
    0x0EA4,  # .. 0x0EA4 ; Unknown
    0x0EA5,  # .. 0x0EA5 ; Lao
    0x0EA6,  # .. 0x0EA6 ; Unknown
    0x0EA7,  # .. 0x0EBD ; Lao
    0x0EBE,  # .. 0x0EBF ; Unknown
    0x0EC0,  # .. 0x0EC4 ; Lao
    0x0EC5,  # .. 0x0EC5 ; Unknown
    0x0EC6,  # .. 0x0EC6 ; Lao
    0x0EC7,  # .. 0x0EC7 ; Unknown
    0x0EC8,  # .. 0x0ECE ; Lao
    0x0ECF,  # .. 0x0ECF ; Unknown
    0x0ED0,  # .. 0x0ED9 ; Lao
    0x0EDA,  # .. 0x0EDB ; Unknown
    0x0EDC,  # .. 0x0EDF ; Lao
    0x0EE0,  # .. 0x0EFF ; Unknown
    0x0F00,  # .. 0x0F47 ; Tibetan
    0x0F48,  # .. 0x0F48 ; Unknown
    0x0F49,  # .. 0x0F6C ; Tibetan
    0x0F6D,  # .. 0x0F70 ; Unknown
    0x0F71,  # .. 0x0F97 ; Tibetan
    0x0F98,  # .. 0x0F98 ; Unknown
    0x0F99,  # .. 0x0FBC ; Tibetan
    0x0FBD,  # .. 0x0FBD ; Unknown
    0x0FBE,  # .. 0x0FCC ; Tibetan
    0x0FCD,  # .. 0x0FCD ; Unknown
    0x0FCE,  # .. 0x0FD4 ; Tibetan
    0x0FD5,  # .. 0x0FD8 ; Common
    0x0FD9,  # .. 0x0FDA ; Tibetan
    0x0FDB,  # .. 0x0FFF ; Unknown
    0x1000,  # .. 0x109F ; Myanmar
    0x10A0,  # .. 0x10C5 ; Georgian
    0x10C6,  # .. 0x10C6 ; Unknown
    0x10C7,  # .. 0x10C7 ; Georgian
    0x10C8,  # .. 0x10CC ; Unknown
    0x10CD,  # .. 0x10CD ; Georgian
    0x10CE,  # .. 0x10CF ; Unknown
    0x10D0,  # .. 0x10FA ; Georgian
    0x10FB,  # .. 0x10FB ; Common
    0x10FC,  # .. 0x10FF ; Georgian
    0x1100,  # .. 0x11FF ; Hangul
    0x1200,  # .. 0x1248 ; Ethiopic
    0x1249,  # .. 0x1249 ; Unknown
    0x124A,  # .. 0x124D ; Ethiopic
    0x124E,  # .. 0x124F ; Unknown
    0x1250,  # .. 0x1256 ; Ethiopic
    0x1257,  # .. 0x1257 ; Unknown
    0x1258,  # .. 0x1258 ; Ethiopic
    0x1259,  # .. 0x1259 ; Unknown
    0x125A,  # .. 0x125D ; Ethiopic
    0x125E,  # .. 0x125F ; Unknown
    0x1260,  # .. 0x1288 ; Ethiopic
    0x1289,  # .. 0x1289 ; Unknown
    0x128A,  # .. 0x128D ; Ethiopic
    0x128E,  # .. 0x128F ; Unknown
    0x1290,  # .. 0x12B0 ; Ethiopic
    0x12B1,  # .. 0x12B1 ; Unknown
    0x12B2,  # .. 0x12B5 ; Ethiopic
    0x12B6,  # .. 0x12B7 ; Unknown
    0x12B8,  # .. 0x12BE ; Ethiopic
    0x12BF,  # .. 0x12BF ; Unknown
    0x12C0,  # .. 0x12C0 ; Ethiopic
    0x12C1,  # .. 0x12C1 ; Unknown
    0x12C2,  # .. 0x12C5 ; Ethiopic
    0x12C6,  # .. 0x12C7 ; Unknown
    0x12C8,  # .. 0x12D6 ; Ethiopic
    0x12D7,  # .. 0x12D7 ; Unknown
    0x12D8,  # .. 0x1310 ; Ethiopic
    0x1311,  # .. 0x1311 ; Unknown
    0x1312,  # .. 0x1315 ; Ethiopic
    0x1316,  # .. 0x1317 ; Unknown
    0x1318,  # .. 0x135A ; Ethiopic
    0x135B,  # .. 0x135C ; Unknown
    0x135D,  # .. 0x137C ; Ethiopic
    0x137D,  # .. 0x137F ; Unknown
    0x1380,  # .. 0x1399 ; Ethiopic
    0x139A,  # .. 0x139F ; Unknown
    0x13A0,  # .. 0x13F5 ; Cherokee
    0x13F6,  # .. 0x13F7 ; Unknown
    0x13F8,  # .. 0x13FD ; Cherokee
    0x13FE,  # .. 0x13FF ; Unknown
    0x1400,  # .. 0x167F ; Canadian_Aboriginal
    0x1680,  # .. 0x169C ; Ogham
    0x169D,  # .. 0x169F ; Unknown
    0x16A0,  # .. 0x16EA ; Runic
    0x16EB,  # .. 0x16ED ; Common
    0x16EE,  # .. 0x16F8 ; Runic
    0x16F9,  # .. 0x16FF ; Unknown
    0x1700,  # .. 0x1715 ; Tagalog
    0x1716,  # .. 0x171E ; Unknown
    0x171F,  # .. 0x171F ; Tagalog
    0x1720,  # .. 0x1734 ; Hanunoo
    0x1735,  # .. 0x1736 ; Common
    0x1737,  # .. 0x173F ; Unknown
    0x1740,  # .. 0x1753 ; Buhid
    0x1754,  # .. 0x175F ; Unknown
    0x1760,  # .. 0x176C ; Tagbanwa
    0x176D,  # .. 0x176D ; Unknown
    0x176E,  # .. 0x1770 ; Tagbanwa
    0x1771,  # .. 0x1771 ; Unknown
    0x1772,  # .. 0x1773 ; Tagbanwa
    0x1774,  # .. 0x177F ; Unknown
    0x1780,  # .. 0x17DD ; Khmer
    0x17DE,  # .. 0x17DF ; Unknown
    0x17E0,  # .. 0x17E9 ; Khmer
    0x17EA,  # .. 0x17EF ; Unknown
    0x17F0,  # .. 0x17F9 ; Khmer
    0x17FA,  # .. 0x17FF ; Unknown
    0x1800,  # .. 0x1801 ; Mongolian
    0x1802,  # .. 0x1803 ; Common
    0x1804,  # .. 0x1804 ; Mongolian
    0x1805,  # .. 0x1805 ; Common
    0x1806,  # .. 0x1819 ; Mongolian
    0x181A,  # .. 0x181F ; Unknown
    0x1820,  # .. 0x1878 ; Mongolian
    0x1879,  # .. 0x187F ; Unknown
    0x1880,  # .. 0x18AA ; Mongolian
    0x18AB,  # .. 0x18AF ; Unknown
    0x18B0,  # .. 0x18F5 ; Canadian_Aboriginal
    0x18F6,  # .. 0x18FF ; Unknown
    0x1900,  # .. 0x191E ; Limbu
    0x191F,  # .. 0x191F ; Unknown
    0x1920,  # .. 0x192B ; Limbu
    0x192C,  # .. 0x192F ; Unknown
    0x1930,  # .. 0x193B ; Limbu
    0x193C,  # .. 0x193F ; Unknown
    0x1940,  # .. 0x1940 ; Limbu
    0x1941,  # .. 0x1943 ; Unknown
    0x1944,  # .. 0x194F ; Limbu
    0x1950,  # .. 0x196D ; Tai_Le
    0x196E,  # .. 0x196F ; Unknown
    0x1970,  # .. 0x1974 ; Tai_Le
    0x1975,  # .. 0x197F ; Unknown
    0x1980,  # .. 0x19AB ; New_Tai_Lue
    0x19AC,  # .. 0x19AF ; Unknown
    0x19B0,  # .. 0x19C9 ; New_Tai_Lue
    0x19CA,  # .. 0x19CF ; Unknown
    0x19D0,  # .. 0x19DA ; New_Tai_Lue
    0x19DB,  # .. 0x19DD ; Unknown
    0x19DE,  # .. 0x19DF ; New_Tai_Lue
    0x19E0,  # .. 0x19FF ; Khmer
    0x1A00,  # .. 0x1A1B ; Buginese
    0x1A1C,  # .. 0x1A1D ; Unknown
    0x1A1E,  # .. 0x1A1F ; Buginese
    0x1A20,  # .. 0x1A5E ; Tai_Tham
    0x1A5F,  # .. 0x1A5F ; Unknown
    0x1A60,  # .. 0x1A7C ; Tai_Tham
    0x1A7D,  # .. 0x1A7E ; Unknown
    0x1A7F,  # .. 0x1A89 ; Tai_Tham
    0x1A8A,  # .. 0x1A8F ; Unknown
    0x1A90,  # .. 0x1A99 ; Tai_Tham
    0x1A9A,  # .. 0x1A9F ; Unknown
    0x1AA0,  # .. 0x1AAD ; Tai_Tham
    0x1AAE,  # .. 0x1AAF ; Unknown
    0x1AB0,  # .. 0x1ADD ; Inherited
    0x1ADE,  # .. 0x1ADF ; Unknown
    0x1AE0,  # .. 0x1AEB ; Inherited
    0x1AEC,  # .. 0x1AFF ; Unknown
    0x1B00,  # .. 0x1B4C ; Balinese
    0x1B4D,  # .. 0x1B4D ; Unknown
    0x1B4E,  # .. 0x1B7F ; Balinese
    0x1B80,  # .. 0x1BBF ; Sundanese
    0x1BC0,  # .. 0x1BF3 ; Batak
    0x1BF4,  # .. 0x1BFB ; Unknown
    0x1BFC,  # .. 0x1BFF ; Batak
    0x1C00,  # .. 0x1C37 ; Lepcha
    0x1C38,  # .. 0x1C3A ; Unknown
    0x1C3B,  # .. 0x1C49 ; Lepcha
    0x1C4A,  # .. 0x1C4C ; Unknown
    0x1C4D,  # .. 0x1C4F ; Lepcha
    0x1C50,  # .. 0x1C7F ; Ol_Chiki
    0x1C80,  # .. 0x1C8A ; Cyrillic
    0x1C8B,  # .. 0x1C8F ; Unknown
    0x1C90,  # .. 0x1CBA ; Georgian
    0x1CBB,  # .. 0x1CBC ; Unknown
    0x1CBD,  # .. 0x1CBF ; Georgian
    0x1CC0,  # .. 0x1CC7 ; Sundanese
    0x1CC8,  # .. 0x1CCF ; Unknown
    0x1CD0,  # .. 0x1CD2 ; Inherited
    0x1CD3,  # .. 0x1CD3 ; Common
    0x1CD4,  # .. 0x1CE0 ; Inherited
    0x1CE1,  # .. 0x1CE1 ; Common
    0x1CE2,  # .. 0x1CE8 ; Inherited
    0x1CE9,  # .. 0x1CEC ; Common
    0x1CED,  # .. 0x1CED ; Inherited
    0x1CEE,  # .. 0x1CF3 ; Common
    0x1CF4,  # .. 0x1CF4 ; Inherited
    0x1CF5,  # .. 0x1CF7 ; Common
    0x1CF8,  # .. 0x1CF9 ; Inherited
    0x1CFA,  # .. 0x1CFA ; Common
    0x1CFB,  # .. 0x1CFF ; Unknown
    0x1D00,  # .. 0x1D25 ; Latin
    0x1D26,  # .. 0x1D2A ; Greek
    0x1D2B,  # .. 0x1D2B ; Cyrillic
    0x1D2C,  # .. 0x1D5C ; Latin
    0x1D5D,  # .. 0x1D61 ; Greek
    0x1D62,  # .. 0x1D65 ; Latin
    0x1D66,  # .. 0x1D6A ; Greek
    0x1D6B,  # .. 0x1D77 ; Latin
    0x1D78,  # .. 0x1D78 ; Cyrillic
    0x1D79,  # .. 0x1DBE ; Latin
    0x1DBF,  # .. 0x1DBF ; Greek
    0x1DC0,  # .. 0x1DFF ; Inherited
    0x1E00,  # .. 0x1EFF ; Latin
    0x1F00,  # .. 0x1F15 ; Greek
    0x1F16,  # .. 0x1F17 ; Unknown
    0x1F18,  # .. 0x1F1D ; Greek
    0x1F1E,  # .. 0x1F1F ; Unknown
    0x1F20,  # .. 0x1F45 ; Greek
    0x1F46,  # .. 0x1F47 ; Unknown
    0x1F48,  # .. 0x1F4D ; Greek
    0x1F4E,  # .. 0x1F4F ; Unknown
    0x1F50,  # .. 0x1F57 ; Greek
    0x1F58,  # .. 0x1F58 ; Unknown
    0x1F59,  # .. 0x1F59 ; Greek
    0x1F5A,  # .. 0x1F5A ; Unknown
    0x1F5B,  # .. 0x1F5B ; Greek
    0x1F5C,  # .. 0x1F5C ; Unknown
    0x1F5D,  # .. 0x1F5D ; Greek
    0x1F5E,  # .. 0x1F5E ; Unknown
    0x1F5F,  # .. 0x1F7D ; Greek
    0x1F7E,  # .. 0x1F7F ; Unknown
    0x1F80,  # .. 0x1FB4 ; Greek
    0x1FB5,  # .. 0x1FB5 ; Unknown
    0x1FB6,  # .. 0x1FC4 ; Greek
    0x1FC5,  # .. 0x1FC5 ; Unknown
    0x1FC6,  # .. 0x1FD3 ; Greek
    0x1FD4,  # .. 0x1FD5 ; Unknown
    0x1FD6,  # .. 0x1FDB ; Greek
    0x1FDC,  # .. 0x1FDC ; Unknown
    0x1FDD,  # .. 0x1FEF ; Greek
    0x1FF0,  # .. 0x1FF1 ; Unknown
    0x1FF2,  # .. 0x1FF4 ; Greek
    0x1FF5,  # .. 0x1FF5 ; Unknown
    0x1FF6,  # .. 0x1FFE ; Greek
    0x1FFF,  # .. 0x1FFF ; Unknown
    0x2000,  # .. 0x200B ; Common
    0x200C,  # .. 0x200D ; Inherited
    0x200E,  # .. 0x2064 ; Common
    0x2065,  # .. 0x2065 ; Unknown
    0x2066,  # .. 0x2070 ; Common
    0x2071,  # .. 0x2071 ; Latin
    0x2072,  # .. 0x2073 ; Unknown
    0x2074,  # .. 0x207E ; Common
    0x207F,  # .. 0x207F ; Latin
    0x2080,  # .. 0x208E ; Common
    0x208F,  # .. 0x208F ; Unknown
    0x2090,  # .. 0x209C ; Latin
    0x209D,  # .. 0x209F ; Unknown
    0x20A0,  # .. 0x20C1 ; Common
    0x20C2,  # .. 0x20CF ; Unknown
    0x20D0,  # .. 0x20F0 ; Inherited
    0x20F1,  # .. 0x20FF ; Unknown
    0x2100,  # .. 0x2125 ; Common
    0x2126,  # .. 0x2126 ; Greek
    0x2127,  # .. 0x2129 ; Common
    0x212A,  # .. 0x212B ; Latin
    0x212C,  # .. 0x2131 ; Common
    0x2132,  # .. 0x2132 ; Latin
    0x2133,  # .. 0x214D ; Common
    0x214E,  # .. 0x214E ; Latin
    0x214F,  # .. 0x215F ; Common
    0x2160,  # .. 0x2188 ; Latin
    0x2189,  # .. 0x218B ; Common
    0x218C,  # .. 0x218F ; Unknown
    0x2190,  # .. 0x2429 ; Common
    0x242A,  # .. 0x243F ; Unknown
    0x2440,  # .. 0x244A ; Common
    0x244B,  # .. 0x245F ; Unknown
    0x2460,  # .. 0x27FF ; Common
    0x2800,  # .. 0x28FF ; Braille
    0x2900,  # .. 0x2B73 ; Common
    0x2B74,  # .. 0x2B75 ; Unknown
    0x2B76,  # .. 0x2BFF ; Common
    0x2C00,  # .. 0x2C5F ; Glagolitic
    0x2C60,  # .. 0x2C7F ; Latin
    0x2C80,  # .. 0x2CF3 ; Coptic
    0x2CF4,  # .. 0x2CF8 ; Unknown
    0x2CF9,  # .. 0x2CFF ; Coptic
    0x2D00,  # .. 0x2D25 ; Georgian
    0x2D26,  # .. 0x2D26 ; Unknown
    0x2D27,  # .. 0x2D27 ; Georgian
    0x2D28,  # .. 0x2D2C ; Unknown
    0x2D2D,  # .. 0x2D2D ; Georgian
    0x2D2E,  # .. 0x2D2F ; Unknown
    0x2D30,  # .. 0x2D67 ; Tifinagh
    0x2D68,  # .. 0x2D6E ; Unknown
    0x2D6F,  # .. 0x2D70 ; Tifinagh
    0x2D71,  # .. 0x2D7E ; Unknown
    0x2D7F,  # .. 0x2D7F ; Tifinagh
    0x2D80,  # .. 0x2D96 ; Ethiopic
    0x2D97,  # .. 0x2D9F ; Unknown
    0x2DA0,  # .. 0x2DA6 ; Ethiopic
    0x2DA7,  # .. 0x2DA7 ; Unknown
    0x2DA8,  # .. 0x2DAE ; Ethiopic
    0x2DAF,  # .. 0x2DAF ; Unknown
    0x2DB0,  # .. 0x2DB6 ; Ethiopic
    0x2DB7,  # .. 0x2DB7 ; Unknown
    0x2DB8,  # .. 0x2DBE ; Ethiopic
    0x2DBF,  # .. 0x2DBF ; Unknown
    0x2DC0,  # .. 0x2DC6 ; Ethiopic
    0x2DC7,  # .. 0x2DC7 ; Unknown
    0x2DC8,  # .. 0x2DCE ; Ethiopic
    0x2DCF,  # .. 0x2DCF ; Unknown
    0x2DD0,  # .. 0x2DD6 ; Ethiopic
    0x2DD7,  # .. 0x2DD7 ; Unknown
    0x2DD8,  # .. 0x2DDE ; Ethiopic
    0x2DDF,  # .. 0x2DDF ; Unknown
    0x2DE0,  # .. 0x2DFF ; Cyrillic
    0x2E00,  # .. 0x2E5D ; Common
    0x2E5E,  # .. 0x2E7F ; Unknown
    0x2E80,  # .. 0x2E99 ; Han
    0x2E9A,  # .. 0x2E9A ; Unknown
    0x2E9B,  # .. 0x2EF3 ; Han
    0x2EF4,  # .. 0x2EFF ; Unknown
    0x2F00,  # .. 0x2FD5 ; Han
    0x2FD6,  # .. 0x2FEF ; Unknown
    0x2FF0,  # .. 0x3004 ; Common
    0x3005,  # .. 0x3005 ; Han
    0x3006,  # .. 0x3006 ; Common
    0x3007,  # .. 0x3007 ; Han
    0x3008,  # .. 0x3020 ; Common
    0x3021,  # .. 0x3029 ; Han
    0x302A,  # .. 0x302D ; Inherited
    0x302E,  # .. 0x302F ; Hangul
    0x3030,  # .. 0x3037 ; Common
    0x3038,  # .. 0x303B ; Han
    0x303C,  # .. 0x303F ; Common
    0x3040,  # .. 0x3040 ; Unknown
    0x3041,  # .. 0x3096 ; Hiragana
    0x3097,  # .. 0x3098 ; Unknown
    0x3099,  # .. 0x309A ; Inherited
    0x309B,  # .. 0x309C ; Common
    0x309D,  # .. 0x309F ; Hiragana
    0x30A0,  # .. 0x30A0 ; Common
    0x30A1,  # .. 0x30FA ; Katakana
    0x30FB,  # .. 0x30FC ; Common
    0x30FD,  # .. 0x30FF ; Katakana
    0x3100,  # .. 0x3104 ; Unknown
    0x3105,  # .. 0x312F ; Bopomofo
    0x3130,  # .. 0x3130 ; Unknown
    0x3131,  # .. 0x318E ; Hangul
    0x318F,  # .. 0x318F ; Unknown
    0x3190,  # .. 0x319F ; Common
    0x31A0,  # .. 0x31BF ; Bopomofo
    0x31C0,  # .. 0x31E5 ; Common
    0x31E6,  # .. 0x31EE ; Unknown
    0x31EF,  # .. 0x31EF ; Common
    0x31F0,  # .. 0x31FF ; Katakana
    0x3200,  # .. 0x321E ; Hangul
    0x321F,  # .. 0x321F ; Unknown
    0x3220,  # .. 0x325F ; Common
    0x3260,  # .. 0x327E ; Hangul
    0x327F,  # .. 0x32CF ; Common
    0x32D0,  # .. 0x32FE ; Katakana
    0x32FF,  # .. 0x32FF ; Common
    0x3300,  # .. 0x3357 ; Katakana
    0x3358,  # .. 0x33FF ; Common
    0x3400,  # .. 0x4DBF ; Han
    0x4DC0,  # .. 0x4DFF ; Common
    0x4E00,  # .. 0x9FFF ; Han
    0xA000,  # .. 0xA48C ; Yi
    0xA48D,  # .. 0xA48F ; Unknown
    0xA490,  # .. 0xA4C6 ; Yi
    0xA4C7,  # .. 0xA4CF ; Unknown
    0xA4D0,  # .. 0xA4FF ; Lisu
    0xA500,  # .. 0xA62B ; Vai
    0xA62C,  # .. 0xA63F ; Unknown
    0xA640,  # .. 0xA69F ; Cyrillic
    0xA6A0,  # .. 0xA6F7 ; Bamum
    0xA6F8,  # .. 0xA6FF ; Unknown
    0xA700,  # .. 0xA721 ; Common
    0xA722,  # .. 0xA787 ; Latin
    0xA788,  # .. 0xA78A ; Common
    0xA78B,  # .. 0xA7DC ; Latin
    0xA7DD,  # .. 0xA7F0 ; Unknown
    0xA7F1,  # .. 0xA7FF ; Latin
    0xA800,  # .. 0xA82C ; Syloti_Nagri
    0xA82D,  # .. 0xA82F ; Unknown
    0xA830,  # .. 0xA839 ; Common
    0xA83A,  # .. 0xA83F ; Unknown
    0xA840,  # .. 0xA877 ; Phags_Pa
    0xA878,  # .. 0xA87F ; Unknown
    0xA880,  # .. 0xA8C5 ; Saurashtra
    0xA8C6,  # .. 0xA8CD ; Unknown
    0xA8CE,  # .. 0xA8D9 ; Saurashtra
    0xA8DA,  # .. 0xA8DF ; Unknown
    0xA8E0,  # .. 0xA8FF ; Devanagari
    0xA900,  # .. 0xA92D ; Kayah_Li
    0xA92E,  # .. 0xA92E ; Common
    0xA92F,  # .. 0xA92F ; Kayah_Li
    0xA930,  # .. 0xA953 ; Rejang
    0xA954,  # .. 0xA95E ; Unknown
    0xA95F,  # .. 0xA95F ; Rejang
    0xA960,  # .. 0xA97C ; Hangul
    0xA97D,  # .. 0xA97F ; Unknown
    0xA980,  # .. 0xA9CD ; Javanese
    0xA9CE,  # .. 0xA9CE ; Unknown
    0xA9CF,  # .. 0xA9CF ; Common
    0xA9D0,  # .. 0xA9D9 ; Javanese
    0xA9DA,  # .. 0xA9DD ; Unknown
    0xA9DE,  # .. 0xA9DF ; Javanese
    0xA9E0,  # .. 0xA9FE ; Myanmar
    0xA9FF,  # .. 0xA9FF ; Unknown
    0xAA00,  # .. 0xAA36 ; Cham
    0xAA37,  # .. 0xAA3F ; Unknown
    0xAA40,  # .. 0xAA4D ; Cham
    0xAA4E,  # .. 0xAA4F ; Unknown
    0xAA50,  # .. 0xAA59 ; Cham
    0xAA5A,  # .. 0xAA5B ; Unknown
    0xAA5C,  # .. 0xAA5F ; Cham
    0xAA60,  # .. 0xAA7F ; Myanmar
    0xAA80,  # .. 0xAAC2 ; Tai_Viet
    0xAAC3,  # .. 0xAADA ; Unknown
    0xAADB,  # .. 0xAADF ; Tai_Viet
    0xAAE0,  # .. 0xAAF6 ; Meetei_Mayek
    0xAAF7,  # .. 0xAB00 ; Unknown
    0xAB01,  # .. 0xAB06 ; Ethiopic
    0xAB07,  # .. 0xAB08 ; Unknown
    0xAB09,  # .. 0xAB0E ; Ethiopic
    0xAB0F,  # .. 0xAB10 ; Unknown
    0xAB11,  # .. 0xAB16 ; Ethiopic
    0xAB17,  # .. 0xAB1F ; Unknown
    0xAB20,  # .. 0xAB26 ; Ethiopic
    0xAB27,  # .. 0xAB27 ; Unknown
    0xAB28,  # .. 0xAB2E ; Ethiopic
    0xAB2F,  # .. 0xAB2F ; Unknown
    0xAB30,  # .. 0xAB5A ; Latin
    0xAB5B,  # .. 0xAB5B ; Common
    0xAB5C,  # .. 0xAB64 ; Latin
    0xAB65,  # .. 0xAB65 ; Greek
    0xAB66,  # .. 0xAB69 ; Latin
    0xAB6A,  # .. 0xAB6B ; Common
    0xAB6C,  # .. 0xAB6F ; Unknown
    0xAB70,  # .. 0xABBF ; Cherokee
    0xABC0,  # .. 0xABED ; Meetei_Mayek
    0xABEE,  # .. 0xABEF ; Unknown
    0xABF0,  # .. 0xABF9 ; Meetei_Mayek
    0xABFA,  # .. 0xABFF ; Unknown
    0xAC00,  # .. 0xD7A3 ; Hangul
    0xD7A4,  # .. 0xD7AF ; Unknown
    0xD7B0,  # .. 0xD7C6 ; Hangul
    0xD7C7,  # .. 0xD7CA ; Unknown
    0xD7CB,  # .. 0xD7FB ; Hangul
    0xD7FC,  # .. 0xF8FF ; Unknown
    0xF900,  # .. 0xFA6D ; Han
    0xFA6E,  # .. 0xFA6F ; Unknown
    0xFA70,  # .. 0xFAD9 ; Han
    0xFADA,  # .. 0xFAFF ; Unknown
    0xFB00,  # .. 0xFB06 ; Latin
    0xFB07,  # .. 0xFB12 ; Unknown
    0xFB13,  # .. 0xFB17 ; Armenian
    0xFB18,  # .. 0xFB1C ; Unknown
    0xFB1D,  # .. 0xFB36 ; Hebrew
    0xFB37,  # .. 0xFB37 ; Unknown
    0xFB38,  # .. 0xFB3C ; Hebrew
    0xFB3D,  # .. 0xFB3D ; Unknown
    0xFB3E,  # .. 0xFB3E ; Hebrew
    0xFB3F,  # .. 0xFB3F ; Unknown
    0xFB40,  # .. 0xFB41 ; Hebrew
    0xFB42,  # .. 0xFB42 ; Unknown
    0xFB43,  # .. 0xFB44 ; Hebrew
    0xFB45,  # .. 0xFB45 ; Unknown
    0xFB46,  # .. 0xFB4F ; Hebrew
    0xFB50,  # .. 0xFD3D ; Arabic
    0xFD3E,  # .. 0xFD3F ; Common
    0xFD40,  # .. 0xFDCF ; Arabic
    0xFDD0,  # .. 0xFDEF ; Unknown
    0xFDF0,  # .. 0xFDFF ; Arabic
    0xFE00,  # .. 0xFE0F ; Inherited
    0xFE10,  # .. 0xFE19 ; Common
    0xFE1A,  # .. 0xFE1F ; Unknown
    0xFE20,  # .. 0xFE2D ; Inherited
    0xFE2E,  # .. 0xFE2F ; Cyrillic
    0xFE30,  # .. 0xFE52 ; Common
    0xFE53,  # .. 0xFE53 ; Unknown
    0xFE54,  # .. 0xFE66 ; Common
    0xFE67,  # .. 0xFE67 ; Unknown
    0xFE68,  # .. 0xFE6B ; Common
    0xFE6C,  # .. 0xFE6F ; Unknown
    0xFE70,  # .. 0xFE74 ; Arabic
    0xFE75,  # .. 0xFE75 ; Unknown
    0xFE76,  # .. 0xFEFC ; Arabic
    0xFEFD,  # .. 0xFEFE ; Unknown
    0xFEFF,  # .. 0xFEFF ; Common
    0xFF00,  # .. 0xFF00 ; Unknown
    0xFF01,  # .. 0xFF20 ; Common
    0xFF21,  # .. 0xFF3A ; Latin
    0xFF3B,  # .. 0xFF40 ; Common
    0xFF41,  # .. 0xFF5A ; Latin
    0xFF5B,  # .. 0xFF65 ; Common
    0xFF66,  # .. 0xFF6F ; Katakana
    0xFF70,  # .. 0xFF70 ; Common
    0xFF71,  # .. 0xFF9D ; Katakana
    0xFF9E,  # .. 0xFF9F ; Common
    0xFFA0,  # .. 0xFFBE ; Hangul
    0xFFBF,  # .. 0xFFC1 ; Unknown
    0xFFC2,  # .. 0xFFC7 ; Hangul
    0xFFC8,  # .. 0xFFC9 ; Unknown
    0xFFCA,  # .. 0xFFCF ; Hangul
    0xFFD0,  # .. 0xFFD1 ; Unknown
    0xFFD2,  # .. 0xFFD7 ; Hangul
    0xFFD8,  # .. 0xFFD9 ; Unknown
    0xFFDA,  # .. 0xFFDC ; Hangul
    0xFFDD,  # .. 0xFFDF ; Unknown
    0xFFE0,  # .. 0xFFE6 ; Common
    0xFFE7,  # .. 0xFFE7 ; Unknown
    0xFFE8,  # .. 0xFFEE ; Common
    0xFFEF,  # .. 0xFFF8 ; Unknown
    0xFFF9,  # .. 0xFFFD ; Common
    0xFFFE,  # .. 0xFFFF ; Unknown
    0x10000,  # .. 0x1000B ; Linear_B
    0x1000C,  # .. 0x1000C ; Unknown
    0x1000D,  # .. 0x10026 ; Linear_B
    0x10027,  # .. 0x10027 ; Unknown
    0x10028,  # .. 0x1003A ; Linear_B
    0x1003B,  # .. 0x1003B ; Unknown
    0x1003C,  # .. 0x1003D ; Linear_B
    0x1003E,  # .. 0x1003E ; Unknown
    0x1003F,  # .. 0x1004D ; Linear_B
    0x1004E,  # .. 0x1004F ; Unknown
    0x10050,  # .. 0x1005D ; Linear_B
    0x1005E,  # .. 0x1007F ; Unknown
    0x10080,  # .. 0x100FA ; Linear_B
    0x100FB,  # .. 0x100FF ; Unknown
    0x10100,  # .. 0x10102 ; Common
    0x10103,  # .. 0x10106 ; Unknown
    0x10107,  # .. 0x10133 ; Common
    0x10134,  # .. 0x10136 ; Unknown
    0x10137,  # .. 0x1013F ; Common
    0x10140,  # .. 0x1018E ; Greek
    0x1018F,  # .. 0x1018F ; Unknown
    0x10190,  # .. 0x1019C ; Common
    0x1019D,  # .. 0x1019F ; Unknown
    0x101A0,  # .. 0x101A0 ; Greek
    0x101A1,  # .. 0x101CF ; Unknown
    0x101D0,  # .. 0x101FC ; Common
    0x101FD,  # .. 0x101FD ; Inherited
    0x101FE,  # .. 0x1027F ; Unknown
    0x10280,  # .. 0x1029C ; Lycian
    0x1029D,  # .. 0x1029F ; Unknown
    0x102A0,  # .. 0x102D0 ; Carian
    0x102D1,  # .. 0x102DF ; Unknown
    0x102E0,  # .. 0x102E0 ; Inherited
    0x102E1,  # .. 0x102FB ; Common
    0x102FC,  # .. 0x102FF ; Unknown
    0x10300,  # .. 0x10323 ; Old_Italic
    0x10324,  # .. 0x1032C ; Unknown
    0x1032D,  # .. 0x1032F ; Old_Italic
    0x10330,  # .. 0x1034A ; Gothic
    0x1034B,  # .. 0x1034F ; Unknown
    0x10350,  # .. 0x1037A ; Old_Permic
    0x1037B,  # .. 0x1037F ; Unknown
    0x10380,  # .. 0x1039D ; Ugaritic
    0x1039E,  # .. 0x1039E ; Unknown
    0x1039F,  # .. 0x1039F ; Ugaritic
    0x103A0,  # .. 0x103C3 ; Old_Persian
    0x103C4,  # .. 0x103C7 ; Unknown
    0x103C8,  # .. 0x103D5 ; Old_Persian
    0x103D6,  # .. 0x103FF ; Unknown
    0x10400,  # .. 0x1044F ; Deseret
    0x10450,  # .. 0x1047F ; Shavian
    0x10480,  # .. 0x1049D ; Osmanya
    0x1049E,  # .. 0x1049F ; Unknown
    0x104A0,  # .. 0x104A9 ; Osmanya
    0x104AA,  # .. 0x104AF ; Unknown
    0x104B0,  # .. 0x104D3 ; Osage
    0x104D4,  # .. 0x104D7 ; Unknown
    0x104D8,  # .. 0x104FB ; Osage
    0x104FC,  # .. 0x104FF ; Unknown
    0x10500,  # .. 0x10527 ; Elbasan
    0x10528,  # .. 0x1052F ; Unknown
    0x10530,  # .. 0x10563 ; Caucasian_Albanian
    0x10564,  # .. 0x1056E ; Unknown
    0x1056F,  # .. 0x1056F ; Caucasian_Albanian
    0x10570,  # .. 0x1057A ; Vithkuqi
    0x1057B,  # .. 0x1057B ; Unknown
    0x1057C,  # .. 0x1058A ; Vithkuqi
    0x1058B,  # .. 0x1058B ; Unknown
    0x1058C,  # .. 0x10592 ; Vithkuqi
    0x10593,  # .. 0x10593 ; Unknown
    0x10594,  # .. 0x10595 ; Vithkuqi
    0x10596,  # .. 0x10596 ; Unknown
    0x10597,  # .. 0x105A1 ; Vithkuqi
    0x105A2,  # .. 0x105A2 ; Unknown
    0x105A3,  # .. 0x105B1 ; Vithkuqi
    0x105B2,  # .. 0x105B2 ; Unknown
    0x105B3,  # .. 0x105B9 ; Vithkuqi
    0x105BA,  # .. 0x105BA ; Unknown
    0x105BB,  # .. 0x105BC ; Vithkuqi
    0x105BD,  # .. 0x105BF ; Unknown
    0x105C0,  # .. 0x105F3 ; Todhri
    0x105F4,  # .. 0x105FF ; Unknown
    0x10600,  # .. 0x10736 ; Linear_A
    0x10737,  # .. 0x1073F ; Unknown
    0x10740,  # .. 0x10755 ; Linear_A
    0x10756,  # .. 0x1075F ; Unknown
    0x10760,  # .. 0x10767 ; Linear_A
    0x10768,  # .. 0x1077F ; Unknown
    0x10780,  # .. 0x10785 ; Latin
    0x10786,  # .. 0x10786 ; Unknown
    0x10787,  # .. 0x107B0 ; Latin
    0x107B1,  # .. 0x107B1 ; Unknown
    0x107B2,  # .. 0x107BA ; Latin
    0x107BB,  # .. 0x107FF ; Unknown
    0x10800,  # .. 0x10805 ; Cypriot
    0x10806,  # .. 0x10807 ; Unknown
    0x10808,  # .. 0x10808 ; Cypriot
    0x10809,  # .. 0x10809 ; Unknown
    0x1080A,  # .. 0x10835 ; Cypriot
    0x10836,  # .. 0x10836 ; Unknown
    0x10837,  # .. 0x10838 ; Cypriot
    0x10839,  # .. 0x1083B ; Unknown
    0x1083C,  # .. 0x1083C ; Cypriot
    0x1083D,  # .. 0x1083E ; Unknown
    0x1083F,  # .. 0x1083F ; Cypriot
    0x10840,  # .. 0x10855 ; Imperial_Aramaic
    0x10856,  # .. 0x10856 ; Unknown
    0x10857,  # .. 0x1085F ; Imperial_Aramaic
    0x10860,  # .. 0x1087F ; Palmyrene
    0x10880,  # .. 0x1089E ; Nabataean
    0x1089F,  # .. 0x108A6 ; Unknown
    0x108A7,  # .. 0x108AF ; Nabataean
    0x108B0,  # .. 0x108DF ; Unknown
    0x108E0,  # .. 0x108F2 ; Hatran
    0x108F3,  # .. 0x108F3 ; Unknown
    0x108F4,  # .. 0x108F5 ; Hatran
    0x108F6,  # .. 0x108FA ; Unknown
    0x108FB,  # .. 0x108FF ; Hatran
    0x10900,  # .. 0x1091B ; Phoenician
    0x1091C,  # .. 0x1091E ; Unknown
    0x1091F,  # .. 0x1091F ; Phoenician
    0x10920,  # .. 0x10939 ; Lydian
    0x1093A,  # .. 0x1093E ; Unknown
    0x1093F,  # .. 0x1093F ; Lydian
    0x10940,  # .. 0x10959 ; Sidetic
    0x1095A,  # .. 0x1097F ; Unknown
    0x10980,  # .. 0x1099F ; Meroitic_Hieroglyphs
    0x109A0,  # .. 0x109B7 ; Meroitic_Cursive
    0x109B8,  # .. 0x109BB ; Unknown
    0x109BC,  # .. 0x109CF ; Meroitic_Cursive
    0x109D0,  # .. 0x109D1 ; Unknown
    0x109D2,  # .. 0x109FF ; Meroitic_Cursive
    0x10A00,  # .. 0x10A03 ; Kharoshthi
    0x10A04,  # .. 0x10A04 ; Unknown
    0x10A05,  # .. 0x10A06 ; Kharoshthi
    0x10A07,  # .. 0x10A0B ; Unknown
    0x10A0C,  # .. 0x10A13 ; Kharoshthi
    0x10A14,  # .. 0x10A14 ; Unknown
    0x10A15,  # .. 0x10A17 ; Kharoshthi
    0x10A18,  # .. 0x10A18 ; Unknown
    0x10A19,  # .. 0x10A35 ; Kharoshthi
    0x10A36,  # .. 0x10A37 ; Unknown
    0x10A38,  # .. 0x10A3A ; Kharoshthi
    0x10A3B,  # .. 0x10A3E ; Unknown
    0x10A3F,  # .. 0x10A48 ; Kharoshthi
    0x10A49,  # .. 0x10A4F ; Unknown
    0x10A50,  # .. 0x10A58 ; Kharoshthi
    0x10A59,  # .. 0x10A5F ; Unknown
    0x10A60,  # .. 0x10A7F ; Old_South_Arabian
    0x10A80,  # .. 0x10A9F ; Old_North_Arabian
    0x10AA0,  # .. 0x10ABF ; Unknown
    0x10AC0,  # .. 0x10AE6 ; Manichaean
    0x10AE7,  # .. 0x10AEA ; Unknown
    0x10AEB,  # .. 0x10AF6 ; Manichaean
    0x10AF7,  # .. 0x10AFF ; Unknown
    0x10B00,  # .. 0x10B35 ; Avestan
    0x10B36,  # .. 0x10B38 ; Unknown
    0x10B39,  # .. 0x10B3F ; Avestan
    0x10B40,  # .. 0x10B55 ; Inscriptional_Parthian
    0x10B56,  # .. 0x10B57 ; Unknown
    0x10B58,  # .. 0x10B5F ; Inscriptional_Parthian
    0x10B60,  # .. 0x10B72 ; Inscriptional_Pahlavi
    0x10B73,  # .. 0x10B77 ; Unknown
    0x10B78,  # .. 0x10B7F ; Inscriptional_Pahlavi
    0x10B80,  # .. 0x10B91 ; Psalter_Pahlavi
    0x10B92,  # .. 0x10B98 ; Unknown
    0x10B99,  # .. 0x10B9C ; Psalter_Pahlavi
    0x10B9D,  # .. 0x10BA8 ; Unknown
    0x10BA9,  # .. 0x10BAF ; Psalter_Pahlavi
    0x10BB0,  # .. 0x10BFF ; Unknown
    0x10C00,  # .. 0x10C48 ; Old_Turkic
    0x10C49,  # .. 0x10C7F ; Unknown
    0x10C80,  # .. 0x10CB2 ; Old_Hungarian
    0x10CB3,  # .. 0x10CBF ; Unknown
    0x10CC0,  # .. 0x10CF2 ; Old_Hungarian
    0x10CF3,  # .. 0x10CF9 ; Unknown
    0x10CFA,  # .. 0x10CFF ; Old_Hungarian
    0x10D00,  # .. 0x10D27 ; Hanifi_Rohingya
    0x10D28,  # .. 0x10D2F ; Unknown
    0x10D30,  # .. 0x10D39 ; Hanifi_Rohingya
    0x10D3A,  # .. 0x10D3F ; Unknown
    0x10D40,  # .. 0x10D65 ; Garay
    0x10D66,  # .. 0x10D68 ; Unknown
    0x10D69,  # .. 0x10D85 ; Garay
    0x10D86,  # .. 0x10D8D ; Unknown
    0x10D8E,  # .. 0x10D8F ; Garay
    0x10D90,  # .. 0x10E5F ; Unknown
    0x10E60,  # .. 0x10E7E ; Arabic
    0x10E7F,  # .. 0x10E7F ; Unknown
    0x10E80,  # .. 0x10EA9 ; Yezidi
    0x10EAA,  # .. 0x10EAA ; Unknown
    0x10EAB,  # .. 0x10EAD ; Yezidi
    0x10EAE,  # .. 0x10EAF ; Unknown
    0x10EB0,  # .. 0x10EB1 ; Yezidi
    0x10EB2,  # .. 0x10EC1 ; Unknown
    0x10EC2,  # .. 0x10EC7 ; Arabic
    0x10EC8,  # .. 0x10ECF ; Unknown
    0x10ED0,  # .. 0x10ED8 ; Arabic
    0x10ED9,  # .. 0x10EF9 ; Unknown
    0x10EFA,  # .. 0x10EFF ; Arabic
    0x10F00,  # .. 0x10F27 ; Old_Sogdian
    0x10F28,  # .. 0x10F2F ; Unknown
    0x10F30,  # .. 0x10F59 ; Sogdian
    0x10F5A,  # .. 0x10F6F ; Unknown
    0x10F70,  # .. 0x10F89 ; Old_Uyghur
    0x10F8A,  # .. 0x10FAF ; Unknown
    0x10FB0,  # .. 0x10FCB ; Chorasmian
    0x10FCC,  # .. 0x10FDF ; Unknown
    0x10FE0,  # .. 0x10FF6 ; Elymaic
    0x10FF7,  # .. 0x10FFF ; Unknown
    0x11000,  # .. 0x1104D ; Brahmi
    0x1104E,  # .. 0x11051 ; Unknown
    0x11052,  # .. 0x11075 ; Brahmi
    0x11076,  # .. 0x1107E ; Unknown
    0x1107F,  # .. 0x1107F ; Brahmi
    0x11080,  # .. 0x110C2 ; Kaithi
    0x110C3,  # .. 0x110CC ; Unknown
    0x110CD,  # .. 0x110CD ; Kaithi
    0x110CE,  # .. 0x110CF ; Unknown
    0x110D0,  # .. 0x110E8 ; Sora_Sompeng
    0x110E9,  # .. 0x110EF ; Unknown
    0x110F0,  # .. 0x110F9 ; Sora_Sompeng
    0x110FA,  # .. 0x110FF ; Unknown
    0x11100,  # .. 0x11134 ; Chakma
    0x11135,  # .. 0x11135 ; Unknown
    0x11136,  # .. 0x11147 ; Chakma
    0x11148,  # .. 0x1114F ; Unknown
    0x11150,  # .. 0x11176 ; Mahajani
    0x11177,  # .. 0x1117F ; Unknown
    0x11180,  # .. 0x111DF ; Sharada
    0x111E0,  # .. 0x111E0 ; Unknown
    0x111E1,  # .. 0x111F4 ; Sinhala
    0x111F5,  # .. 0x111FF ; Unknown
    0x11200,  # .. 0x11211 ; Khojki
    0x11212,  # .. 0x11212 ; Unknown
    0x11213,  # .. 0x11241 ; Khojki
    0x11242,  # .. 0x1127F ; Unknown
    0x11280,  # .. 0x11286 ; Multani
    0x11287,  # .. 0x11287 ; Unknown
    0x11288,  # .. 0x11288 ; Multani
    0x11289,  # .. 0x11289 ; Unknown
    0x1128A,  # .. 0x1128D ; Multani
    0x1128E,  # .. 0x1128E ; Unknown
    0x1128F,  # .. 0x1129D ; Multani
    0x1129E,  # .. 0x1129E ; Unknown
    0x1129F,  # .. 0x112A9 ; Multani
    0x112AA,  # .. 0x112AF ; Unknown
    0x112B0,  # .. 0x112EA ; Khudawadi
    0x112EB,  # .. 0x112EF ; Unknown
    0x112F0,  # .. 0x112F9 ; Khudawadi
    0x112FA,  # .. 0x112FF ; Unknown
    0x11300,  # .. 0x11303 ; Grantha
    0x11304,  # .. 0x11304 ; Unknown
    0x11305,  # .. 0x1130C ; Grantha
    0x1130D,  # .. 0x1130E ; Unknown
    0x1130F,  # .. 0x11310 ; Grantha
    0x11311,  # .. 0x11312 ; Unknown
    0x11313,  # .. 0x11328 ; Grantha
    0x11329,  # .. 0x11329 ; Unknown
    0x1132A,  # .. 0x11330 ; Grantha
    0x11331,  # .. 0x11331 ; Unknown
    0x11332,  # .. 0x11333 ; Grantha
    0x11334,  # .. 0x11334 ; Unknown
    0x11335,  # .. 0x11339 ; Grantha
    0x1133A,  # .. 0x1133A ; Unknown
    0x1133B,  # .. 0x1133B ; Inherited
    0x1133C,  # .. 0x11344 ; Grantha
    0x11345,  # .. 0x11346 ; Unknown
    0x11347,  # .. 0x11348 ; Grantha
    0x11349,  # .. 0x1134A ; Unknown
    0x1134B,  # .. 0x1134D ; Grantha
    0x1134E,  # .. 0x1134F ; Unknown
    0x11350,  # .. 0x11350 ; Grantha
    0x11351,  # .. 0x11356 ; Unknown
    0x11357,  # .. 0x11357 ; Grantha
    0x11358,  # .. 0x1135C ; Unknown
    0x1135D,  # .. 0x11363 ; Grantha
    0x11364,  # .. 0x11365 ; Unknown
    0x11366,  # .. 0x1136C ; Grantha
    0x1136D,  # .. 0x1136F ; Unknown
    0x11370,  # .. 0x11374 ; Grantha
    0x11375,  # .. 0x1137F ; Unknown
    0x11380,  # .. 0x11389 ; Tulu_Tigalari
    0x1138A,  # .. 0x1138A ; Unknown
    0x1138B,  # .. 0x1138B ; Tulu_Tigalari
    0x1138C,  # .. 0x1138D ; Unknown
    0x1138E,  # .. 0x1138E ; Tulu_Tigalari
    0x1138F,  # .. 0x1138F ; Unknown
    0x11390,  # .. 0x113B5 ; Tulu_Tigalari
    0x113B6,  # .. 0x113B6 ; Unknown
    0x113B7,  # .. 0x113C0 ; Tulu_Tigalari
    0x113C1,  # .. 0x113C1 ; Unknown
    0x113C2,  # .. 0x113C2 ; Tulu_Tigalari
    0x113C3,  # .. 0x113C4 ; Unknown
    0x113C5,  # .. 0x113C5 ; Tulu_Tigalari
    0x113C6,  # .. 0x113C6 ; Unknown
    0x113C7,  # .. 0x113CA ; Tulu_Tigalari
    0x113CB,  # .. 0x113CB ; Unknown
    0x113CC,  # .. 0x113D5 ; Tulu_Tigalari
    0x113D6,  # .. 0x113D6 ; Unknown
    0x113D7,  # .. 0x113D8 ; Tulu_Tigalari
    0x113D9,  # .. 0x113E0 ; Unknown
    0x113E1,  # .. 0x113E2 ; Tulu_Tigalari
    0x113E3,  # .. 0x113FF ; Unknown
    0x11400,  # .. 0x1145B ; Newa
    0x1145C,  # .. 0x1145C ; Unknown
    0x1145D,  # .. 0x11461 ; Newa
    0x11462,  # .. 0x1147F ; Unknown
    0x11480,  # .. 0x114C7 ; Tirhuta
    0x114C8,  # .. 0x114CF ; Unknown
    0x114D0,  # .. 0x114D9 ; Tirhuta
    0x114DA,  # .. 0x1157F ; Unknown
    0x11580,  # .. 0x115B5 ; Siddham
    0x115B6,  # .. 0x115B7 ; Unknown
    0x115B8,  # .. 0x115DD ; Siddham
    0x115DE,  # .. 0x115FF ; Unknown
    0x11600,  # .. 0x11644 ; Modi
    0x11645,  # .. 0x1164F ; Unknown
    0x11650,  # .. 0x11659 ; Modi
    0x1165A,  # .. 0x1165F ; Unknown
    0x11660,  # .. 0x1166C ; Mongolian
    0x1166D,  # .. 0x1167F ; Unknown
    0x11680,  # .. 0x116B9 ; Takri
    0x116BA,  # .. 0x116BF ; Unknown
    0x116C0,  # .. 0x116C9 ; Takri
    0x116CA,  # .. 0x116CF ; Unknown
    0x116D0,  # .. 0x116E3 ; Myanmar
    0x116E4,  # .. 0x116FF ; Unknown
    0x11700,  # .. 0x1171A ; Ahom
    0x1171B,  # .. 0x1171C ; Unknown
    0x1171D,  # .. 0x1172B ; Ahom
    0x1172C,  # .. 0x1172F ; Unknown
    0x11730,  # .. 0x11746 ; Ahom
    0x11747,  # .. 0x117FF ; Unknown
    0x11800,  # .. 0x1183B ; Dogra
    0x1183C,  # .. 0x1189F ; Unknown
    0x118A0,  # .. 0x118F2 ; Warang_Citi
    0x118F3,  # .. 0x118FE ; Unknown
    0x118FF,  # .. 0x118FF ; Warang_Citi
    0x11900,  # .. 0x11906 ; Dives_Akuru
    0x11907,  # .. 0x11908 ; Unknown
    0x11909,  # .. 0x11909 ; Dives_Akuru
    0x1190A,  # .. 0x1190B ; Unknown
    0x1190C,  # .. 0x11913 ; Dives_Akuru
    0x11914,  # .. 0x11914 ; Unknown
    0x11915,  # .. 0x11916 ; Dives_Akuru
    0x11917,  # .. 0x11917 ; Unknown
    0x11918,  # .. 0x11935 ; Dives_Akuru
    0x11936,  # .. 0x11936 ; Unknown
    0x11937,  # .. 0x11938 ; Dives_Akuru
    0x11939,  # .. 0x1193A ; Unknown
    0x1193B,  # .. 0x11946 ; Dives_Akuru
    0x11947,  # .. 0x1194F ; Unknown
    0x11950,  # .. 0x11959 ; Dives_Akuru
    0x1195A,  # .. 0x1199F ; Unknown
    0x119A0,  # .. 0x119A7 ; Nandinagari
    0x119A8,  # .. 0x119A9 ; Unknown
    0x119AA,  # .. 0x119D7 ; Nandinagari
    0x119D8,  # .. 0x119D9 ; Unknown
    0x119DA,  # .. 0x119E4 ; Nandinagari
    0x119E5,  # .. 0x119FF ; Unknown
    0x11A00,  # .. 0x11A47 ; Zanabazar_Square
    0x11A48,  # .. 0x11A4F ; Unknown
    0x11A50,  # .. 0x11AA2 ; Soyombo
    0x11AA3,  # .. 0x11AAF ; Unknown
    0x11AB0,  # .. 0x11ABF ; Canadian_Aboriginal
    0x11AC0,  # .. 0x11AF8 ; Pau_Cin_Hau
    0x11AF9,  # .. 0x11AFF ; Unknown
    0x11B00,  # .. 0x11B09 ; Devanagari
    0x11B0A,  # .. 0x11B5F ; Unknown
    0x11B60,  # .. 0x11B67 ; Sharada
    0x11B68,  # .. 0x11BBF ; Unknown
    0x11BC0,  # .. 0x11BE1 ; Sunuwar
    0x11BE2,  # .. 0x11BEF ; Unknown
    0x11BF0,  # .. 0x11BF9 ; Sunuwar
    0x11BFA,  # .. 0x11BFF ; Unknown
    0x11C00,  # .. 0x11C08 ; Bhaiksuki
    0x11C09,  # .. 0x11C09 ; Unknown
    0x11C0A,  # .. 0x11C36 ; Bhaiksuki
    0x11C37,  # .. 0x11C37 ; Unknown
    0x11C38,  # .. 0x11C45 ; Bhaiksuki
    0x11C46,  # .. 0x11C4F ; Unknown
    0x11C50,  # .. 0x11C6C ; Bhaiksuki
    0x11C6D,  # .. 0x11C6F ; Unknown
    0x11C70,  # .. 0x11C8F ; Marchen
    0x11C90,  # .. 0x11C91 ; Unknown
    0x11C92,  # .. 0x11CA7 ; Marchen
    0x11CA8,  # .. 0x11CA8 ; Unknown
    0x11CA9,  # .. 0x11CB6 ; Marchen
    0x11CB7,  # .. 0x11CFF ; Unknown
    0x11D00,  # .. 0x11D06 ; Masaram_Gondi
    0x11D07,  # .. 0x11D07 ; Unknown
    0x11D08,  # .. 0x11D09 ; Masaram_Gondi
    0x11D0A,  # .. 0x11D0A ; Unknown
    0x11D0B,  # .. 0x11D36 ; Masaram_Gondi
    0x11D37,  # .. 0x11D39 ; Unknown
    0x11D3A,  # .. 0x11D3A ; Masaram_Gondi
    0x11D3B,  # .. 0x11D3B ; Unknown
    0x11D3C,  # .. 0x11D3D ; Masaram_Gondi
    0x11D3E,  # .. 0x11D3E ; Unknown
    0x11D3F,  # .. 0x11D47 ; Masaram_Gondi
    0x11D48,  # .. 0x11D4F ; Unknown
    0x11D50,  # .. 0x11D59 ; Masaram_Gondi
    0x11D5A,  # .. 0x11D5F ; Unknown
    0x11D60,  # .. 0x11D65 ; Gunjala_Gondi
    0x11D66,  # .. 0x11D66 ; Unknown
    0x11D67,  # .. 0x11D68 ; Gunjala_Gondi
    0x11D69,  # .. 0x11D69 ; Unknown
    0x11D6A,  # .. 0x11D8E ; Gunjala_Gondi
    0x11D8F,  # .. 0x11D8F ; Unknown
    0x11D90,  # .. 0x11D91 ; Gunjala_Gondi
    0x11D92,  # .. 0x11D92 ; Unknown
    0x11D93,  # .. 0x11D98 ; Gunjala_Gondi
    0x11D99,  # .. 0x11D9F ; Unknown
    0x11DA0,  # .. 0x11DA9 ; Gunjala_Gondi
    0x11DAA,  # .. 0x11DAF ; Unknown
    0x11DB0,  # .. 0x11DDB ; Tolong_Siki
    0x11DDC,  # .. 0x11DDF ; Unknown
    0x11DE0,  # .. 0x11DE9 ; Tolong_Siki
    0x11DEA,  # .. 0x11EDF ; Unknown
    0x11EE0,  # .. 0x11EF8 ; Makasar
    0x11EF9,  # .. 0x11EFF ; Unknown
    0x11F00,  # .. 0x11F10 ; Kawi
    0x11F11,  # .. 0x11F11 ; Unknown
    0x11F12,  # .. 0x11F3A ; Kawi
    0x11F3B,  # .. 0x11F3D ; Unknown
    0x11F3E,  # .. 0x11F5A ; Kawi
    0x11F5B,  # .. 0x11FAF ; Unknown
    0x11FB0,  # .. 0x11FB0 ; Lisu
    0x11FB1,  # .. 0x11FBF ; Unknown
    0x11FC0,  # .. 0x11FF1 ; Tamil
    0x11FF2,  # .. 0x11FFE ; Unknown
    0x11FFF,  # .. 0x11FFF ; Tamil
    0x12000,  # .. 0x12399 ; Cuneiform
    0x1239A,  # .. 0x123FF ; Unknown
    0x12400,  # .. 0x1246E ; Cuneiform
    0x1246F,  # .. 0x1246F ; Unknown
    0x12470,  # .. 0x12474 ; Cuneiform
    0x12475,  # .. 0x1247F ; Unknown
    0x12480,  # .. 0x12543 ; Cuneiform
    0x12544,  # .. 0x12F8F ; Unknown
    0x12F90,  # .. 0x12FF2 ; Cypro_Minoan
    0x12FF3,  # .. 0x12FFF ; Unknown
    0x13000,  # .. 0x13455 ; Egyptian_Hieroglyphs
    0x13456,  # .. 0x1345F ; Unknown
    0x13460,  # .. 0x143FA ; Egyptian_Hieroglyphs
    0x143FB,  # .. 0x143FF ; Unknown
    0x14400,  # .. 0x14646 ; Anatolian_Hieroglyphs
    0x14647,  # .. 0x160FF ; Unknown
    0x16100,  # .. 0x16139 ; Gurung_Khema
    0x1613A,  # .. 0x167FF ; Unknown
    0x16800,  # .. 0x16A38 ; Bamum
    0x16A39,  # .. 0x16A3F ; Unknown
    0x16A40,  # .. 0x16A5E ; Mro
    0x16A5F,  # .. 0x16A5F ; Unknown
    0x16A60,  # .. 0x16A69 ; Mro
    0x16A6A,  # .. 0x16A6D ; Unknown
    0x16A6E,  # .. 0x16A6F ; Mro
    0x16A70,  # .. 0x16ABE ; Tangsa
    0x16ABF,  # .. 0x16ABF ; Unknown
    0x16AC0,  # .. 0x16AC9 ; Tangsa
    0x16ACA,  # .. 0x16ACF ; Unknown
    0x16AD0,  # .. 0x16AED ; Bassa_Vah
    0x16AEE,  # .. 0x16AEF ; Unknown
    0x16AF0,  # .. 0x16AF5 ; Bassa_Vah
    0x16AF6,  # .. 0x16AFF ; Unknown
    0x16B00,  # .. 0x16B45 ; Pahawh_Hmong
    0x16B46,  # .. 0x16B4F ; Unknown
    0x16B50,  # .. 0x16B59 ; Pahawh_Hmong
    0x16B5A,  # .. 0x16B5A ; Unknown
    0x16B5B,  # .. 0x16B61 ; Pahawh_Hmong
    0x16B62,  # .. 0x16B62 ; Unknown
    0x16B63,  # .. 0x16B77 ; Pahawh_Hmong
    0x16B78,  # .. 0x16B7C ; Unknown
    0x16B7D,  # .. 0x16B8F ; Pahawh_Hmong
    0x16B90,  # .. 0x16D3F ; Unknown
    0x16D40,  # .. 0x16D79 ; Kirat_Rai
    0x16D7A,  # .. 0x16E3F ; Unknown
    0x16E40,  # .. 0x16E9A ; Medefaidrin
    0x16E9B,  # .. 0x16E9F ; Unknown
    0x16EA0,  # .. 0x16EB8 ; Beria_Erfe
    0x16EB9,  # .. 0x16EBA ; Unknown
    0x16EBB,  # .. 0x16ED3 ; Beria_Erfe
    0x16ED4,  # .. 0x16EFF ; Unknown
    0x16F00,  # .. 0x16F4A ; Miao
    0x16F4B,  # .. 0x16F4E ; Unknown
    0x16F4F,  # .. 0x16F87 ; Miao
    0x16F88,  # .. 0x16F8E ; Unknown
    0x16F8F,  # .. 0x16F9F ; Miao
    0x16FA0,  # .. 0x16FDF ; Unknown
    0x16FE0,  # .. 0x16FE0 ; Tangut
    0x16FE1,  # .. 0x16FE1 ; Nushu
    0x16FE2,  # .. 0x16FE3 ; Han
    0x16FE4,  # .. 0x16FE4 ; Khitan_Small_Script
    0x16FE5,  # .. 0x16FEF ; Unknown
    0x16FF0,  # .. 0x16FF6 ; Han
    0x16FF7,  # .. 0x16FFF ; Unknown
    0x17000,  # .. 0x18AFF ; Tangut
    0x18B00,  # .. 0x18CD5 ; Khitan_Small_Script
    0x18CD6,  # .. 0x18CFE ; Unknown
    0x18CFF,  # .. 0x18CFF ; Khitan_Small_Script
    0x18D00,  # .. 0x18D1E ; Tangut
    0x18D1F,  # .. 0x18D7F ; Unknown
    0x18D80,  # .. 0x18DF2 ; Tangut
    0x18DF3,  # .. 0x1AFEF ; Unknown
    0x1AFF0,  # .. 0x1AFF3 ; Katakana
    0x1AFF4,  # .. 0x1AFF4 ; Unknown
    0x1AFF5,  # .. 0x1AFFB ; Katakana
    0x1AFFC,  # .. 0x1AFFC ; Unknown
    0x1AFFD,  # .. 0x1AFFE ; Katakana
    0x1AFFF,  # .. 0x1AFFF ; Unknown
    0x1B000,  # .. 0x1B000 ; Katakana
    0x1B001,  # .. 0x1B11F ; Hiragana
    0x1B120,  # .. 0x1B122 ; Katakana
    0x1B123,  # .. 0x1B131 ; Unknown
    0x1B132,  # .. 0x1B132 ; Hiragana
    0x1B133,  # .. 0x1B14F ; Unknown
    0x1B150,  # .. 0x1B152 ; Hiragana
    0x1B153,  # .. 0x1B154 ; Unknown
    0x1B155,  # .. 0x1B155 ; Katakana
    0x1B156,  # .. 0x1B163 ; Unknown
    0x1B164,  # .. 0x1B167 ; Katakana
    0x1B168,  # .. 0x1B16F ; Unknown
    0x1B170,  # .. 0x1B2FB ; Nushu
    0x1B2FC,  # .. 0x1BBFF ; Unknown
    0x1BC00,  # .. 0x1BC6A ; Duployan
    0x1BC6B,  # .. 0x1BC6F ; Unknown
    0x1BC70,  # .. 0x1BC7C ; Duployan
    0x1BC7D,  # .. 0x1BC7F ; Unknown
    0x1BC80,  # .. 0x1BC88 ; Duployan
    0x1BC89,  # .. 0x1BC8F ; Unknown
    0x1BC90,  # .. 0x1BC99 ; Duployan
    0x1BC9A,  # .. 0x1BC9B ; Unknown
    0x1BC9C,  # .. 0x1BC9F ; Duployan
    0x1BCA0,  # .. 0x1BCA3 ; Common
    0x1BCA4,  # .. 0x1CBFF ; Unknown
    0x1CC00,  # .. 0x1CCFC ; Common
    0x1CCFD,  # .. 0x1CCFF ; Unknown
    0x1CD00,  # .. 0x1CEB3 ; Common
    0x1CEB4,  # .. 0x1CEB9 ; Unknown
    0x1CEBA,  # .. 0x1CED0 ; Common
    0x1CED1,  # .. 0x1CEDF ; Unknown
    0x1CEE0,  # .. 0x1CEF0 ; Common
    0x1CEF1,  # .. 0x1CEFF ; Unknown
    0x1CF00,  # .. 0x1CF2D ; Inherited
    0x1CF2E,  # .. 0x1CF2F ; Unknown
    0x1CF30,  # .. 0x1CF46 ; Inherited
    0x1CF47,  # .. 0x1CF4F ; Unknown
    0x1CF50,  # .. 0x1CFC3 ; Common
    0x1CFC4,  # .. 0x1CFFF ; Unknown
    0x1D000,  # .. 0x1D0F5 ; Common
    0x1D0F6,  # .. 0x1D0FF ; Unknown
    0x1D100,  # .. 0x1D126 ; Common
    0x1D127,  # .. 0x1D128 ; Unknown
    0x1D129,  # .. 0x1D166 ; Common
    0x1D167,  # .. 0x1D169 ; Inherited
    0x1D16A,  # .. 0x1D17A ; Common
    0x1D17B,  # .. 0x1D182 ; Inherited
    0x1D183,  # .. 0x1D184 ; Common
    0x1D185,  # .. 0x1D18B ; Inherited
    0x1D18C,  # .. 0x1D1A9 ; Common
    0x1D1AA,  # .. 0x1D1AD ; Inherited
    0x1D1AE,  # .. 0x1D1EA ; Common
    0x1D1EB,  # .. 0x1D1FF ; Unknown
    0x1D200,  # .. 0x1D245 ; Greek
    0x1D246,  # .. 0x1D2BF ; Unknown
    0x1D2C0,  # .. 0x1D2D3 ; Common
    0x1D2D4,  # .. 0x1D2DF ; Unknown
    0x1D2E0,  # .. 0x1D2F3 ; Common
    0x1D2F4,  # .. 0x1D2FF ; Unknown
    0x1D300,  # .. 0x1D356 ; Common
    0x1D357,  # .. 0x1D35F ; Unknown
    0x1D360,  # .. 0x1D378 ; Common
    0x1D379,  # .. 0x1D3FF ; Unknown
    0x1D400,  # .. 0x1D454 ; Common
    0x1D455,  # .. 0x1D455 ; Unknown
    0x1D456,  # .. 0x1D49C ; Common
    0x1D49D,  # .. 0x1D49D ; Unknown
    0x1D49E,  # .. 0x1D49F ; Common
    0x1D4A0,  # .. 0x1D4A1 ; Unknown
    0x1D4A2,  # .. 0x1D4A2 ; Common
    0x1D4A3,  # .. 0x1D4A4 ; Unknown
    0x1D4A5,  # .. 0x1D4A6 ; Common
    0x1D4A7,  # .. 0x1D4A8 ; Unknown
    0x1D4A9,  # .. 0x1D4AC ; Common
    0x1D4AD,  # .. 0x1D4AD ; Unknown
    0x1D4AE,  # .. 0x1D4B9 ; Common
    0x1D4BA,  # .. 0x1D4BA ; Unknown
    0x1D4BB,  # .. 0x1D4BB ; Common
    0x1D4BC,  # .. 0x1D4BC ; Unknown
    0x1D4BD,  # .. 0x1D4C3 ; Common
    0x1D4C4,  # .. 0x1D4C4 ; Unknown
    0x1D4C5,  # .. 0x1D505 ; Common
    0x1D506,  # .. 0x1D506 ; Unknown
    0x1D507,  # .. 0x1D50A ; Common
    0x1D50B,  # .. 0x1D50C ; Unknown
    0x1D50D,  # .. 0x1D514 ; Common
    0x1D515,  # .. 0x1D515 ; Unknown
    0x1D516,  # .. 0x1D51C ; Common
    0x1D51D,  # .. 0x1D51D ; Unknown
    0x1D51E,  # .. 0x1D539 ; Common
    0x1D53A,  # .. 0x1D53A ; Unknown
    0x1D53B,  # .. 0x1D53E ; Common
    0x1D53F,  # .. 0x1D53F ; Unknown
    0x1D540,  # .. 0x1D544 ; Common
    0x1D545,  # .. 0x1D545 ; Unknown
    0x1D546,  # .. 0x1D546 ; Common
    0x1D547,  # .. 0x1D549 ; Unknown
    0x1D54A,  # .. 0x1D550 ; Common
    0x1D551,  # .. 0x1D551 ; Unknown
    0x1D552,  # .. 0x1D6A5 ; Common
    0x1D6A6,  # .. 0x1D6A7 ; Unknown
    0x1D6A8,  # .. 0x1D7CB ; Common
    0x1D7CC,  # .. 0x1D7CD ; Unknown
    0x1D7CE,  # .. 0x1D7FF ; Common
    0x1D800,  # .. 0x1DA8B ; SignWriting
    0x1DA8C,  # .. 0x1DA9A ; Unknown
    0x1DA9B,  # .. 0x1DA9F ; SignWriting
    0x1DAA0,  # .. 0x1DAA0 ; Unknown
    0x1DAA1,  # .. 0x1DAAF ; SignWriting
    0x1DAB0,  # .. 0x1DEFF ; Unknown
    0x1DF00,  # .. 0x1DF1E ; Latin
    0x1DF1F,  # .. 0x1DF24 ; Unknown
    0x1DF25,  # .. 0x1DF2A ; Latin
    0x1DF2B,  # .. 0x1DFFF ; Unknown
    0x1E000,  # .. 0x1E006 ; Glagolitic
    0x1E007,  # .. 0x1E007 ; Unknown
    0x1E008,  # .. 0x1E018 ; Glagolitic
    0x1E019,  # .. 0x1E01A ; Unknown
    0x1E01B,  # .. 0x1E021 ; Glagolitic
    0x1E022,  # .. 0x1E022 ; Unknown
    0x1E023,  # .. 0x1E024 ; Glagolitic
    0x1E025,  # .. 0x1E025 ; Unknown
    0x1E026,  # .. 0x1E02A ; Glagolitic
    0x1E02B,  # .. 0x1E02F ; Unknown
    0x1E030,  # .. 0x1E06D ; Cyrillic
    0x1E06E,  # .. 0x1E08E ; Unknown
    0x1E08F,  # .. 0x1E08F ; Cyrillic
    0x1E090,  # .. 0x1E0FF ; Unknown
    0x1E100,  # .. 0x1E12C ; Nyiakeng_Puachue_Hmong
    0x1E12D,  # .. 0x1E12F ; Unknown
    0x1E130,  # .. 0x1E13D ; Nyiakeng_Puachue_Hmong
    0x1E13E,  # .. 0x1E13F ; Unknown
    0x1E140,  # .. 0x1E149 ; Nyiakeng_Puachue_Hmong
    0x1E14A,  # .. 0x1E14D ; Unknown
    0x1E14E,  # .. 0x1E14F ; Nyiakeng_Puachue_Hmong
    0x1E150,  # .. 0x1E28F ; Unknown
    0x1E290,  # .. 0x1E2AE ; Toto
    0x1E2AF,  # .. 0x1E2BF ; Unknown
    0x1E2C0,  # .. 0x1E2F9 ; Wancho
    0x1E2FA,  # .. 0x1E2FE ; Unknown
    0x1E2FF,  # .. 0x1E2FF ; Wancho
    0x1E300,  # .. 0x1E4CF ; Unknown
    0x1E4D0,  # .. 0x1E4F9 ; Nag_Mundari
    0x1E4FA,  # .. 0x1E5CF ; Unknown
    0x1E5D0,  # .. 0x1E5FA ; Ol_Onal
    0x1E5FB,  # .. 0x1E5FE ; Unknown
    0x1E5FF,  # .. 0x1E5FF ; Ol_Onal
    0x1E600,  # .. 0x1E6BF ; Unknown
    0x1E6C0,  # .. 0x1E6DE ; Tai_Yo
    0x1E6DF,  # .. 0x1E6DF ; Unknown
    0x1E6E0,  # .. 0x1E6F5 ; Tai_Yo
    0x1E6F6,  # .. 0x1E6FD ; Unknown
    0x1E6FE,  # .. 0x1E6FF ; Tai_Yo
    0x1E700,  # .. 0x1E7DF ; Unknown
    0x1E7E0,  # .. 0x1E7E6 ; Ethiopic
    0x1E7E7,  # .. 0x1E7E7 ; Unknown
    0x1E7E8,  # .. 0x1E7EB ; Ethiopic
    0x1E7EC,  # .. 0x1E7EC ; Unknown
    0x1E7ED,  # .. 0x1E7EE ; Ethiopic
    0x1E7EF,  # .. 0x1E7EF ; Unknown
    0x1E7F0,  # .. 0x1E7FE ; Ethiopic
    0x1E7FF,  # .. 0x1E7FF ; Unknown
    0x1E800,  # .. 0x1E8C4 ; Mende_Kikakui
    0x1E8C5,  # .. 0x1E8C6 ; Unknown
    0x1E8C7,  # .. 0x1E8D6 ; Mende_Kikakui
    0x1E8D7,  # .. 0x1E8FF ; Unknown
    0x1E900,  # .. 0x1E94B ; Adlam
    0x1E94C,  # .. 0x1E94F ; Unknown
    0x1E950,  # .. 0x1E959 ; Adlam
    0x1E95A,  # .. 0x1E95D ; Unknown
    0x1E95E,  # .. 0x1E95F ; Adlam
    0x1E960,  # .. 0x1EC70 ; Unknown
    0x1EC71,  # .. 0x1ECB4 ; Common
    0x1ECB5,  # .. 0x1ED00 ; Unknown
    0x1ED01,  # .. 0x1ED3D ; Common
    0x1ED3E,  # .. 0x1EDFF ; Unknown
    0x1EE00,  # .. 0x1EE03 ; Arabic
    0x1EE04,  # .. 0x1EE04 ; Unknown
    0x1EE05,  # .. 0x1EE1F ; Arabic
    0x1EE20,  # .. 0x1EE20 ; Unknown
    0x1EE21,  # .. 0x1EE22 ; Arabic
    0x1EE23,  # .. 0x1EE23 ; Unknown
    0x1EE24,  # .. 0x1EE24 ; Arabic
    0x1EE25,  # .. 0x1EE26 ; Unknown
    0x1EE27,  # .. 0x1EE27 ; Arabic
    0x1EE28,  # .. 0x1EE28 ; Unknown
    0x1EE29,  # .. 0x1EE32 ; Arabic
    0x1EE33,  # .. 0x1EE33 ; Unknown
    0x1EE34,  # .. 0x1EE37 ; Arabic
    0x1EE38,  # .. 0x1EE38 ; Unknown
    0x1EE39,  # .. 0x1EE39 ; Arabic
    0x1EE3A,  # .. 0x1EE3A ; Unknown
    0x1EE3B,  # .. 0x1EE3B ; Arabic
    0x1EE3C,  # .. 0x1EE41 ; Unknown
    0x1EE42,  # .. 0x1EE42 ; Arabic
    0x1EE43,  # .. 0x1EE46 ; Unknown
    0x1EE47,  # .. 0x1EE47 ; Arabic
    0x1EE48,  # .. 0x1EE48 ; Unknown
    0x1EE49,  # .. 0x1EE49 ; Arabic
    0x1EE4A,  # .. 0x1EE4A ; Unknown
    0x1EE4B,  # .. 0x1EE4B ; Arabic
    0x1EE4C,  # .. 0x1EE4C ; Unknown
    0x1EE4D,  # .. 0x1EE4F ; Arabic
    0x1EE50,  # .. 0x1EE50 ; Unknown
    0x1EE51,  # .. 0x1EE52 ; Arabic
    0x1EE53,  # .. 0x1EE53 ; Unknown
    0x1EE54,  # .. 0x1EE54 ; Arabic
    0x1EE55,  # .. 0x1EE56 ; Unknown
    0x1EE57,  # .. 0x1EE57 ; Arabic
    0x1EE58,  # .. 0x1EE58 ; Unknown
    0x1EE59,  # .. 0x1EE59 ; Arabic
    0x1EE5A,  # .. 0x1EE5A ; Unknown
    0x1EE5B,  # .. 0x1EE5B ; Arabic
    0x1EE5C,  # .. 0x1EE5C ; Unknown
    0x1EE5D,  # .. 0x1EE5D ; Arabic
    0x1EE5E,  # .. 0x1EE5E ; Unknown
    0x1EE5F,  # .. 0x1EE5F ; Arabic
    0x1EE60,  # .. 0x1EE60 ; Unknown
    0x1EE61,  # .. 0x1EE62 ; Arabic
    0x1EE63,  # .. 0x1EE63 ; Unknown
    0x1EE64,  # .. 0x1EE64 ; Arabic
    0x1EE65,  # .. 0x1EE66 ; Unknown
    0x1EE67,  # .. 0x1EE6A ; Arabic
    0x1EE6B,  # .. 0x1EE6B ; Unknown
    0x1EE6C,  # .. 0x1EE72 ; Arabic
    0x1EE73,  # .. 0x1EE73 ; Unknown
    0x1EE74,  # .. 0x1EE77 ; Arabic
    0x1EE78,  # .. 0x1EE78 ; Unknown
    0x1EE79,  # .. 0x1EE7C ; Arabic
    0x1EE7D,  # .. 0x1EE7D ; Unknown
    0x1EE7E,  # .. 0x1EE7E ; Arabic
    0x1EE7F,  # .. 0x1EE7F ; Unknown
    0x1EE80,  # .. 0x1EE89 ; Arabic
    0x1EE8A,  # .. 0x1EE8A ; Unknown
    0x1EE8B,  # .. 0x1EE9B ; Arabic
    0x1EE9C,  # .. 0x1EEA0 ; Unknown
    0x1EEA1,  # .. 0x1EEA3 ; Arabic
    0x1EEA4,  # .. 0x1EEA4 ; Unknown
    0x1EEA5,  # .. 0x1EEA9 ; Arabic
    0x1EEAA,  # .. 0x1EEAA ; Unknown
    0x1EEAB,  # .. 0x1EEBB ; Arabic
    0x1EEBC,  # .. 0x1EEEF ; Unknown
    0x1EEF0,  # .. 0x1EEF1 ; Arabic
    0x1EEF2,  # .. 0x1EFFF ; Unknown
    0x1F000,  # .. 0x1F02B ; Common
    0x1F02C,  # .. 0x1F02F ; Unknown
    0x1F030,  # .. 0x1F093 ; Common
    0x1F094,  # .. 0x1F09F ; Unknown
    0x1F0A0,  # .. 0x1F0AE ; Common
    0x1F0AF,  # .. 0x1F0B0 ; Unknown
    0x1F0B1,  # .. 0x1F0BF ; Common
    0x1F0C0,  # .. 0x1F0C0 ; Unknown
    0x1F0C1,  # .. 0x1F0CF ; Common
    0x1F0D0,  # .. 0x1F0D0 ; Unknown
    0x1F0D1,  # .. 0x1F0F5 ; Common
    0x1F0F6,  # .. 0x1F0FF ; Unknown
    0x1F100,  # .. 0x1F1AD ; Common
    0x1F1AE,  # .. 0x1F1E5 ; Unknown
    0x1F1E6,  # .. 0x1F1FF ; Common
    0x1F200,  # .. 0x1F200 ; Hiragana
    0x1F201,  # .. 0x1F202 ; Common
    0x1F203,  # .. 0x1F20F ; Unknown
    0x1F210,  # .. 0x1F23B ; Common
    0x1F23C,  # .. 0x1F23F ; Unknown
    0x1F240,  # .. 0x1F248 ; Common
    0x1F249,  # .. 0x1F24F ; Unknown
    0x1F250,  # .. 0x1F251 ; Common
    0x1F252,  # .. 0x1F25F ; Unknown
    0x1F260,  # .. 0x1F265 ; Common
    0x1F266,  # .. 0x1F2FF ; Unknown
    0x1F300,  # .. 0x1F6D8 ; Common
    0x1F6D9,  # .. 0x1F6DB ; Unknown
    0x1F6DC,  # .. 0x1F6EC ; Common
    0x1F6ED,  # .. 0x1F6EF ; Unknown
    0x1F6F0,  # .. 0x1F6FC ; Common
    0x1F6FD,  # .. 0x1F6FF ; Unknown
    0x1F700,  # .. 0x1F7D9 ; Common
    0x1F7DA,  # .. 0x1F7DF ; Unknown
    0x1F7E0,  # .. 0x1F7EB ; Common
    0x1F7EC,  # .. 0x1F7EF ; Unknown
    0x1F7F0,  # .. 0x1F7F0 ; Common
    0x1F7F1,  # .. 0x1F7FF ; Unknown
    0x1F800,  # .. 0x1F80B ; Common
    0x1F80C,  # .. 0x1F80F ; Unknown
    0x1F810,  # .. 0x1F847 ; Common
    0x1F848,  # .. 0x1F84F ; Unknown
    0x1F850,  # .. 0x1F859 ; Common
    0x1F85A,  # .. 0x1F85F ; Unknown
    0x1F860,  # .. 0x1F887 ; Common
    0x1F888,  # .. 0x1F88F ; Unknown
    0x1F890,  # .. 0x1F8AD ; Common
    0x1F8AE,  # .. 0x1F8AF ; Unknown
    0x1F8B0,  # .. 0x1F8BB ; Common
    0x1F8BC,  # .. 0x1F8BF ; Unknown
    0x1F8C0,  # .. 0x1F8C1 ; Common
    0x1F8C2,  # .. 0x1F8CF ; Unknown
    0x1F8D0,  # .. 0x1F8D8 ; Common
    0x1F8D9,  # .. 0x1F8FF ; Unknown
    0x1F900,  # .. 0x1FA57 ; Common
    0x1FA58,  # .. 0x1FA5F ; Unknown
    0x1FA60,  # .. 0x1FA6D ; Common
    0x1FA6E,  # .. 0x1FA6F ; Unknown
    0x1FA70,  # .. 0x1FA7C ; Common
    0x1FA7D,  # .. 0x1FA7F ; Unknown
    0x1FA80,  # .. 0x1FA8A ; Common
    0x1FA8B,  # .. 0x1FA8D ; Unknown
    0x1FA8E,  # .. 0x1FAC6 ; Common
    0x1FAC7,  # .. 0x1FAC7 ; Unknown
    0x1FAC8,  # .. 0x1FAC8 ; Common
    0x1FAC9,  # .. 0x1FACC ; Unknown
    0x1FACD,  # .. 0x1FADC ; Common
    0x1FADD,  # .. 0x1FADE ; Unknown
    0x1FADF,  # .. 0x1FAEA ; Common
    0x1FAEB,  # .. 0x1FAEE ; Unknown
    0x1FAEF,  # .. 0x1FAF8 ; Common
    0x1FAF9,  # .. 0x1FAFF ; Unknown
    0x1FB00,  # .. 0x1FB92 ; Common
    0x1FB93,  # .. 0x1FB93 ; Unknown
    0x1FB94,  # .. 0x1FBFA ; Common
    0x1FBFB,  # .. 0x1FFFF ; Unknown
    0x20000,  # .. 0x2A6DF ; Han
    0x2A6E0,  # .. 0x2A6FF ; Unknown
    0x2A700,  # .. 0x2B81D ; Han
    0x2B81E,  # .. 0x2B81F ; Unknown
    0x2B820,  # .. 0x2CEAD ; Han
    0x2CEAE,  # .. 0x2CEAF ; Unknown
    0x2CEB0,  # .. 0x2EBE0 ; Han
    0x2EBE1,  # .. 0x2EBEF ; Unknown
    0x2EBF0,  # .. 0x2EE5D ; Han
    0x2EE5E,  # .. 0x2F7FF ; Unknown
    0x2F800,  # .. 0x2FA1D ; Han
    0x2FA1E,  # .. 0x2FFFF ; Unknown
    0x30000,  # .. 0x3134A ; Han
    0x3134B,  # .. 0x3134F ; Unknown
    0x31350,  # .. 0x33479 ; Han
    0x3347A,  # .. 0xE0000 ; Unknown
    0xE0001,  # .. 0xE0001 ; Common
    0xE0002,  # .. 0xE001F ; Unknown
    0xE0020,  # .. 0xE007F ; Common
    0xE0080,  # .. 0xE00FF ; Unknown
    0xE0100,  # .. 0xE01EF ; Inherited
    0xE01F0,  # .. 0x10FFFF ; Unknown
]

VALUES = [
    "Zyyy",  # 0000..0040 ; Common
    "Latn",  # 0041..005A ; Latin
    "Zyyy",  # 005B..0060 ; Common
    "Latn",  # 0061..007A ; Latin
    "Zyyy",  # 007B..00A9 ; Common
    "Latn",  # 00AA..00AA ; Latin
    "Zyyy",  # 00AB..00B9 ; Common
    "Latn",  # 00BA..00BA ; Latin
    "Zyyy",  # 00BB..00BF ; Common
    "Latn",  # 00C0..00D6 ; Latin
    "Zyyy",  # 00D7..00D7 ; Common
    "Latn",  # 00D8..00F6 ; Latin
    "Zyyy",  # 00F7..00F7 ; Common
    "Latn",  # 00F8..02B8 ; Latin
    "Zyyy",  # 02B9..02DF ; Common
    "Latn",  # 02E0..02E4 ; Latin
    "Zyyy",  # 02E5..02E9 ; Common
    "Bopo",  # 02EA..02EB ; Bopomofo
    "Zyyy",  # 02EC..02FF ; Common
    "Zinh",  # 0300..036F ; Inherited
    "Grek",  # 0370..0373 ; Greek
    "Zyyy",  # 0374..0374 ; Common
    "Grek",  # 0375..0377 ; Greek
    "Zzzz",  # 0378..0379 ; Unknown
    "Grek",  # 037A..037D ; Greek
    "Zyyy",  # 037E..037E ; Common
    "Grek",  # 037F..037F ; Greek
    "Zzzz",  # 0380..0383 ; Unknown
    "Grek",  # 0384..0384 ; Greek
    "Zyyy",  # 0385..0385 ; Common
    "Grek",  # 0386..0386 ; Greek
    "Zyyy",  # 0387..0387 ; Common
    "Grek",  # 0388..038A ; Greek
    "Zzzz",  # 038B..038B ; Unknown
    "Grek",  # 038C..038C ; Greek
    "Zzzz",  # 038D..038D ; Unknown
    "Grek",  # 038E..03A1 ; Greek
    "Zzzz",  # 03A2..03A2 ; Unknown
    "Grek",  # 03A3..03E1 ; Greek
    "Copt",  # 03E2..03EF ; Coptic
    "Grek",  # 03F0..03FF ; Greek
    "Cyrl",  # 0400..0484 ; Cyrillic
    "Zinh",  # 0485..0486 ; Inherited
    "Cyrl",  # 0487..052F ; Cyrillic
    "Zzzz",  # 0530..0530 ; Unknown
    "Armn",  # 0531..0556 ; Armenian
    "Zzzz",  # 0557..0558 ; Unknown
    "Armn",  # 0559..058A ; Armenian
    "Zzzz",  # 058B..058C ; Unknown
    "Armn",  # 058D..058F ; Armenian
    "Zzzz",  # 0590..0590 ; Unknown
    "Hebr",  # 0591..05C7 ; Hebrew
    "Zzzz",  # 05C8..05CF ; Unknown
    "Hebr",  # 05D0..05EA ; Hebrew
    "Zzzz",  # 05EB..05EE ; Unknown
    "Hebr",  # 05EF..05F4 ; Hebrew
    "Zzzz",  # 05F5..05FF ; Unknown
    "Arab",  # 0600..0604 ; Arabic
    "Zyyy",  # 0605..0605 ; Common
    "Arab",  # 0606..060B ; Arabic
    "Zyyy",  # 060C..060C ; Common
    "Arab",  # 060D..061A ; Arabic
    "Zyyy",  # 061B..061B ; Common
    "Arab",  # 061C..061E ; Arabic
    "Zyyy",  # 061F..061F ; Common
    "Arab",  # 0620..063F ; Arabic
    "Zyyy",  # 0640..0640 ; Common
    "Arab",  # 0641..064A ; Arabic
    "Zinh",  # 064B..0655 ; Inherited
    "Arab",  # 0656..066F ; Arabic
    "Zinh",  # 0670..0670 ; Inherited
    "Arab",  # 0671..06DC ; Arabic
    "Zyyy",  # 06DD..06DD ; Common
    "Arab",  # 06DE..06FF ; Arabic
    "Syrc",  # 0700..070D ; Syriac
    "Zzzz",  # 070E..070E ; Unknown
    "Syrc",  # 070F..074A ; Syriac
    "Zzzz",  # 074B..074C ; Unknown
    "Syrc",  # 074D..074F ; Syriac
    "Arab",  # 0750..077F ; Arabic
    "Thaa",  # 0780..07B1 ; Thaana
    "Zzzz",  # 07B2..07BF ; Unknown
    "Nkoo",  # 07C0..07FA ; Nko
    "Zzzz",  # 07FB..07FC ; Unknown
    "Nkoo",  # 07FD..07FF ; Nko
    "Samr",  # 0800..082D ; Samaritan
    "Zzzz",  # 082E..082F ; Unknown
    "Samr",  # 0830..083E ; Samaritan
    "Zzzz",  # 083F..083F ; Unknown
    "Mand",  # 0840..085B ; Mandaic
    "Zzzz",  # 085C..085D ; Unknown
    "Mand",  # 085E..085E ; Mandaic
    "Zzzz",  # 085F..085F ; Unknown
    "Syrc",  # 0860..086A ; Syriac
    "Zzzz",  # 086B..086F ; Unknown
    "Arab",  # 0870..0891 ; Arabic
    "Zzzz",  # 0892..0896 ; Unknown
    "Arab",  # 0897..08E1 ; Arabic
    "Zyyy",  # 08E2..08E2 ; Common
    "Arab",  # 08E3..08FF ; Arabic
    "Deva",  # 0900..0950 ; Devanagari
    "Zinh",  # 0951..0954 ; Inherited
    "Deva",  # 0955..0963 ; Devanagari
    "Zyyy",  # 0964..0965 ; Common
    "Deva",  # 0966..097F ; Devanagari
    "Beng",  # 0980..0983 ; Bengali
    "Zzzz",  # 0984..0984 ; Unknown
    "Beng",  # 0985..098C ; Bengali
    "Zzzz",  # 098D..098E ; Unknown
    "Beng",  # 098F..0990 ; Bengali
    "Zzzz",  # 0991..0992 ; Unknown
    "Beng",  # 0993..09A8 ; Bengali
    "Zzzz",  # 09A9..09A9 ; Unknown
    "Beng",  # 09AA..09B0 ; Bengali
    "Zzzz",  # 09B1..09B1 ; Unknown
    "Beng",  # 09B2..09B2 ; Bengali
    "Zzzz",  # 09B3..09B5 ; Unknown
    "Beng",  # 09B6..09B9 ; Bengali
    "Zzzz",  # 09BA..09BB ; Unknown
    "Beng",  # 09BC..09C4 ; Bengali
    "Zzzz",  # 09C5..09C6 ; Unknown
    "Beng",  # 09C7..09C8 ; Bengali
    "Zzzz",  # 09C9..09CA ; Unknown
    "Beng",  # 09CB..09CE ; Bengali
    "Zzzz",  # 09CF..09D6 ; Unknown
    "Beng",  # 09D7..09D7 ; Bengali
    "Zzzz",  # 09D8..09DB ; Unknown
    "Beng",  # 09DC..09DD ; Bengali
    "Zzzz",  # 09DE..09DE ; Unknown
    "Beng",  # 09DF..09E3 ; Bengali
    "Zzzz",  # 09E4..09E5 ; Unknown
    "Beng",  # 09E6..09FE ; Bengali
    "Zzzz",  # 09FF..0A00 ; Unknown
    "Guru",  # 0A01..0A03 ; Gurmukhi
    "Zzzz",  # 0A04..0A04 ; Unknown
    "Guru",  # 0A05..0A0A ; Gurmukhi
    "Zzzz",  # 0A0B..0A0E ; Unknown
    "Guru",  # 0A0F..0A10 ; Gurmukhi
    "Zzzz",  # 0A11..0A12 ; Unknown
    "Guru",  # 0A13..0A28 ; Gurmukhi
    "Zzzz",  # 0A29..0A29 ; Unknown
    "Guru",  # 0A2A..0A30 ; Gurmukhi
    "Zzzz",  # 0A31..0A31 ; Unknown
    "Guru",  # 0A32..0A33 ; Gurmukhi
    "Zzzz",  # 0A34..0A34 ; Unknown
    "Guru",  # 0A35..0A36 ; Gurmukhi
    "Zzzz",  # 0A37..0A37 ; Unknown
    "Guru",  # 0A38..0A39 ; Gurmukhi
    "Zzzz",  # 0A3A..0A3B ; Unknown
    "Guru",  # 0A3C..0A3C ; Gurmukhi
    "Zzzz",  # 0A3D..0A3D ; Unknown
    "Guru",  # 0A3E..0A42 ; Gurmukhi
    "Zzzz",  # 0A43..0A46 ; Unknown
    "Guru",  # 0A47..0A48 ; Gurmukhi
    "Zzzz",  # 0A49..0A4A ; Unknown
    "Guru",  # 0A4B..0A4D ; Gurmukhi
    "Zzzz",  # 0A4E..0A50 ; Unknown
    "Guru",  # 0A51..0A51 ; Gurmukhi
    "Zzzz",  # 0A52..0A58 ; Unknown
    "Guru",  # 0A59..0A5C ; Gurmukhi
    "Zzzz",  # 0A5D..0A5D ; Unknown
    "Guru",  # 0A5E..0A5E ; Gurmukhi
    "Zzzz",  # 0A5F..0A65 ; Unknown
    "Guru",  # 0A66..0A76 ; Gurmukhi
    "Zzzz",  # 0A77..0A80 ; Unknown
    "Gujr",  # 0A81..0A83 ; Gujarati
    "Zzzz",  # 0A84..0A84 ; Unknown
    "Gujr",  # 0A85..0A8D ; Gujarati
    "Zzzz",  # 0A8E..0A8E ; Unknown
    "Gujr",  # 0A8F..0A91 ; Gujarati
    "Zzzz",  # 0A92..0A92 ; Unknown
    "Gujr",  # 0A93..0AA8 ; Gujarati
    "Zzzz",  # 0AA9..0AA9 ; Unknown
    "Gujr",  # 0AAA..0AB0 ; Gujarati
    "Zzzz",  # 0AB1..0AB1 ; Unknown
    "Gujr",  # 0AB2..0AB3 ; Gujarati
    "Zzzz",  # 0AB4..0AB4 ; Unknown
    "Gujr",  # 0AB5..0AB9 ; Gujarati
    "Zzzz",  # 0ABA..0ABB ; Unknown
    "Gujr",  # 0ABC..0AC5 ; Gujarati
    "Zzzz",  # 0AC6..0AC6 ; Unknown
    "Gujr",  # 0AC7..0AC9 ; Gujarati
    "Zzzz",  # 0ACA..0ACA ; Unknown
    "Gujr",  # 0ACB..0ACD ; Gujarati
    "Zzzz",  # 0ACE..0ACF ; Unknown
    "Gujr",  # 0AD0..0AD0 ; Gujarati
    "Zzzz",  # 0AD1..0ADF ; Unknown
    "Gujr",  # 0AE0..0AE3 ; Gujarati
    "Zzzz",  # 0AE4..0AE5 ; Unknown
    "Gujr",  # 0AE6..0AF1 ; Gujarati
    "Zzzz",  # 0AF2..0AF8 ; Unknown
    "Gujr",  # 0AF9..0AFF ; Gujarati
    "Zzzz",  # 0B00..0B00 ; Unknown
    "Orya",  # 0B01..0B03 ; Oriya
    "Zzzz",  # 0B04..0B04 ; Unknown
    "Orya",  # 0B05..0B0C ; Oriya
    "Zzzz",  # 0B0D..0B0E ; Unknown
    "Orya",  # 0B0F..0B10 ; Oriya
    "Zzzz",  # 0B11..0B12 ; Unknown
    "Orya",  # 0B13..0B28 ; Oriya
    "Zzzz",  # 0B29..0B29 ; Unknown
    "Orya",  # 0B2A..0B30 ; Oriya
    "Zzzz",  # 0B31..0B31 ; Unknown
    "Orya",  # 0B32..0B33 ; Oriya
    "Zzzz",  # 0B34..0B34 ; Unknown
    "Orya",  # 0B35..0B39 ; Oriya
    "Zzzz",  # 0B3A..0B3B ; Unknown
    "Orya",  # 0B3C..0B44 ; Oriya
    "Zzzz",  # 0B45..0B46 ; Unknown
    "Orya",  # 0B47..0B48 ; Oriya
    "Zzzz",  # 0B49..0B4A ; Unknown
    "Orya",  # 0B4B..0B4D ; Oriya
    "Zzzz",  # 0B4E..0B54 ; Unknown
    "Orya",  # 0B55..0B57 ; Oriya
    "Zzzz",  # 0B58..0B5B ; Unknown
    "Orya",  # 0B5C..0B5D ; Oriya
    "Zzzz",  # 0B5E..0B5E ; Unknown
    "Orya",  # 0B5F..0B63 ; Oriya
    "Zzzz",  # 0B64..0B65 ; Unknown
    "Orya",  # 0B66..0B77 ; Oriya
    "Zzzz",  # 0B78..0B81 ; Unknown
    "Taml",  # 0B82..0B83 ; Tamil
    "Zzzz",  # 0B84..0B84 ; Unknown
    "Taml",  # 0B85..0B8A ; Tamil
    "Zzzz",  # 0B8B..0B8D ; Unknown
    "Taml",  # 0B8E..0B90 ; Tamil
    "Zzzz",  # 0B91..0B91 ; Unknown
    "Taml",  # 0B92..0B95 ; Tamil
    "Zzzz",  # 0B96..0B98 ; Unknown
    "Taml",  # 0B99..0B9A ; Tamil
    "Zzzz",  # 0B9B..0B9B ; Unknown
    "Taml",  # 0B9C..0B9C ; Tamil
    "Zzzz",  # 0B9D..0B9D ; Unknown
    "Taml",  # 0B9E..0B9F ; Tamil
    "Zzzz",  # 0BA0..0BA2 ; Unknown
    "Taml",  # 0BA3..0BA4 ; Tamil
    "Zzzz",  # 0BA5..0BA7 ; Unknown
    "Taml",  # 0BA8..0BAA ; Tamil
    "Zzzz",  # 0BAB..0BAD ; Unknown
    "Taml",  # 0BAE..0BB9 ; Tamil
    "Zzzz",  # 0BBA..0BBD ; Unknown
    "Taml",  # 0BBE..0BC2 ; Tamil
    "Zzzz",  # 0BC3..0BC5 ; Unknown
    "Taml",  # 0BC6..0BC8 ; Tamil
    "Zzzz",  # 0BC9..0BC9 ; Unknown
    "Taml",  # 0BCA..0BCD ; Tamil
    "Zzzz",  # 0BCE..0BCF ; Unknown
    "Taml",  # 0BD0..0BD0 ; Tamil
    "Zzzz",  # 0BD1..0BD6 ; Unknown
    "Taml",  # 0BD7..0BD7 ; Tamil
    "Zzzz",  # 0BD8..0BE5 ; Unknown
    "Taml",  # 0BE6..0BFA ; Tamil
    "Zzzz",  # 0BFB..0BFF ; Unknown
    "Telu",  # 0C00..0C0C ; Telugu
    "Zzzz",  # 0C0D..0C0D ; Unknown
    "Telu",  # 0C0E..0C10 ; Telugu
    "Zzzz",  # 0C11..0C11 ; Unknown
    "Telu",  # 0C12..0C28 ; Telugu
    "Zzzz",  # 0C29..0C29 ; Unknown
    "Telu",  # 0C2A..0C39 ; Telugu
    "Zzzz",  # 0C3A..0C3B ; Unknown
    "Telu",  # 0C3C..0C44 ; Telugu
    "Zzzz",  # 0C45..0C45 ; Unknown
    "Telu",  # 0C46..0C48 ; Telugu
    "Zzzz",  # 0C49..0C49 ; Unknown
    "Telu",  # 0C4A..0C4D ; Telugu
    "Zzzz",  # 0C4E..0C54 ; Unknown
    "Telu",  # 0C55..0C56 ; Telugu
    "Zzzz",  # 0C57..0C57 ; Unknown
    "Telu",  # 0C58..0C5A ; Telugu
    "Zzzz",  # 0C5B..0C5B ; Unknown
    "Telu",  # 0C5C..0C5D ; Telugu
    "Zzzz",  # 0C5E..0C5F ; Unknown
    "Telu",  # 0C60..0C63 ; Telugu
    "Zzzz",  # 0C64..0C65 ; Unknown
    "Telu",  # 0C66..0C6F ; Telugu
    "Zzzz",  # 0C70..0C76 ; Unknown
    "Telu",  # 0C77..0C7F ; Telugu
    "Knda",  # 0C80..0C8C ; Kannada
    "Zzzz",  # 0C8D..0C8D ; Unknown
    "Knda",  # 0C8E..0C90 ; Kannada
    "Zzzz",  # 0C91..0C91 ; Unknown
    "Knda",  # 0C92..0CA8 ; Kannada
    "Zzzz",  # 0CA9..0CA9 ; Unknown
    "Knda",  # 0CAA..0CB3 ; Kannada
    "Zzzz",  # 0CB4..0CB4 ; Unknown
    "Knda",  # 0CB5..0CB9 ; Kannada
    "Zzzz",  # 0CBA..0CBB ; Unknown
    "Knda",  # 0CBC..0CC4 ; Kannada
    "Zzzz",  # 0CC5..0CC5 ; Unknown
    "Knda",  # 0CC6..0CC8 ; Kannada
    "Zzzz",  # 0CC9..0CC9 ; Unknown
    "Knda",  # 0CCA..0CCD ; Kannada
    "Zzzz",  # 0CCE..0CD4 ; Unknown
    "Knda",  # 0CD5..0CD6 ; Kannada
    "Zzzz",  # 0CD7..0CDB ; Unknown
    "Knda",  # 0CDC..0CDE ; Kannada
    "Zzzz",  # 0CDF..0CDF ; Unknown
    "Knda",  # 0CE0..0CE3 ; Kannada
    "Zzzz",  # 0CE4..0CE5 ; Unknown
    "Knda",  # 0CE6..0CEF ; Kannada
    "Zzzz",  # 0CF0..0CF0 ; Unknown
    "Knda",  # 0CF1..0CF3 ; Kannada
    "Zzzz",  # 0CF4..0CFF ; Unknown
    "Mlym",  # 0D00..0D0C ; Malayalam
    "Zzzz",  # 0D0D..0D0D ; Unknown
    "Mlym",  # 0D0E..0D10 ; Malayalam
    "Zzzz",  # 0D11..0D11 ; Unknown
    "Mlym",  # 0D12..0D44 ; Malayalam
    "Zzzz",  # 0D45..0D45 ; Unknown
    "Mlym",  # 0D46..0D48 ; Malayalam
    "Zzzz",  # 0D49..0D49 ; Unknown
    "Mlym",  # 0D4A..0D4F ; Malayalam
    "Zzzz",  # 0D50..0D53 ; Unknown
    "Mlym",  # 0D54..0D63 ; Malayalam
    "Zzzz",  # 0D64..0D65 ; Unknown
    "Mlym",  # 0D66..0D7F ; Malayalam
    "Zzzz",  # 0D80..0D80 ; Unknown
    "Sinh",  # 0D81..0D83 ; Sinhala
    "Zzzz",  # 0D84..0D84 ; Unknown
    "Sinh",  # 0D85..0D96 ; Sinhala
    "Zzzz",  # 0D97..0D99 ; Unknown
    "Sinh",  # 0D9A..0DB1 ; Sinhala
    "Zzzz",  # 0DB2..0DB2 ; Unknown
    "Sinh",  # 0DB3..0DBB ; Sinhala
    "Zzzz",  # 0DBC..0DBC ; Unknown
    "Sinh",  # 0DBD..0DBD ; Sinhala
    "Zzzz",  # 0DBE..0DBF ; Unknown
    "Sinh",  # 0DC0..0DC6 ; Sinhala
    "Zzzz",  # 0DC7..0DC9 ; Unknown
    "Sinh",  # 0DCA..0DCA ; Sinhala
    "Zzzz",  # 0DCB..0DCE ; Unknown
    "Sinh",  # 0DCF..0DD4 ; Sinhala
    "Zzzz",  # 0DD5..0DD5 ; Unknown
    "Sinh",  # 0DD6..0DD6 ; Sinhala
    "Zzzz",  # 0DD7..0DD7 ; Unknown
    "Sinh",  # 0DD8..0DDF ; Sinhala
    "Zzzz",  # 0DE0..0DE5 ; Unknown
    "Sinh",  # 0DE6..0DEF ; Sinhala
    "Zzzz",  # 0DF0..0DF1 ; Unknown
    "Sinh",  # 0DF2..0DF4 ; Sinhala
    "Zzzz",  # 0DF5..0E00 ; Unknown
    "Thai",  # 0E01..0E3A ; Thai
    "Zzzz",  # 0E3B..0E3E ; Unknown
    "Zyyy",  # 0E3F..0E3F ; Common
    "Thai",  # 0E40..0E5B ; Thai
    "Zzzz",  # 0E5C..0E80 ; Unknown
    "Laoo",  # 0E81..0E82 ; Lao
    "Zzzz",  # 0E83..0E83 ; Unknown
    "Laoo",  # 0E84..0E84 ; Lao
    "Zzzz",  # 0E85..0E85 ; Unknown
    "Laoo",  # 0E86..0E8A ; Lao
    "Zzzz",  # 0E8B..0E8B ; Unknown
    "Laoo",  # 0E8C..0EA3 ; Lao
    "Zzzz",  # 0EA4..0EA4 ; Unknown
    "Laoo",  # 0EA5..0EA5 ; Lao
    "Zzzz",  # 0EA6..0EA6 ; Unknown
    "Laoo",  # 0EA7..0EBD ; Lao
    "Zzzz",  # 0EBE..0EBF ; Unknown
    "Laoo",  # 0EC0..0EC4 ; Lao
    "Zzzz",  # 0EC5..0EC5 ; Unknown
    "Laoo",  # 0EC6..0EC6 ; Lao
    "Zzzz",  # 0EC7..0EC7 ; Unknown
    "Laoo",  # 0EC8..0ECE ; Lao
    "Zzzz",  # 0ECF..0ECF ; Unknown
    "Laoo",  # 0ED0..0ED9 ; Lao
    "Zzzz",  # 0EDA..0EDB ; Unknown
    "Laoo",  # 0EDC..0EDF ; Lao
    "Zzzz",  # 0EE0..0EFF ; Unknown
    "Tibt",  # 0F00..0F47 ; Tibetan
    "Zzzz",  # 0F48..0F48 ; Unknown
    "Tibt",  # 0F49..0F6C ; Tibetan
    "Zzzz",  # 0F6D..0F70 ; Unknown
    "Tibt",  # 0F71..0F97 ; Tibetan
    "Zzzz",  # 0F98..0F98 ; Unknown
    "Tibt",  # 0F99..0FBC ; Tibetan
    "Zzzz",  # 0FBD..0FBD ; Unknown
    "Tibt",  # 0FBE..0FCC ; Tibetan
    "Zzzz",  # 0FCD..0FCD ; Unknown
    "Tibt",  # 0FCE..0FD4 ; Tibetan
    "Zyyy",  # 0FD5..0FD8 ; Common
    "Tibt",  # 0FD9..0FDA ; Tibetan
    "Zzzz",  # 0FDB..0FFF ; Unknown
    "Mymr",  # 1000..109F ; Myanmar
    "Geor",  # 10A0..10C5 ; Georgian
    "Zzzz",  # 10C6..10C6 ; Unknown
    "Geor",  # 10C7..10C7 ; Georgian
    "Zzzz",  # 10C8..10CC ; Unknown
    "Geor",  # 10CD..10CD ; Georgian
    "Zzzz",  # 10CE..10CF ; Unknown
    "Geor",  # 10D0..10FA ; Georgian
    "Zyyy",  # 10FB..10FB ; Common
    "Geor",  # 10FC..10FF ; Georgian
    "Hang",  # 1100..11FF ; Hangul
    "Ethi",  # 1200..1248 ; Ethiopic
    "Zzzz",  # 1249..1249 ; Unknown
    "Ethi",  # 124A..124D ; Ethiopic
    "Zzzz",  # 124E..124F ; Unknown
    "Ethi",  # 1250..1256 ; Ethiopic
    "Zzzz",  # 1257..1257 ; Unknown
    "Ethi",  # 1258..1258 ; Ethiopic
    "Zzzz",  # 1259..1259 ; Unknown
    "Ethi",  # 125A..125D ; Ethiopic
    "Zzzz",  # 125E..125F ; Unknown
    "Ethi",  # 1260..1288 ; Ethiopic
    "Zzzz",  # 1289..1289 ; Unknown
    "Ethi",  # 128A..128D ; Ethiopic
    "Zzzz",  # 128E..128F ; Unknown
    "Ethi",  # 1290..12B0 ; Ethiopic
    "Zzzz",  # 12B1..12B1 ; Unknown
    "Ethi",  # 12B2..12B5 ; Ethiopic
    "Zzzz",  # 12B6..12B7 ; Unknown
    "Ethi",  # 12B8..12BE ; Ethiopic
    "Zzzz",  # 12BF..12BF ; Unknown
    "Ethi",  # 12C0..12C0 ; Ethiopic
    "Zzzz",  # 12C1..12C1 ; Unknown
    "Ethi",  # 12C2..12C5 ; Ethiopic
    "Zzzz",  # 12C6..12C7 ; Unknown
    "Ethi",  # 12C8..12D6 ; Ethiopic
    "Zzzz",  # 12D7..12D7 ; Unknown
    "Ethi",  # 12D8..1310 ; Ethiopic
    "Zzzz",  # 1311..1311 ; Unknown
    "Ethi",  # 1312..1315 ; Ethiopic
    "Zzzz",  # 1316..1317 ; Unknown
    "Ethi",  # 1318..135A ; Ethiopic
    "Zzzz",  # 135B..135C ; Unknown
    "Ethi",  # 135D..137C ; Ethiopic
    "Zzzz",  # 137D..137F ; Unknown
    "Ethi",  # 1380..1399 ; Ethiopic
    "Zzzz",  # 139A..139F ; Unknown
    "Cher",  # 13A0..13F5 ; Cherokee
    "Zzzz",  # 13F6..13F7 ; Unknown
    "Cher",  # 13F8..13FD ; Cherokee
    "Zzzz",  # 13FE..13FF ; Unknown
    "Cans",  # 1400..167F ; Canadian_Aboriginal
    "Ogam",  # 1680..169C ; Ogham
    "Zzzz",  # 169D..169F ; Unknown
    "Runr",  # 16A0..16EA ; Runic
    "Zyyy",  # 16EB..16ED ; Common
    "Runr",  # 16EE..16F8 ; Runic
    "Zzzz",  # 16F9..16FF ; Unknown
    "Tglg",  # 1700..1715 ; Tagalog
    "Zzzz",  # 1716..171E ; Unknown
    "Tglg",  # 171F..171F ; Tagalog
    "Hano",  # 1720..1734 ; Hanunoo
    "Zyyy",  # 1735..1736 ; Common
    "Zzzz",  # 1737..173F ; Unknown
    "Buhd",  # 1740..1753 ; Buhid
    "Zzzz",  # 1754..175F ; Unknown
    "Tagb",  # 1760..176C ; Tagbanwa
    "Zzzz",  # 176D..176D ; Unknown
    "Tagb",  # 176E..1770 ; Tagbanwa
    "Zzzz",  # 1771..1771 ; Unknown
    "Tagb",  # 1772..1773 ; Tagbanwa
    "Zzzz",  # 1774..177F ; Unknown
    "Khmr",  # 1780..17DD ; Khmer
    "Zzzz",  # 17DE..17DF ; Unknown
    "Khmr",  # 17E0..17E9 ; Khmer
    "Zzzz",  # 17EA..17EF ; Unknown
    "Khmr",  # 17F0..17F9 ; Khmer
    "Zzzz",  # 17FA..17FF ; Unknown
    "Mong",  # 1800..1801 ; Mongolian
    "Zyyy",  # 1802..1803 ; Common
    "Mong",  # 1804..1804 ; Mongolian
    "Zyyy",  # 1805..1805 ; Common
    "Mong",  # 1806..1819 ; Mongolian
    "Zzzz",  # 181A..181F ; Unknown
    "Mong",  # 1820..1878 ; Mongolian
    "Zzzz",  # 1879..187F ; Unknown
    "Mong",  # 1880..18AA ; Mongolian
    "Zzzz",  # 18AB..18AF ; Unknown
    "Cans",  # 18B0..18F5 ; Canadian_Aboriginal
    "Zzzz",  # 18F6..18FF ; Unknown
    "Limb",  # 1900..191E ; Limbu
    "Zzzz",  # 191F..191F ; Unknown
    "Limb",  # 1920..192B ; Limbu
    "Zzzz",  # 192C..192F ; Unknown
    "Limb",  # 1930..193B ; Limbu
    "Zzzz",  # 193C..193F ; Unknown
    "Limb",  # 1940..1940 ; Limbu
    "Zzzz",  # 1941..1943 ; Unknown
    "Limb",  # 1944..194F ; Limbu
    "Tale",  # 1950..196D ; Tai_Le
    "Zzzz",  # 196E..196F ; Unknown
    "Tale",  # 1970..1974 ; Tai_Le
    "Zzzz",  # 1975..197F ; Unknown
    "Talu",  # 1980..19AB ; New_Tai_Lue
    "Zzzz",  # 19AC..19AF ; Unknown
    "Talu",  # 19B0..19C9 ; New_Tai_Lue
    "Zzzz",  # 19CA..19CF ; Unknown
    "Talu",  # 19D0..19DA ; New_Tai_Lue
    "Zzzz",  # 19DB..19DD ; Unknown
    "Talu",  # 19DE..19DF ; New_Tai_Lue
    "Khmr",  # 19E0..19FF ; Khmer
    "Bugi",  # 1A00..1A1B ; Buginese
    "Zzzz",  # 1A1C..1A1D ; Unknown
    "Bugi",  # 1A1E..1A1F ; Buginese
    "Lana",  # 1A20..1A5E ; Tai_Tham
    "Zzzz",  # 1A5F..1A5F ; Unknown
    "Lana",  # 1A60..1A7C ; Tai_Tham
    "Zzzz",  # 1A7D..1A7E ; Unknown
    "Lana",  # 1A7F..1A89 ; Tai_Tham
    "Zzzz",  # 1A8A..1A8F ; Unknown
    "Lana",  # 1A90..1A99 ; Tai_Tham
    "Zzzz",  # 1A9A..1A9F ; Unknown
    "Lana",  # 1AA0..1AAD ; Tai_Tham
    "Zzzz",  # 1AAE..1AAF ; Unknown
    "Zinh",  # 1AB0..1ADD ; Inherited
    "Zzzz",  # 1ADE..1ADF ; Unknown
    "Zinh",  # 1AE0..1AEB ; Inherited
    "Zzzz",  # 1AEC..1AFF ; Unknown
    "Bali",  # 1B00..1B4C ; Balinese
    "Zzzz",  # 1B4D..1B4D ; Unknown
    "Bali",  # 1B4E..1B7F ; Balinese
    "Sund",  # 1B80..1BBF ; Sundanese
    "Batk",  # 1BC0..1BF3 ; Batak
    "Zzzz",  # 1BF4..1BFB ; Unknown
    "Batk",  # 1BFC..1BFF ; Batak
    "Lepc",  # 1C00..1C37 ; Lepcha
    "Zzzz",  # 1C38..1C3A ; Unknown
    "Lepc",  # 1C3B..1C49 ; Lepcha
    "Zzzz",  # 1C4A..1C4C ; Unknown
    "Lepc",  # 1C4D..1C4F ; Lepcha
    "Olck",  # 1C50..1C7F ; Ol_Chiki
    "Cyrl",  # 1C80..1C8A ; Cyrillic
    "Zzzz",  # 1C8B..1C8F ; Unknown
    "Geor",  # 1C90..1CBA ; Georgian
    "Zzzz",  # 1CBB..1CBC ; Unknown
    "Geor",  # 1CBD..1CBF ; Georgian
    "Sund",  # 1CC0..1CC7 ; Sundanese
    "Zzzz",  # 1CC8..1CCF ; Unknown
    "Zinh",  # 1CD0..1CD2 ; Inherited
    "Zyyy",  # 1CD3..1CD3 ; Common
    "Zinh",  # 1CD4..1CE0 ; Inherited
    "Zyyy",  # 1CE1..1CE1 ; Common
    "Zinh",  # 1CE2..1CE8 ; Inherited
    "Zyyy",  # 1CE9..1CEC ; Common
    "Zinh",  # 1CED..1CED ; Inherited
    "Zyyy",  # 1CEE..1CF3 ; Common
    "Zinh",  # 1CF4..1CF4 ; Inherited
    "Zyyy",  # 1CF5..1CF7 ; Common
    "Zinh",  # 1CF8..1CF9 ; Inherited
    "Zyyy",  # 1CFA..1CFA ; Common
    "Zzzz",  # 1CFB..1CFF ; Unknown
    "Latn",  # 1D00..1D25 ; Latin
    "Grek",  # 1D26..1D2A ; Greek
    "Cyrl",  # 1D2B..1D2B ; Cyrillic
    "Latn",  # 1D2C..1D5C ; Latin
    "Grek",  # 1D5D..1D61 ; Greek
    "Latn",  # 1D62..1D65 ; Latin
    "Grek",  # 1D66..1D6A ; Greek
    "Latn",  # 1D6B..1D77 ; Latin
    "Cyrl",  # 1D78..1D78 ; Cyrillic
    "Latn",  # 1D79..1DBE ; Latin
    "Grek",  # 1DBF..1DBF ; Greek
    "Zinh",  # 1DC0..1DFF ; Inherited
    "Latn",  # 1E00..1EFF ; Latin
    "Grek",  # 1F00..1F15 ; Greek
    "Zzzz",  # 1F16..1F17 ; Unknown
    "Grek",  # 1F18..1F1D ; Greek
    "Zzzz",  # 1F1E..1F1F ; Unknown
    "Grek",  # 1F20..1F45 ; Greek
    "Zzzz",  # 1F46..1F47 ; Unknown
    "Grek",  # 1F48..1F4D ; Greek
    "Zzzz",  # 1F4E..1F4F ; Unknown
    "Grek",  # 1F50..1F57 ; Greek
    "Zzzz",  # 1F58..1F58 ; Unknown
    "Grek",  # 1F59..1F59 ; Greek
    "Zzzz",  # 1F5A..1F5A ; Unknown
    "Grek",  # 1F5B..1F5B ; Greek
    "Zzzz",  # 1F5C..1F5C ; Unknown
    "Grek",  # 1F5D..1F5D ; Greek
    "Zzzz",  # 1F5E..1F5E ; Unknown
    "Grek",  # 1F5F..1F7D ; Greek
    "Zzzz",  # 1F7E..1F7F ; Unknown
    "Grek",  # 1F80..1FB4 ; Greek
    "Zzzz",  # 1FB5..1FB5 ; Unknown
    "Grek",  # 1FB6..1FC4 ; Greek
    "Zzzz",  # 1FC5..1FC5 ; Unknown
    "Grek",  # 1FC6..1FD3 ; Greek
    "Zzzz",  # 1FD4..1FD5 ; Unknown
    "Grek",  # 1FD6..1FDB ; Greek
    "Zzzz",  # 1FDC..1FDC ; Unknown
    "Grek",  # 1FDD..1FEF ; Greek
    "Zzzz",  # 1FF0..1FF1 ; Unknown
    "Grek",  # 1FF2..1FF4 ; Greek
    "Zzzz",  # 1FF5..1FF5 ; Unknown
    "Grek",  # 1FF6..1FFE ; Greek
    "Zzzz",  # 1FFF..1FFF ; Unknown
    "Zyyy",  # 2000..200B ; Common
    "Zinh",  # 200C..200D ; Inherited
    "Zyyy",  # 200E..2064 ; Common
    "Zzzz",  # 2065..2065 ; Unknown
    "Zyyy",  # 2066..2070 ; Common
    "Latn",  # 2071..2071 ; Latin
    "Zzzz",  # 2072..2073 ; Unknown
    "Zyyy",  # 2074..207E ; Common
    "Latn",  # 207F..207F ; Latin
    "Zyyy",  # 2080..208E ; Common
    "Zzzz",  # 208F..208F ; Unknown
    "Latn",  # 2090..209C ; Latin
    "Zzzz",  # 209D..209F ; Unknown
    "Zyyy",  # 20A0..20C1 ; Common
    "Zzzz",  # 20C2..20CF ; Unknown
    "Zinh",  # 20D0..20F0 ; Inherited
    "Zzzz",  # 20F1..20FF ; Unknown
    "Zyyy",  # 2100..2125 ; Common
    "Grek",  # 2126..2126 ; Greek
    "Zyyy",  # 2127..2129 ; Common
    "Latn",  # 212A..212B ; Latin
    "Zyyy",  # 212C..2131 ; Common
    "Latn",  # 2132..2132 ; Latin
    "Zyyy",  # 2133..214D ; Common
    "Latn",  # 214E..214E ; Latin
    "Zyyy",  # 214F..215F ; Common
    "Latn",  # 2160..2188 ; Latin
    "Zyyy",  # 2189..218B ; Common
    "Zzzz",  # 218C..218F ; Unknown
    "Zyyy",  # 2190..2429 ; Common
    "Zzzz",  # 242A..243F ; Unknown
    "Zyyy",  # 2440..244A ; Common
    "Zzzz",  # 244B..245F ; Unknown
    "Zyyy",  # 2460..27FF ; Common
    "Brai",  # 2800..28FF ; Braille
    "Zyyy",  # 2900..2B73 ; Common
    "Zzzz",  # 2B74..2B75 ; Unknown
    "Zyyy",  # 2B76..2BFF ; Common
    "Glag",  # 2C00..2C5F ; Glagolitic
    "Latn",  # 2C60..2C7F ; Latin
    "Copt",  # 2C80..2CF3 ; Coptic
    "Zzzz",  # 2CF4..2CF8 ; Unknown
    "Copt",  # 2CF9..2CFF ; Coptic
    "Geor",  # 2D00..2D25 ; Georgian
    "Zzzz",  # 2D26..2D26 ; Unknown
    "Geor",  # 2D27..2D27 ; Georgian
    "Zzzz",  # 2D28..2D2C ; Unknown
    "Geor",  # 2D2D..2D2D ; Georgian
    "Zzzz",  # 2D2E..2D2F ; Unknown
    "Tfng",  # 2D30..2D67 ; Tifinagh
    "Zzzz",  # 2D68..2D6E ; Unknown
    "Tfng",  # 2D6F..2D70 ; Tifinagh
    "Zzzz",  # 2D71..2D7E ; Unknown
    "Tfng",  # 2D7F..2D7F ; Tifinagh
    "Ethi",  # 2D80..2D96 ; Ethiopic
    "Zzzz",  # 2D97..2D9F ; Unknown
    "Ethi",  # 2DA0..2DA6 ; Ethiopic
    "Zzzz",  # 2DA7..2DA7 ; Unknown
    "Ethi",  # 2DA8..2DAE ; Ethiopic
    "Zzzz",  # 2DAF..2DAF ; Unknown
    "Ethi",  # 2DB0..2DB6 ; Ethiopic
    "Zzzz",  # 2DB7..2DB7 ; Unknown
    "Ethi",  # 2DB8..2DBE ; Ethiopic
    "Zzzz",  # 2DBF..2DBF ; Unknown
    "Ethi",  # 2DC0..2DC6 ; Ethiopic
    "Zzzz",  # 2DC7..2DC7 ; Unknown
    "Ethi",  # 2DC8..2DCE ; Ethiopic
    "Zzzz",  # 2DCF..2DCF ; Unknown
    "Ethi",  # 2DD0..2DD6 ; Ethiopic
    "Zzzz",  # 2DD7..2DD7 ; Unknown
    "Ethi",  # 2DD8..2DDE ; Ethiopic
    "Zzzz",  # 2DDF..2DDF ; Unknown
    "Cyrl",  # 2DE0..2DFF ; Cyrillic
    "Zyyy",  # 2E00..2E5D ; Common
    "Zzzz",  # 2E5E..2E7F ; Unknown
    "Hani",  # 2E80..2E99 ; Han
    "Zzzz",  # 2E9A..2E9A ; Unknown
    "Hani",  # 2E9B..2EF3 ; Han
    "Zzzz",  # 2EF4..2EFF ; Unknown
    "Hani",  # 2F00..2FD5 ; Han
    "Zzzz",  # 2FD6..2FEF ; Unknown
    "Zyyy",  # 2FF0..3004 ; Common
    "Hani",  # 3005..3005 ; Han
    "Zyyy",  # 3006..3006 ; Common
    "Hani",  # 3007..3007 ; Han
    "Zyyy",  # 3008..3020 ; Common
    "Hani",  # 3021..3029 ; Han
    "Zinh",  # 302A..302D ; Inherited
    "Hang",  # 302E..302F ; Hangul
    "Zyyy",  # 3030..3037 ; Common
    "Hani",  # 3038..303B ; Han
    "Zyyy",  # 303C..303F ; Common
    "Zzzz",  # 3040..3040 ; Unknown
    "Hira",  # 3041..3096 ; Hiragana
    "Zzzz",  # 3097..3098 ; Unknown
    "Zinh",  # 3099..309A ; Inherited
    "Zyyy",  # 309B..309C ; Common
    "Hira",  # 309D..309F ; Hiragana
    "Zyyy",  # 30A0..30A0 ; Common
    "Kana",  # 30A1..30FA ; Katakana
    "Zyyy",  # 30FB..30FC ; Common
    "Kana",  # 30FD..30FF ; Katakana
    "Zzzz",  # 3100..3104 ; Unknown
    "Bopo",  # 3105..312F ; Bopomofo
    "Zzzz",  # 3130..3130 ; Unknown
    "Hang",  # 3131..318E ; Hangul
    "Zzzz",  # 318F..318F ; Unknown
    "Zyyy",  # 3190..319F ; Common
    "Bopo",  # 31A0..31BF ; Bopomofo
    "Zyyy",  # 31C0..31E5 ; Common
    "Zzzz",  # 31E6..31EE ; Unknown
    "Zyyy",  # 31EF..31EF ; Common
    "Kana",  # 31F0..31FF ; Katakana
    "Hang",  # 3200..321E ; Hangul
    "Zzzz",  # 321F..321F ; Unknown
    "Zyyy",  # 3220..325F ; Common
    "Hang",  # 3260..327E ; Hangul
    "Zyyy",  # 327F..32CF ; Common
    "Kana",  # 32D0..32FE ; Katakana
    "Zyyy",  # 32FF..32FF ; Common
    "Kana",  # 3300..3357 ; Katakana
    "Zyyy",  # 3358..33FF ; Common
    "Hani",  # 3400..4DBF ; Han
    "Zyyy",  # 4DC0..4DFF ; Common
    "Hani",  # 4E00..9FFF ; Han
    "Yiii",  # A000..A48C ; Yi
    "Zzzz",  # A48D..A48F ; Unknown
    "Yiii",  # A490..A4C6 ; Yi
    "Zzzz",  # A4C7..A4CF ; Unknown
    "Lisu",  # A4D0..A4FF ; Lisu
    "Vaii",  # A500..A62B ; Vai
    "Zzzz",  # A62C..A63F ; Unknown
    "Cyrl",  # A640..A69F ; Cyrillic
    "Bamu",  # A6A0..A6F7 ; Bamum
    "Zzzz",  # A6F8..A6FF ; Unknown
    "Zyyy",  # A700..A721 ; Common
    "Latn",  # A722..A787 ; Latin
    "Zyyy",  # A788..A78A ; Common
    "Latn",  # A78B..A7DC ; Latin
    "Zzzz",  # A7DD..A7F0 ; Unknown
    "Latn",  # A7F1..A7FF ; Latin
    "Sylo",  # A800..A82C ; Syloti_Nagri
    "Zzzz",  # A82D..A82F ; Unknown
    "Zyyy",  # A830..A839 ; Common
    "Zzzz",  # A83A..A83F ; Unknown
    "Phag",  # A840..A877 ; Phags_Pa
    "Zzzz",  # A878..A87F ; Unknown
    "Saur",  # A880..A8C5 ; Saurashtra
    "Zzzz",  # A8C6..A8CD ; Unknown
    "Saur",  # A8CE..A8D9 ; Saurashtra
    "Zzzz",  # A8DA..A8DF ; Unknown
    "Deva",  # A8E0..A8FF ; Devanagari
    "Kali",  # A900..A92D ; Kayah_Li
    "Zyyy",  # A92E..A92E ; Common
    "Kali",  # A92F..A92F ; Kayah_Li
    "Rjng",  # A930..A953 ; Rejang
    "Zzzz",  # A954..A95E ; Unknown
    "Rjng",  # A95F..A95F ; Rejang
    "Hang",  # A960..A97C ; Hangul
    "Zzzz",  # A97D..A97F ; Unknown
    "Java",  # A980..A9CD ; Javanese
    "Zzzz",  # A9CE..A9CE ; Unknown
    "Zyyy",  # A9CF..A9CF ; Common
    "Java",  # A9D0..A9D9 ; Javanese
    "Zzzz",  # A9DA..A9DD ; Unknown
    "Java",  # A9DE..A9DF ; Javanese
    "Mymr",  # A9E0..A9FE ; Myanmar
    "Zzzz",  # A9FF..A9FF ; Unknown
    "Cham",  # AA00..AA36 ; Cham
    "Zzzz",  # AA37..AA3F ; Unknown
    "Cham",  # AA40..AA4D ; Cham
    "Zzzz",  # AA4E..AA4F ; Unknown
    "Cham",  # AA50..AA59 ; Cham
    "Zzzz",  # AA5A..AA5B ; Unknown
    "Cham",  # AA5C..AA5F ; Cham
    "Mymr",  # AA60..AA7F ; Myanmar
    "Tavt",  # AA80..AAC2 ; Tai_Viet
    "Zzzz",  # AAC3..AADA ; Unknown
    "Tavt",  # AADB..AADF ; Tai_Viet
    "Mtei",  # AAE0..AAF6 ; Meetei_Mayek
    "Zzzz",  # AAF7..AB00 ; Unknown
    "Ethi",  # AB01..AB06 ; Ethiopic
    "Zzzz",  # AB07..AB08 ; Unknown
    "Ethi",  # AB09..AB0E ; Ethiopic
    "Zzzz",  # AB0F..AB10 ; Unknown
    "Ethi",  # AB11..AB16 ; Ethiopic
    "Zzzz",  # AB17..AB1F ; Unknown
    "Ethi",  # AB20..AB26 ; Ethiopic
    "Zzzz",  # AB27..AB27 ; Unknown
    "Ethi",  # AB28..AB2E ; Ethiopic
    "Zzzz",  # AB2F..AB2F ; Unknown
    "Latn",  # AB30..AB5A ; Latin
    "Zyyy",  # AB5B..AB5B ; Common
    "Latn",  # AB5C..AB64 ; Latin
    "Grek",  # AB65..AB65 ; Greek
    "Latn",  # AB66..AB69 ; Latin
    "Zyyy",  # AB6A..AB6B ; Common
    "Zzzz",  # AB6C..AB6F ; Unknown
    "Cher",  # AB70..ABBF ; Cherokee
    "Mtei",  # ABC0..ABED ; Meetei_Mayek
    "Zzzz",  # ABEE..ABEF ; Unknown
    "Mtei",  # ABF0..ABF9 ; Meetei_Mayek
    "Zzzz",  # ABFA..ABFF ; Unknown
    "Hang",  # AC00..D7A3 ; Hangul
    "Zzzz",  # D7A4..D7AF ; Unknown
    "Hang",  # D7B0..D7C6 ; Hangul
    "Zzzz",  # D7C7..D7CA ; Unknown
    "Hang",  # D7CB..D7FB ; Hangul
    "Zzzz",  # D7FC..F8FF ; Unknown
    "Hani",  # F900..FA6D ; Han
    "Zzzz",  # FA6E..FA6F ; Unknown
    "Hani",  # FA70..FAD9 ; Han
    "Zzzz",  # FADA..FAFF ; Unknown
    "Latn",  # FB00..FB06 ; Latin
    "Zzzz",  # FB07..FB12 ; Unknown
    "Armn",  # FB13..FB17 ; Armenian
    "Zzzz",  # FB18..FB1C ; Unknown
    "Hebr",  # FB1D..FB36 ; Hebrew
    "Zzzz",  # FB37..FB37 ; Unknown
    "Hebr",  # FB38..FB3C ; Hebrew
    "Zzzz",  # FB3D..FB3D ; Unknown
    "Hebr",  # FB3E..FB3E ; Hebrew
    "Zzzz",  # FB3F..FB3F ; Unknown
    "Hebr",  # FB40..FB41 ; Hebrew
    "Zzzz",  # FB42..FB42 ; Unknown
    "Hebr",  # FB43..FB44 ; Hebrew
    "Zzzz",  # FB45..FB45 ; Unknown
    "Hebr",  # FB46..FB4F ; Hebrew
    "Arab",  # FB50..FD3D ; Arabic
    "Zyyy",  # FD3E..FD3F ; Common
    "Arab",  # FD40..FDCF ; Arabic
    "Zzzz",  # FDD0..FDEF ; Unknown
    "Arab",  # FDF0..FDFF ; Arabic
    "Zinh",  # FE00..FE0F ; Inherited
    "Zyyy",  # FE10..FE19 ; Common
    "Zzzz",  # FE1A..FE1F ; Unknown
    "Zinh",  # FE20..FE2D ; Inherited
    "Cyrl",  # FE2E..FE2F ; Cyrillic
    "Zyyy",  # FE30..FE52 ; Common
    "Zzzz",  # FE53..FE53 ; Unknown
    "Zyyy",  # FE54..FE66 ; Common
    "Zzzz",  # FE67..FE67 ; Unknown
    "Zyyy",  # FE68..FE6B ; Common
    "Zzzz",  # FE6C..FE6F ; Unknown
    "Arab",  # FE70..FE74 ; Arabic
    "Zzzz",  # FE75..FE75 ; Unknown
    "Arab",  # FE76..FEFC ; Arabic
    "Zzzz",  # FEFD..FEFE ; Unknown
    "Zyyy",  # FEFF..FEFF ; Common
    "Zzzz",  # FF00..FF00 ; Unknown
    "Zyyy",  # FF01..FF20 ; Common
    "Latn",  # FF21..FF3A ; Latin
    "Zyyy",  # FF3B..FF40 ; Common
    "Latn",  # FF41..FF5A ; Latin
    "Zyyy",  # FF5B..FF65 ; Common
    "Kana",  # FF66..FF6F ; Katakana
    "Zyyy",  # FF70..FF70 ; Common
    "Kana",  # FF71..FF9D ; Katakana
    "Zyyy",  # FF9E..FF9F ; Common
    "Hang",  # FFA0..FFBE ; Hangul
    "Zzzz",  # FFBF..FFC1 ; Unknown
    "Hang",  # FFC2..FFC7 ; Hangul
    "Zzzz",  # FFC8..FFC9 ; Unknown
    "Hang",  # FFCA..FFCF ; Hangul
    "Zzzz",  # FFD0..FFD1 ; Unknown
    "Hang",  # FFD2..FFD7 ; Hangul
    "Zzzz",  # FFD8..FFD9 ; Unknown
    "Hang",  # FFDA..FFDC ; Hangul
    "Zzzz",  # FFDD..FFDF ; Unknown
    "Zyyy",  # FFE0..FFE6 ; Common
    "Zzzz",  # FFE7..FFE7 ; Unknown
    "Zyyy",  # FFE8..FFEE ; Common
    "Zzzz",  # FFEF..FFF8 ; Unknown
    "Zyyy",  # FFF9..FFFD ; Common
    "Zzzz",  # FFFE..FFFF ; Unknown
    "Linb",  # 10000..1000B ; Linear_B
    "Zzzz",  # 1000C..1000C ; Unknown
    "Linb",  # 1000D..10026 ; Linear_B
    "Zzzz",  # 10027..10027 ; Unknown
    "Linb",  # 10028..1003A ; Linear_B
    "Zzzz",  # 1003B..1003B ; Unknown
    "Linb",  # 1003C..1003D ; Linear_B
    "Zzzz",  # 1003E..1003E ; Unknown
    "Linb",  # 1003F..1004D ; Linear_B
    "Zzzz",  # 1004E..1004F ; Unknown
    "Linb",  # 10050..1005D ; Linear_B
    "Zzzz",  # 1005E..1007F ; Unknown
    "Linb",  # 10080..100FA ; Linear_B
    "Zzzz",  # 100FB..100FF ; Unknown
    "Zyyy",  # 10100..10102 ; Common
    "Zzzz",  # 10103..10106 ; Unknown
    "Zyyy",  # 10107..10133 ; Common
    "Zzzz",  # 10134..10136 ; Unknown
    "Zyyy",  # 10137..1013F ; Common
    "Grek",  # 10140..1018E ; Greek
    "Zzzz",  # 1018F..1018F ; Unknown
    "Zyyy",  # 10190..1019C ; Common
    "Zzzz",  # 1019D..1019F ; Unknown
    "Grek",  # 101A0..101A0 ; Greek
    "Zzzz",  # 101A1..101CF ; Unknown
    "Zyyy",  # 101D0..101FC ; Common
    "Zinh",  # 101FD..101FD ; Inherited
    "Zzzz",  # 101FE..1027F ; Unknown
    "Lyci",  # 10280..1029C ; Lycian
    "Zzzz",  # 1029D..1029F ; Unknown
    "Cari",  # 102A0..102D0 ; Carian
    "Zzzz",  # 102D1..102DF ; Unknown
    "Zinh",  # 102E0..102E0 ; Inherited
    "Zyyy",  # 102E1..102FB ; Common
    "Zzzz",  # 102FC..102FF ; Unknown
    "Ital",  # 10300..10323 ; Old_Italic
    "Zzzz",  # 10324..1032C ; Unknown
    "Ital",  # 1032D..1032F ; Old_Italic
    "Goth",  # 10330..1034A ; Gothic
    "Zzzz",  # 1034B..1034F ; Unknown
    "Perm",  # 10350..1037A ; Old_Permic
    "Zzzz",  # 1037B..1037F ; Unknown
    "Ugar",  # 10380..1039D ; Ugaritic
    "Zzzz",  # 1039E..1039E ; Unknown
    "Ugar",  # 1039F..1039F ; Ugaritic
    "Xpeo",  # 103A0..103C3 ; Old_Persian
    "Zzzz",  # 103C4..103C7 ; Unknown
    "Xpeo",  # 103C8..103D5 ; Old_Persian
    "Zzzz",  # 103D6..103FF ; Unknown
    "Dsrt",  # 10400..1044F ; Deseret
    "Shaw",  # 10450..1047F ; Shavian
    "Osma",  # 10480..1049D ; Osmanya
    "Zzzz",  # 1049E..1049F ; Unknown
    "Osma",  # 104A0..104A9 ; Osmanya
    "Zzzz",  # 104AA..104AF ; Unknown
    "Osge",  # 104B0..104D3 ; Osage
    "Zzzz",  # 104D4..104D7 ; Unknown
    "Osge",  # 104D8..104FB ; Osage
    "Zzzz",  # 104FC..104FF ; Unknown
    "Elba",  # 10500..10527 ; Elbasan
    "Zzzz",  # 10528..1052F ; Unknown
    "Aghb",  # 10530..10563 ; Caucasian_Albanian
    "Zzzz",  # 10564..1056E ; Unknown
    "Aghb",  # 1056F..1056F ; Caucasian_Albanian
    "Vith",  # 10570..1057A ; Vithkuqi
    "Zzzz",  # 1057B..1057B ; Unknown
    "Vith",  # 1057C..1058A ; Vithkuqi
    "Zzzz",  # 1058B..1058B ; Unknown
    "Vith",  # 1058C..10592 ; Vithkuqi
    "Zzzz",  # 10593..10593 ; Unknown
    "Vith",  # 10594..10595 ; Vithkuqi
    "Zzzz",  # 10596..10596 ; Unknown
    "Vith",  # 10597..105A1 ; Vithkuqi
    "Zzzz",  # 105A2..105A2 ; Unknown
    "Vith",  # 105A3..105B1 ; Vithkuqi
    "Zzzz",  # 105B2..105B2 ; Unknown
    "Vith",  # 105B3..105B9 ; Vithkuqi
    "Zzzz",  # 105BA..105BA ; Unknown
    "Vith",  # 105BB..105BC ; Vithkuqi
    "Zzzz",  # 105BD..105BF ; Unknown
    "Todr",  # 105C0..105F3 ; Todhri
    "Zzzz",  # 105F4..105FF ; Unknown
    "Lina",  # 10600..10736 ; Linear_A
    "Zzzz",  # 10737..1073F ; Unknown
    "Lina",  # 10740..10755 ; Linear_A
    "Zzzz",  # 10756..1075F ; Unknown
    "Lina",  # 10760..10767 ; Linear_A
    "Zzzz",  # 10768..1077F ; Unknown
    "Latn",  # 10780..10785 ; Latin
    "Zzzz",  # 10786..10786 ; Unknown
    "Latn",  # 10787..107B0 ; Latin
    "Zzzz",  # 107B1..107B1 ; Unknown
    "Latn",  # 107B2..107BA ; Latin
    "Zzzz",  # 107BB..107FF ; Unknown
    "Cprt",  # 10800..10805 ; Cypriot
    "Zzzz",  # 10806..10807 ; Unknown
    "Cprt",  # 10808..10808 ; Cypriot
    "Zzzz",  # 10809..10809 ; Unknown
    "Cprt",  # 1080A..10835 ; Cypriot
    "Zzzz",  # 10836..10836 ; Unknown
    "Cprt",  # 10837..10838 ; Cypriot
    "Zzzz",  # 10839..1083B ; Unknown
    "Cprt",  # 1083C..1083C ; Cypriot
    "Zzzz",  # 1083D..1083E ; Unknown
    "Cprt",  # 1083F..1083F ; Cypriot
    "Armi",  # 10840..10855 ; Imperial_Aramaic
    "Zzzz",  # 10856..10856 ; Unknown
    "Armi",  # 10857..1085F ; Imperial_Aramaic
    "Palm",  # 10860..1087F ; Palmyrene
    "Nbat",  # 10880..1089E ; Nabataean
    "Zzzz",  # 1089F..108A6 ; Unknown
    "Nbat",  # 108A7..108AF ; Nabataean
    "Zzzz",  # 108B0..108DF ; Unknown
    "Hatr",  # 108E0..108F2 ; Hatran
    "Zzzz",  # 108F3..108F3 ; Unknown
    "Hatr",  # 108F4..108F5 ; Hatran
    "Zzzz",  # 108F6..108FA ; Unknown
    "Hatr",  # 108FB..108FF ; Hatran
    "Phnx",  # 10900..1091B ; Phoenician
    "Zzzz",  # 1091C..1091E ; Unknown
    "Phnx",  # 1091F..1091F ; Phoenician
    "Lydi",  # 10920..10939 ; Lydian
    "Zzzz",  # 1093A..1093E ; Unknown
    "Lydi",  # 1093F..1093F ; Lydian
    "Sidt",  # 10940..10959 ; Sidetic
    "Zzzz",  # 1095A..1097F ; Unknown
    "Mero",  # 10980..1099F ; Meroitic_Hieroglyphs
    "Merc",  # 109A0..109B7 ; Meroitic_Cursive
    "Zzzz",  # 109B8..109BB ; Unknown
    "Merc",  # 109BC..109CF ; Meroitic_Cursive
    "Zzzz",  # 109D0..109D1 ; Unknown
    "Merc",  # 109D2..109FF ; Meroitic_Cursive
    "Khar",  # 10A00..10A03 ; Kharoshthi
    "Zzzz",  # 10A04..10A04 ; Unknown
    "Khar",  # 10A05..10A06 ; Kharoshthi
    "Zzzz",  # 10A07..10A0B ; Unknown
    "Khar",  # 10A0C..10A13 ; Kharoshthi
    "Zzzz",  # 10A14..10A14 ; Unknown
    "Khar",  # 10A15..10A17 ; Kharoshthi
    "Zzzz",  # 10A18..10A18 ; Unknown
    "Khar",  # 10A19..10A35 ; Kharoshthi
    "Zzzz",  # 10A36..10A37 ; Unknown
    "Khar",  # 10A38..10A3A ; Kharoshthi
    "Zzzz",  # 10A3B..10A3E ; Unknown
    "Khar",  # 10A3F..10A48 ; Kharoshthi
    "Zzzz",  # 10A49..10A4F ; Unknown
    "Khar",  # 10A50..10A58 ; Kharoshthi
    "Zzzz",  # 10A59..10A5F ; Unknown
    "Sarb",  # 10A60..10A7F ; Old_South_Arabian
    "Narb",  # 10A80..10A9F ; Old_North_Arabian
    "Zzzz",  # 10AA0..10ABF ; Unknown
    "Mani",  # 10AC0..10AE6 ; Manichaean
    "Zzzz",  # 10AE7..10AEA ; Unknown
    "Mani",  # 10AEB..10AF6 ; Manichaean
    "Zzzz",  # 10AF7..10AFF ; Unknown
    "Avst",  # 10B00..10B35 ; Avestan
    "Zzzz",  # 10B36..10B38 ; Unknown
    "Avst",  # 10B39..10B3F ; Avestan
    "Prti",  # 10B40..10B55 ; Inscriptional_Parthian
    "Zzzz",  # 10B56..10B57 ; Unknown
    "Prti",  # 10B58..10B5F ; Inscriptional_Parthian
    "Phli",  # 10B60..10B72 ; Inscriptional_Pahlavi
    "Zzzz",  # 10B73..10B77 ; Unknown
    "Phli",  # 10B78..10B7F ; Inscriptional_Pahlavi
    "Phlp",  # 10B80..10B91 ; Psalter_Pahlavi
    "Zzzz",  # 10B92..10B98 ; Unknown
    "Phlp",  # 10B99..10B9C ; Psalter_Pahlavi
    "Zzzz",  # 10B9D..10BA8 ; Unknown
    "Phlp",  # 10BA9..10BAF ; Psalter_Pahlavi
    "Zzzz",  # 10BB0..10BFF ; Unknown
    "Orkh",  # 10C00..10C48 ; Old_Turkic
    "Zzzz",  # 10C49..10C7F ; Unknown
    "Hung",  # 10C80..10CB2 ; Old_Hungarian
    "Zzzz",  # 10CB3..10CBF ; Unknown
    "Hung",  # 10CC0..10CF2 ; Old_Hungarian
    "Zzzz",  # 10CF3..10CF9 ; Unknown
    "Hung",  # 10CFA..10CFF ; Old_Hungarian
    "Rohg",  # 10D00..10D27 ; Hanifi_Rohingya
    "Zzzz",  # 10D28..10D2F ; Unknown
    "Rohg",  # 10D30..10D39 ; Hanifi_Rohingya
    "Zzzz",  # 10D3A..10D3F ; Unknown
    "Gara",  # 10D40..10D65 ; Garay
    "Zzzz",  # 10D66..10D68 ; Unknown
    "Gara",  # 10D69..10D85 ; Garay
    "Zzzz",  # 10D86..10D8D ; Unknown
    "Gara",  # 10D8E..10D8F ; Garay
    "Zzzz",  # 10D90..10E5F ; Unknown
    "Arab",  # 10E60..10E7E ; Arabic
    "Zzzz",  # 10E7F..10E7F ; Unknown
    "Yezi",  # 10E80..10EA9 ; Yezidi
    "Zzzz",  # 10EAA..10EAA ; Unknown
    "Yezi",  # 10EAB..10EAD ; Yezidi
    "Zzzz",  # 10EAE..10EAF ; Unknown
    "Yezi",  # 10EB0..10EB1 ; Yezidi
    "Zzzz",  # 10EB2..10EC1 ; Unknown
    "Arab",  # 10EC2..10EC7 ; Arabic
    "Zzzz",  # 10EC8..10ECF ; Unknown
    "Arab",  # 10ED0..10ED8 ; Arabic
    "Zzzz",  # 10ED9..10EF9 ; Unknown
    "Arab",  # 10EFA..10EFF ; Arabic
    "Sogo",  # 10F00..10F27 ; Old_Sogdian
    "Zzzz",  # 10F28..10F2F ; Unknown
    "Sogd",  # 10F30..10F59 ; Sogdian
    "Zzzz",  # 10F5A..10F6F ; Unknown
    "Ougr",  # 10F70..10F89 ; Old_Uyghur
    "Zzzz",  # 10F8A..10FAF ; Unknown
    "Chrs",  # 10FB0..10FCB ; Chorasmian
    "Zzzz",  # 10FCC..10FDF ; Unknown
    "Elym",  # 10FE0..10FF6 ; Elymaic
    "Zzzz",  # 10FF7..10FFF ; Unknown
    "Brah",  # 11000..1104D ; Brahmi
    "Zzzz",  # 1104E..11051 ; Unknown
    "Brah",  # 11052..11075 ; Brahmi
    "Zzzz",  # 11076..1107E ; Unknown
    "Brah",  # 1107F..1107F ; Brahmi
    "Kthi",  # 11080..110C2 ; Kaithi
    "Zzzz",  # 110C3..110CC ; Unknown
    "Kthi",  # 110CD..110CD ; Kaithi
    "Zzzz",  # 110CE..110CF ; Unknown
    "Sora",  # 110D0..110E8 ; Sora_Sompeng
    "Zzzz",  # 110E9..110EF ; Unknown
    "Sora",  # 110F0..110F9 ; Sora_Sompeng
    "Zzzz",  # 110FA..110FF ; Unknown
    "Cakm",  # 11100..11134 ; Chakma
    "Zzzz",  # 11135..11135 ; Unknown
    "Cakm",  # 11136..11147 ; Chakma
    "Zzzz",  # 11148..1114F ; Unknown
    "Mahj",  # 11150..11176 ; Mahajani
    "Zzzz",  # 11177..1117F ; Unknown
    "Shrd",  # 11180..111DF ; Sharada
    "Zzzz",  # 111E0..111E0 ; Unknown
    "Sinh",  # 111E1..111F4 ; Sinhala
    "Zzzz",  # 111F5..111FF ; Unknown
    "Khoj",  # 11200..11211 ; Khojki
    "Zzzz",  # 11212..11212 ; Unknown
    "Khoj",  # 11213..11241 ; Khojki
    "Zzzz",  # 11242..1127F ; Unknown
    "Mult",  # 11280..11286 ; Multani
    "Zzzz",  # 11287..11287 ; Unknown
    "Mult",  # 11288..11288 ; Multani
    "Zzzz",  # 11289..11289 ; Unknown
    "Mult",  # 1128A..1128D ; Multani
    "Zzzz",  # 1128E..1128E ; Unknown
    "Mult",  # 1128F..1129D ; Multani
    "Zzzz",  # 1129E..1129E ; Unknown
    "Mult",  # 1129F..112A9 ; Multani
    "Zzzz",  # 112AA..112AF ; Unknown
    "Sind",  # 112B0..112EA ; Khudawadi
    "Zzzz",  # 112EB..112EF ; Unknown
    "Sind",  # 112F0..112F9 ; Khudawadi
    "Zzzz",  # 112FA..112FF ; Unknown
    "Gran",  # 11300..11303 ; Grantha
    "Zzzz",  # 11304..11304 ; Unknown
    "Gran",  # 11305..1130C ; Grantha
    "Zzzz",  # 1130D..1130E ; Unknown
    "Gran",  # 1130F..11310 ; Grantha
    "Zzzz",  # 11311..11312 ; Unknown
    "Gran",  # 11313..11328 ; Grantha
    "Zzzz",  # 11329..11329 ; Unknown
    "Gran",  # 1132A..11330 ; Grantha
    "Zzzz",  # 11331..11331 ; Unknown
    "Gran",  # 11332..11333 ; Grantha
    "Zzzz",  # 11334..11334 ; Unknown
    "Gran",  # 11335..11339 ; Grantha
    "Zzzz",  # 1133A..1133A ; Unknown
    "Zinh",  # 1133B..1133B ; Inherited
    "Gran",  # 1133C..11344 ; Grantha
    "Zzzz",  # 11345..11346 ; Unknown
    "Gran",  # 11347..11348 ; Grantha
    "Zzzz",  # 11349..1134A ; Unknown
    "Gran",  # 1134B..1134D ; Grantha
    "Zzzz",  # 1134E..1134F ; Unknown
    "Gran",  # 11350..11350 ; Grantha
    "Zzzz",  # 11351..11356 ; Unknown
    "Gran",  # 11357..11357 ; Grantha
    "Zzzz",  # 11358..1135C ; Unknown
    "Gran",  # 1135D..11363 ; Grantha
    "Zzzz",  # 11364..11365 ; Unknown
    "Gran",  # 11366..1136C ; Grantha
    "Zzzz",  # 1136D..1136F ; Unknown
    "Gran",  # 11370..11374 ; Grantha
    "Zzzz",  # 11375..1137F ; Unknown
    "Tutg",  # 11380..11389 ; Tulu_Tigalari
    "Zzzz",  # 1138A..1138A ; Unknown
    "Tutg",  # 1138B..1138B ; Tulu_Tigalari
    "Zzzz",  # 1138C..1138D ; Unknown
    "Tutg",  # 1138E..1138E ; Tulu_Tigalari
    "Zzzz",  # 1138F..1138F ; Unknown
    "Tutg",  # 11390..113B5 ; Tulu_Tigalari
    "Zzzz",  # 113B6..113B6 ; Unknown
    "Tutg",  # 113B7..113C0 ; Tulu_Tigalari
    "Zzzz",  # 113C1..113C1 ; Unknown
    "Tutg",  # 113C2..113C2 ; Tulu_Tigalari
    "Zzzz",  # 113C3..113C4 ; Unknown
    "Tutg",  # 113C5..113C5 ; Tulu_Tigalari
    "Zzzz",  # 113C6..113C6 ; Unknown
    "Tutg",  # 113C7..113CA ; Tulu_Tigalari
    "Zzzz",  # 113CB..113CB ; Unknown
    "Tutg",  # 113CC..113D5 ; Tulu_Tigalari
    "Zzzz",  # 113D6..113D6 ; Unknown
    "Tutg",  # 113D7..113D8 ; Tulu_Tigalari
    "Zzzz",  # 113D9..113E0 ; Unknown
    "Tutg",  # 113E1..113E2 ; Tulu_Tigalari
    "Zzzz",  # 113E3..113FF ; Unknown
    "Newa",  # 11400..1145B ; Newa
    "Zzzz",  # 1145C..1145C ; Unknown
    "Newa",  # 1145D..11461 ; Newa
    "Zzzz",  # 11462..1147F ; Unknown
    "Tirh",  # 11480..114C7 ; Tirhuta
    "Zzzz",  # 114C8..114CF ; Unknown
    "Tirh",  # 114D0..114D9 ; Tirhuta
    "Zzzz",  # 114DA..1157F ; Unknown
    "Sidd",  # 11580..115B5 ; Siddham
    "Zzzz",  # 115B6..115B7 ; Unknown
    "Sidd",  # 115B8..115DD ; Siddham
    "Zzzz",  # 115DE..115FF ; Unknown
    "Modi",  # 11600..11644 ; Modi
    "Zzzz",  # 11645..1164F ; Unknown
    "Modi",  # 11650..11659 ; Modi
    "Zzzz",  # 1165A..1165F ; Unknown
    "Mong",  # 11660..1166C ; Mongolian
    "Zzzz",  # 1166D..1167F ; Unknown
    "Takr",  # 11680..116B9 ; Takri
    "Zzzz",  # 116BA..116BF ; Unknown
    "Takr",  # 116C0..116C9 ; Takri
    "Zzzz",  # 116CA..116CF ; Unknown
    "Mymr",  # 116D0..116E3 ; Myanmar
    "Zzzz",  # 116E4..116FF ; Unknown
    "Ahom",  # 11700..1171A ; Ahom
    "Zzzz",  # 1171B..1171C ; Unknown
    "Ahom",  # 1171D..1172B ; Ahom
    "Zzzz",  # 1172C..1172F ; Unknown
    "Ahom",  # 11730..11746 ; Ahom
    "Zzzz",  # 11747..117FF ; Unknown
    "Dogr",  # 11800..1183B ; Dogra
    "Zzzz",  # 1183C..1189F ; Unknown
    "Wara",  # 118A0..118F2 ; Warang_Citi
    "Zzzz",  # 118F3..118FE ; Unknown
    "Wara",  # 118FF..118FF ; Warang_Citi
    "Diak",  # 11900..11906 ; Dives_Akuru
    "Zzzz",  # 11907..11908 ; Unknown
    "Diak",  # 11909..11909 ; Dives_Akuru
    "Zzzz",  # 1190A..1190B ; Unknown
    "Diak",  # 1190C..11913 ; Dives_Akuru
    "Zzzz",  # 11914..11914 ; Unknown
    "Diak",  # 11915..11916 ; Dives_Akuru
    "Zzzz",  # 11917..11917 ; Unknown
    "Diak",  # 11918..11935 ; Dives_Akuru
    "Zzzz",  # 11936..11936 ; Unknown
    "Diak",  # 11937..11938 ; Dives_Akuru
    "Zzzz",  # 11939..1193A ; Unknown
    "Diak",  # 1193B..11946 ; Dives_Akuru
    "Zzzz",  # 11947..1194F ; Unknown
    "Diak",  # 11950..11959 ; Dives_Akuru
    "Zzzz",  # 1195A..1199F ; Unknown
    "Nand",  # 119A0..119A7 ; Nandinagari
    "Zzzz",  # 119A8..119A9 ; Unknown
    "Nand",  # 119AA..119D7 ; Nandinagari
    "Zzzz",  # 119D8..119D9 ; Unknown
    "Nand",  # 119DA..119E4 ; Nandinagari
    "Zzzz",  # 119E5..119FF ; Unknown
    "Zanb",  # 11A00..11A47 ; Zanabazar_Square
    "Zzzz",  # 11A48..11A4F ; Unknown
    "Soyo",  # 11A50..11AA2 ; Soyombo
    "Zzzz",  # 11AA3..11AAF ; Unknown
    "Cans",  # 11AB0..11ABF ; Canadian_Aboriginal
    "Pauc",  # 11AC0..11AF8 ; Pau_Cin_Hau
    "Zzzz",  # 11AF9..11AFF ; Unknown
    "Deva",  # 11B00..11B09 ; Devanagari
    "Zzzz",  # 11B0A..11B5F ; Unknown
    "Shrd",  # 11B60..11B67 ; Sharada
    "Zzzz",  # 11B68..11BBF ; Unknown
    "Sunu",  # 11BC0..11BE1 ; Sunuwar
    "Zzzz",  # 11BE2..11BEF ; Unknown
    "Sunu",  # 11BF0..11BF9 ; Sunuwar
    "Zzzz",  # 11BFA..11BFF ; Unknown
    "Bhks",  # 11C00..11C08 ; Bhaiksuki
    "Zzzz",  # 11C09..11C09 ; Unknown
    "Bhks",  # 11C0A..11C36 ; Bhaiksuki
    "Zzzz",  # 11C37..11C37 ; Unknown
    "Bhks",  # 11C38..11C45 ; Bhaiksuki
    "Zzzz",  # 11C46..11C4F ; Unknown
    "Bhks",  # 11C50..11C6C ; Bhaiksuki
    "Zzzz",  # 11C6D..11C6F ; Unknown
    "Marc",  # 11C70..11C8F ; Marchen
    "Zzzz",  # 11C90..11C91 ; Unknown
    "Marc",  # 11C92..11CA7 ; Marchen
    "Zzzz",  # 11CA8..11CA8 ; Unknown
    "Marc",  # 11CA9..11CB6 ; Marchen
    "Zzzz",  # 11CB7..11CFF ; Unknown
    "Gonm",  # 11D00..11D06 ; Masaram_Gondi
    "Zzzz",  # 11D07..11D07 ; Unknown
    "Gonm",  # 11D08..11D09 ; Masaram_Gondi
    "Zzzz",  # 11D0A..11D0A ; Unknown
    "Gonm",  # 11D0B..11D36 ; Masaram_Gondi
    "Zzzz",  # 11D37..11D39 ; Unknown
    "Gonm",  # 11D3A..11D3A ; Masaram_Gondi
    "Zzzz",  # 11D3B..11D3B ; Unknown
    "Gonm",  # 11D3C..11D3D ; Masaram_Gondi
    "Zzzz",  # 11D3E..11D3E ; Unknown
    "Gonm",  # 11D3F..11D47 ; Masaram_Gondi
    "Zzzz",  # 11D48..11D4F ; Unknown
    "Gonm",  # 11D50..11D59 ; Masaram_Gondi
    "Zzzz",  # 11D5A..11D5F ; Unknown
    "Gong",  # 11D60..11D65 ; Gunjala_Gondi
    "Zzzz",  # 11D66..11D66 ; Unknown
    "Gong",  # 11D67..11D68 ; Gunjala_Gondi
    "Zzzz",  # 11D69..11D69 ; Unknown
    "Gong",  # 11D6A..11D8E ; Gunjala_Gondi
    "Zzzz",  # 11D8F..11D8F ; Unknown
    "Gong",  # 11D90..11D91 ; Gunjala_Gondi
    "Zzzz",  # 11D92..11D92 ; Unknown
    "Gong",  # 11D93..11D98 ; Gunjala_Gondi
    "Zzzz",  # 11D99..11D9F ; Unknown
    "Gong",  # 11DA0..11DA9 ; Gunjala_Gondi
    "Zzzz",  # 11DAA..11DAF ; Unknown
    "Tols",  # 11DB0..11DDB ; Tolong_Siki
    "Zzzz",  # 11DDC..11DDF ; Unknown
    "Tols",  # 11DE0..11DE9 ; Tolong_Siki
    "Zzzz",  # 11DEA..11EDF ; Unknown
    "Maka",  # 11EE0..11EF8 ; Makasar
    "Zzzz",  # 11EF9..11EFF ; Unknown
    "Kawi",  # 11F00..11F10 ; Kawi
    "Zzzz",  # 11F11..11F11 ; Unknown
    "Kawi",  # 11F12..11F3A ; Kawi
    "Zzzz",  # 11F3B..11F3D ; Unknown
    "Kawi",  # 11F3E..11F5A ; Kawi
    "Zzzz",  # 11F5B..11FAF ; Unknown
    "Lisu",  # 11FB0..11FB0 ; Lisu
    "Zzzz",  # 11FB1..11FBF ; Unknown
    "Taml",  # 11FC0..11FF1 ; Tamil
    "Zzzz",  # 11FF2..11FFE ; Unknown
    "Taml",  # 11FFF..11FFF ; Tamil
    "Xsux",  # 12000..12399 ; Cuneiform
    "Zzzz",  # 1239A..123FF ; Unknown
    "Xsux",  # 12400..1246E ; Cuneiform
    "Zzzz",  # 1246F..1246F ; Unknown
    "Xsux",  # 12470..12474 ; Cuneiform
    "Zzzz",  # 12475..1247F ; Unknown
    "Xsux",  # 12480..12543 ; Cuneiform
    "Zzzz",  # 12544..12F8F ; Unknown
    "Cpmn",  # 12F90..12FF2 ; Cypro_Minoan
    "Zzzz",  # 12FF3..12FFF ; Unknown
    "Egyp",  # 13000..13455 ; Egyptian_Hieroglyphs
    "Zzzz",  # 13456..1345F ; Unknown
    "Egyp",  # 13460..143FA ; Egyptian_Hieroglyphs
    "Zzzz",  # 143FB..143FF ; Unknown
    "Hluw",  # 14400..14646 ; Anatolian_Hieroglyphs
    "Zzzz",  # 14647..160FF ; Unknown
    "Gukh",  # 16100..16139 ; Gurung_Khema
    "Zzzz",  # 1613A..167FF ; Unknown
    "Bamu",  # 16800..16A38 ; Bamum
    "Zzzz",  # 16A39..16A3F ; Unknown
    "Mroo",  # 16A40..16A5E ; Mro
    "Zzzz",  # 16A5F..16A5F ; Unknown
    "Mroo",  # 16A60..16A69 ; Mro
    "Zzzz",  # 16A6A..16A6D ; Unknown
    "Mroo",  # 16A6E..16A6F ; Mro
    "Tnsa",  # 16A70..16ABE ; Tangsa
    "Zzzz",  # 16ABF..16ABF ; Unknown
    "Tnsa",  # 16AC0..16AC9 ; Tangsa
    "Zzzz",  # 16ACA..16ACF ; Unknown
    "Bass",  # 16AD0..16AED ; Bassa_Vah
    "Zzzz",  # 16AEE..16AEF ; Unknown
    "Bass",  # 16AF0..16AF5 ; Bassa_Vah
    "Zzzz",  # 16AF6..16AFF ; Unknown
    "Hmng",  # 16B00..16B45 ; Pahawh_Hmong
    "Zzzz",  # 16B46..16B4F ; Unknown
    "Hmng",  # 16B50..16B59 ; Pahawh_Hmong
    "Zzzz",  # 16B5A..16B5A ; Unknown
    "Hmng",  # 16B5B..16B61 ; Pahawh_Hmong
    "Zzzz",  # 16B62..16B62 ; Unknown
    "Hmng",  # 16B63..16B77 ; Pahawh_Hmong
    "Zzzz",  # 16B78..16B7C ; Unknown
    "Hmng",  # 16B7D..16B8F ; Pahawh_Hmong
    "Zzzz",  # 16B90..16D3F ; Unknown
    "Krai",  # 16D40..16D79 ; Kirat_Rai
    "Zzzz",  # 16D7A..16E3F ; Unknown
    "Medf",  # 16E40..16E9A ; Medefaidrin
    "Zzzz",  # 16E9B..16E9F ; Unknown
    "Berf",  # 16EA0..16EB8 ; Beria_Erfe
    "Zzzz",  # 16EB9..16EBA ; Unknown
    "Berf",  # 16EBB..16ED3 ; Beria_Erfe
    "Zzzz",  # 16ED4..16EFF ; Unknown
    "Plrd",  # 16F00..16F4A ; Miao
    "Zzzz",  # 16F4B..16F4E ; Unknown
    "Plrd",  # 16F4F..16F87 ; Miao
    "Zzzz",  # 16F88..16F8E ; Unknown
    "Plrd",  # 16F8F..16F9F ; Miao
    "Zzzz",  # 16FA0..16FDF ; Unknown
    "Tang",  # 16FE0..16FE0 ; Tangut
    "Nshu",  # 16FE1..16FE1 ; Nushu
    "Hani",  # 16FE2..16FE3 ; Han
    "Kits",  # 16FE4..16FE4 ; Khitan_Small_Script
    "Zzzz",  # 16FE5..16FEF ; Unknown
    "Hani",  # 16FF0..16FF6 ; Han
    "Zzzz",  # 16FF7..16FFF ; Unknown
    "Tang",  # 17000..18AFF ; Tangut
    "Kits",  # 18B00..18CD5 ; Khitan_Small_Script
    "Zzzz",  # 18CD6..18CFE ; Unknown
    "Kits",  # 18CFF..18CFF ; Khitan_Small_Script
    "Tang",  # 18D00..18D1E ; Tangut
    "Zzzz",  # 18D1F..18D7F ; Unknown
    "Tang",  # 18D80..18DF2 ; Tangut
    "Zzzz",  # 18DF3..1AFEF ; Unknown
    "Kana",  # 1AFF0..1AFF3 ; Katakana
    "Zzzz",  # 1AFF4..1AFF4 ; Unknown
    "Kana",  # 1AFF5..1AFFB ; Katakana
    "Zzzz",  # 1AFFC..1AFFC ; Unknown
    "Kana",  # 1AFFD..1AFFE ; Katakana
    "Zzzz",  # 1AFFF..1AFFF ; Unknown
    "Kana",  # 1B000..1B000 ; Katakana
    "Hira",  # 1B001..1B11F ; Hiragana
    "Kana",  # 1B120..1B122 ; Katakana
    "Zzzz",  # 1B123..1B131 ; Unknown
    "Hira",  # 1B132..1B132 ; Hiragana
    "Zzzz",  # 1B133..1B14F ; Unknown
    "Hira",  # 1B150..1B152 ; Hiragana
    "Zzzz",  # 1B153..1B154 ; Unknown
    "Kana",  # 1B155..1B155 ; Katakana
    "Zzzz",  # 1B156..1B163 ; Unknown
    "Kana",  # 1B164..1B167 ; Katakana
    "Zzzz",  # 1B168..1B16F ; Unknown
    "Nshu",  # 1B170..1B2FB ; Nushu
    "Zzzz",  # 1B2FC..1BBFF ; Unknown
    "Dupl",  # 1BC00..1BC6A ; Duployan
    "Zzzz",  # 1BC6B..1BC6F ; Unknown
    "Dupl",  # 1BC70..1BC7C ; Duployan
    "Zzzz",  # 1BC7D..1BC7F ; Unknown
    "Dupl",  # 1BC80..1BC88 ; Duployan
    "Zzzz",  # 1BC89..1BC8F ; Unknown
    "Dupl",  # 1BC90..1BC99 ; Duployan
    "Zzzz",  # 1BC9A..1BC9B ; Unknown
    "Dupl",  # 1BC9C..1BC9F ; Duployan
    "Zyyy",  # 1BCA0..1BCA3 ; Common
    "Zzzz",  # 1BCA4..1CBFF ; Unknown
    "Zyyy",  # 1CC00..1CCFC ; Common
    "Zzzz",  # 1CCFD..1CCFF ; Unknown
    "Zyyy",  # 1CD00..1CEB3 ; Common
    "Zzzz",  # 1CEB4..1CEB9 ; Unknown
    "Zyyy",  # 1CEBA..1CED0 ; Common
    "Zzzz",  # 1CED1..1CEDF ; Unknown
    "Zyyy",  # 1CEE0..1CEF0 ; Common
    "Zzzz",  # 1CEF1..1CEFF ; Unknown
    "Zinh",  # 1CF00..1CF2D ; Inherited
    "Zzzz",  # 1CF2E..1CF2F ; Unknown
    "Zinh",  # 1CF30..1CF46 ; Inherited
    "Zzzz",  # 1CF47..1CF4F ; Unknown
    "Zyyy",  # 1CF50..1CFC3 ; Common
    "Zzzz",  # 1CFC4..1CFFF ; Unknown
    "Zyyy",  # 1D000..1D0F5 ; Common
    "Zzzz",  # 1D0F6..1D0FF ; Unknown
    "Zyyy",  # 1D100..1D126 ; Common
    "Zzzz",  # 1D127..1D128 ; Unknown
    "Zyyy",  # 1D129..1D166 ; Common
    "Zinh",  # 1D167..1D169 ; Inherited
    "Zyyy",  # 1D16A..1D17A ; Common
    "Zinh",  # 1D17B..1D182 ; Inherited
    "Zyyy",  # 1D183..1D184 ; Common
    "Zinh",  # 1D185..1D18B ; Inherited
    "Zyyy",  # 1D18C..1D1A9 ; Common
    "Zinh",  # 1D1AA..1D1AD ; Inherited
    "Zyyy",  # 1D1AE..1D1EA ; Common
    "Zzzz",  # 1D1EB..1D1FF ; Unknown
    "Grek",  # 1D200..1D245 ; Greek
    "Zzzz",  # 1D246..1D2BF ; Unknown
    "Zyyy",  # 1D2C0..1D2D3 ; Common
    "Zzzz",  # 1D2D4..1D2DF ; Unknown
    "Zyyy",  # 1D2E0..1D2F3 ; Common
    "Zzzz",  # 1D2F4..1D2FF ; Unknown
    "Zyyy",  # 1D300..1D356 ; Common
    "Zzzz",  # 1D357..1D35F ; Unknown
    "Zyyy",  # 1D360..1D378 ; Common
    "Zzzz",  # 1D379..1D3FF ; Unknown
    "Zyyy",  # 1D400..1D454 ; Common
    "Zzzz",  # 1D455..1D455 ; Unknown
    "Zyyy",  # 1D456..1D49C ; Common
    "Zzzz",  # 1D49D..1D49D ; Unknown
    "Zyyy",  # 1D49E..1D49F ; Common
    "Zzzz",  # 1D4A0..1D4A1 ; Unknown
    "Zyyy",  # 1D4A2..1D4A2 ; Common
    "Zzzz",  # 1D4A3..1D4A4 ; Unknown
    "Zyyy",  # 1D4A5..1D4A6 ; Common
    "Zzzz",  # 1D4A7..1D4A8 ; Unknown
    "Zyyy",  # 1D4A9..1D4AC ; Common
    "Zzzz",  # 1D4AD..1D4AD ; Unknown
    "Zyyy",  # 1D4AE..1D4B9 ; Common
    "Zzzz",  # 1D4BA..1D4BA ; Unknown
    "Zyyy",  # 1D4BB..1D4BB ; Common
    "Zzzz",  # 1D4BC..1D4BC ; Unknown
    "Zyyy",  # 1D4BD..1D4C3 ; Common
    "Zzzz",  # 1D4C4..1D4C4 ; Unknown
    "Zyyy",  # 1D4C5..1D505 ; Common
    "Zzzz",  # 1D506..1D506 ; Unknown
    "Zyyy",  # 1D507..1D50A ; Common
    "Zzzz",  # 1D50B..1D50C ; Unknown
    "Zyyy",  # 1D50D..1D514 ; Common
    "Zzzz",  # 1D515..1D515 ; Unknown
    "Zyyy",  # 1D516..1D51C ; Common
    "Zzzz",  # 1D51D..1D51D ; Unknown
    "Zyyy",  # 1D51E..1D539 ; Common
    "Zzzz",  # 1D53A..1D53A ; Unknown
    "Zyyy",  # 1D53B..1D53E ; Common
    "Zzzz",  # 1D53F..1D53F ; Unknown
    "Zyyy",  # 1D540..1D544 ; Common
    "Zzzz",  # 1D545..1D545 ; Unknown
    "Zyyy",  # 1D546..1D546 ; Common
    "Zzzz",  # 1D547..1D549 ; Unknown
    "Zyyy",  # 1D54A..1D550 ; Common
    "Zzzz",  # 1D551..1D551 ; Unknown
    "Zyyy",  # 1D552..1D6A5 ; Common
    "Zzzz",  # 1D6A6..1D6A7 ; Unknown
    "Zyyy",  # 1D6A8..1D7CB ; Common
    "Zzzz",  # 1D7CC..1D7CD ; Unknown
    "Zyyy",  # 1D7CE..1D7FF ; Common
    "Sgnw",  # 1D800..1DA8B ; SignWriting
    "Zzzz",  # 1DA8C..1DA9A ; Unknown
    "Sgnw",  # 1DA9B..1DA9F ; SignWriting
    "Zzzz",  # 1DAA0..1DAA0 ; Unknown
    "Sgnw",  # 1DAA1..1DAAF ; SignWriting
    "Zzzz",  # 1DAB0..1DEFF ; Unknown
    "Latn",  # 1DF00..1DF1E ; Latin
    "Zzzz",  # 1DF1F..1DF24 ; Unknown
    "Latn",  # 1DF25..1DF2A ; Latin
    "Zzzz",  # 1DF2B..1DFFF ; Unknown
    "Glag",  # 1E000..1E006 ; Glagolitic
    "Zzzz",  # 1E007..1E007 ; Unknown
    "Glag",  # 1E008..1E018 ; Glagolitic
    "Zzzz",  # 1E019..1E01A ; Unknown
    "Glag",  # 1E01B..1E021 ; Glagolitic
    "Zzzz",  # 1E022..1E022 ; Unknown
    "Glag",  # 1E023..1E024 ; Glagolitic
    "Zzzz",  # 1E025..1E025 ; Unknown
    "Glag",  # 1E026..1E02A ; Glagolitic
    "Zzzz",  # 1E02B..1E02F ; Unknown
    "Cyrl",  # 1E030..1E06D ; Cyrillic
    "Zzzz",  # 1E06E..1E08E ; Unknown
    "Cyrl",  # 1E08F..1E08F ; Cyrillic
    "Zzzz",  # 1E090..1E0FF ; Unknown
    "Hmnp",  # 1E100..1E12C ; Nyiakeng_Puachue_Hmong
    "Zzzz",  # 1E12D..1E12F ; Unknown
    "Hmnp",  # 1E130..1E13D ; Nyiakeng_Puachue_Hmong
    "Zzzz",  # 1E13E..1E13F ; Unknown
    "Hmnp",  # 1E140..1E149 ; Nyiakeng_Puachue_Hmong
    "Zzzz",  # 1E14A..1E14D ; Unknown
    "Hmnp",  # 1E14E..1E14F ; Nyiakeng_Puachue_Hmong
    "Zzzz",  # 1E150..1E28F ; Unknown
    "Toto",  # 1E290..1E2AE ; Toto
    "Zzzz",  # 1E2AF..1E2BF ; Unknown
    "Wcho",  # 1E2C0..1E2F9 ; Wancho
    "Zzzz",  # 1E2FA..1E2FE ; Unknown
    "Wcho",  # 1E2FF..1E2FF ; Wancho
    "Zzzz",  # 1E300..1E4CF ; Unknown
    "Nagm",  # 1E4D0..1E4F9 ; Nag_Mundari
    "Zzzz",  # 1E4FA..1E5CF ; Unknown
    "Onao",  # 1E5D0..1E5FA ; Ol_Onal
    "Zzzz",  # 1E5FB..1E5FE ; Unknown
    "Onao",  # 1E5FF..1E5FF ; Ol_Onal
    "Zzzz",  # 1E600..1E6BF ; Unknown
    "Tayo",  # 1E6C0..1E6DE ; Tai_Yo
    "Zzzz",  # 1E6DF..1E6DF ; Unknown
    "Tayo",  # 1E6E0..1E6F5 ; Tai_Yo
    "Zzzz",  # 1E6F6..1E6FD ; Unknown
    "Tayo",  # 1E6FE..1E6FF ; Tai_Yo
    "Zzzz",  # 1E700..1E7DF ; Unknown
    "Ethi",  # 1E7E0..1E7E6 ; Ethiopic
    "Zzzz",  # 1E7E7..1E7E7 ; Unknown
    "Ethi",  # 1E7E8..1E7EB ; Ethiopic
    "Zzzz",  # 1E7EC..1E7EC ; Unknown
    "Ethi",  # 1E7ED..1E7EE ; Ethiopic
    "Zzzz",  # 1E7EF..1E7EF ; Unknown
    "Ethi",  # 1E7F0..1E7FE ; Ethiopic
    "Zzzz",  # 1E7FF..1E7FF ; Unknown
    "Mend",  # 1E800..1E8C4 ; Mende_Kikakui
    "Zzzz",  # 1E8C5..1E8C6 ; Unknown
    "Mend",  # 1E8C7..1E8D6 ; Mende_Kikakui
    "Zzzz",  # 1E8D7..1E8FF ; Unknown
    "Adlm",  # 1E900..1E94B ; Adlam
    "Zzzz",  # 1E94C..1E94F ; Unknown
    "Adlm",  # 1E950..1E959 ; Adlam
    "Zzzz",  # 1E95A..1E95D ; Unknown
    "Adlm",  # 1E95E..1E95F ; Adlam
    "Zzzz",  # 1E960..1EC70 ; Unknown
    "Zyyy",  # 1EC71..1ECB4 ; Common
    "Zzzz",  # 1ECB5..1ED00 ; Unknown
    "Zyyy",  # 1ED01..1ED3D ; Common
    "Zzzz",  # 1ED3E..1EDFF ; Unknown
    "Arab",  # 1EE00..1EE03 ; Arabic
    "Zzzz",  # 1EE04..1EE04 ; Unknown
    "Arab",  # 1EE05..1EE1F ; Arabic
    "Zzzz",  # 1EE20..1EE20 ; Unknown
    "Arab",  # 1EE21..1EE22 ; Arabic
    "Zzzz",  # 1EE23..1EE23 ; Unknown
    "Arab",  # 1EE24..1EE24 ; Arabic
    "Zzzz",  # 1EE25..1EE26 ; Unknown
    "Arab",  # 1EE27..1EE27 ; Arabic
    "Zzzz",  # 1EE28..1EE28 ; Unknown
    "Arab",  # 1EE29..1EE32 ; Arabic
    "Zzzz",  # 1EE33..1EE33 ; Unknown
    "Arab",  # 1EE34..1EE37 ; Arabic
    "Zzzz",  # 1EE38..1EE38 ; Unknown
    "Arab",  # 1EE39..1EE39 ; Arabic
    "Zzzz",  # 1EE3A..1EE3A ; Unknown
    "Arab",  # 1EE3B..1EE3B ; Arabic
    "Zzzz",  # 1EE3C..1EE41 ; Unknown
    "Arab",  # 1EE42..1EE42 ; Arabic
    "Zzzz",  # 1EE43..1EE46 ; Unknown
    "Arab",  # 1EE47..1EE47 ; Arabic
    "Zzzz",  # 1EE48..1EE48 ; Unknown
    "Arab",  # 1EE49..1EE49 ; Arabic
    "Zzzz",  # 1EE4A..1EE4A ; Unknown
    "Arab",  # 1EE4B..1EE4B ; Arabic
    "Zzzz",  # 1EE4C..1EE4C ; Unknown
    "Arab",  # 1EE4D..1EE4F ; Arabic
    "Zzzz",  # 1EE50..1EE50 ; Unknown
    "Arab",  # 1EE51..1EE52 ; Arabic
    "Zzzz",  # 1EE53..1EE53 ; Unknown
    "Arab",  # 1EE54..1EE54 ; Arabic
    "Zzzz",  # 1EE55..1EE56 ; Unknown
    "Arab",  # 1EE57..1EE57 ; Arabic
    "Zzzz",  # 1EE58..1EE58 ; Unknown
    "Arab",  # 1EE59..1EE59 ; Arabic
    "Zzzz",  # 1EE5A..1EE5A ; Unknown
    "Arab",  # 1EE5B..1EE5B ; Arabic
    "Zzzz",  # 1EE5C..1EE5C ; Unknown
    "Arab",  # 1EE5D..1EE5D ; Arabic
    "Zzzz",  # 1EE5E..1EE5E ; Unknown
    "Arab",  # 1EE5F..1EE5F ; Arabic
    "Zzzz",  # 1EE60..1EE60 ; Unknown
    "Arab",  # 1EE61..1EE62 ; Arabic
    "Zzzz",  # 1EE63..1EE63 ; Unknown
    "Arab",  # 1EE64..1EE64 ; Arabic
    "Zzzz",  # 1EE65..1EE66 ; Unknown
    "Arab",  # 1EE67..1EE6A ; Arabic
    "Zzzz",  # 1EE6B..1EE6B ; Unknown
    "Arab",  # 1EE6C..1EE72 ; Arabic
    "Zzzz",  # 1EE73..1EE73 ; Unknown
    "Arab",  # 1EE74..1EE77 ; Arabic
    "Zzzz",  # 1EE78..1EE78 ; Unknown
    "Arab",  # 1EE79..1EE7C ; Arabic
    "Zzzz",  # 1EE7D..1EE7D ; Unknown
    "Arab",  # 1EE7E..1EE7E ; Arabic
    "Zzzz",  # 1EE7F..1EE7F ; Unknown
    "Arab",  # 1EE80..1EE89 ; Arabic
    "Zzzz",  # 1EE8A..1EE8A ; Unknown
    "Arab",  # 1EE8B..1EE9B ; Arabic
    "Zzzz",  # 1EE9C..1EEA0 ; Unknown
    "Arab",  # 1EEA1..1EEA3 ; Arabic
    "Zzzz",  # 1EEA4..1EEA4 ; Unknown
    "Arab",  # 1EEA5..1EEA9 ; Arabic
    "Zzzz",  # 1EEAA..1EEAA ; Unknown
    "Arab",  # 1EEAB..1EEBB ; Arabic
    "Zzzz",  # 1EEBC..1EEEF ; Unknown
    "Arab",  # 1EEF0..1EEF1 ; Arabic
    "Zzzz",  # 1EEF2..1EFFF ; Unknown
    "Zyyy",  # 1F000..1F02B ; Common
    "Zzzz",  # 1F02C..1F02F ; Unknown
    "Zyyy",  # 1F030..1F093 ; Common
    "Zzzz",  # 1F094..1F09F ; Unknown
    "Zyyy",  # 1F0A0..1F0AE ; Common
    "Zzzz",  # 1F0AF..1F0B0 ; Unknown
    "Zyyy",  # 1F0B1..1F0BF ; Common
    "Zzzz",  # 1F0C0..1F0C0 ; Unknown
    "Zyyy",  # 1F0C1..1F0CF ; Common
    "Zzzz",  # 1F0D0..1F0D0 ; Unknown
    "Zyyy",  # 1F0D1..1F0F5 ; Common
    "Zzzz",  # 1F0F6..1F0FF ; Unknown
    "Zyyy",  # 1F100..1F1AD ; Common
    "Zzzz",  # 1F1AE..1F1E5 ; Unknown
    "Zyyy",  # 1F1E6..1F1FF ; Common
    "Hira",  # 1F200..1F200 ; Hiragana
    "Zyyy",  # 1F201..1F202 ; Common
    "Zzzz",  # 1F203..1F20F ; Unknown
    "Zyyy",  # 1F210..1F23B ; Common
    "Zzzz",  # 1F23C..1F23F ; Unknown
    "Zyyy",  # 1F240..1F248 ; Common
    "Zzzz",  # 1F249..1F24F ; Unknown
    "Zyyy",  # 1F250..1F251 ; Common
    "Zzzz",  # 1F252..1F25F ; Unknown
    "Zyyy",  # 1F260..1F265 ; Common
    "Zzzz",  # 1F266..1F2FF ; Unknown
    "Zyyy",  # 1F300..1F6D8 ; Common
    "Zzzz",  # 1F6D9..1F6DB ; Unknown
    "Zyyy",  # 1F6DC..1F6EC ; Common
    "Zzzz",  # 1F6ED..1F6EF ; Unknown
    "Zyyy",  # 1F6F0..1F6FC ; Common
    "Zzzz",  # 1F6FD..1F6FF ; Unknown
    "Zyyy",  # 1F700..1F7D9 ; Common
    "Zzzz",  # 1F7DA..1F7DF ; Unknown
    "Zyyy",  # 1F7E0..1F7EB ; Common
    "Zzzz",  # 1F7EC..1F7EF ; Unknown
    "Zyyy",  # 1F7F0..1F7F0 ; Common
    "Zzzz",  # 1F7F1..1F7FF ; Unknown
    "Zyyy",  # 1F800..1F80B ; Common
    "Zzzz",  # 1F80C..1F80F ; Unknown
    "Zyyy",  # 1F810..1F847 ; Common
    "Zzzz",  # 1F848..1F84F ; Unknown
    "Zyyy",  # 1F850..1F859 ; Common
    "Zzzz",  # 1F85A..1F85F ; Unknown
    "Zyyy",  # 1F860..1F887 ; Common
    "Zzzz",  # 1F888..1F88F ; Unknown
    "Zyyy",  # 1F890..1F8AD ; Common
    "Zzzz",  # 1F8AE..1F8AF ; Unknown
    "Zyyy",  # 1F8B0..1F8BB ; Common
    "Zzzz",  # 1F8BC..1F8BF ; Unknown
    "Zyyy",  # 1F8C0..1F8C1 ; Common
    "Zzzz",  # 1F8C2..1F8CF ; Unknown
    "Zyyy",  # 1F8D0..1F8D8 ; Common
    "Zzzz",  # 1F8D9..1F8FF ; Unknown
    "Zyyy",  # 1F900..1FA57 ; Common
    "Zzzz",  # 1FA58..1FA5F ; Unknown
    "Zyyy",  # 1FA60..1FA6D ; Common
    "Zzzz",  # 1FA6E..1FA6F ; Unknown
    "Zyyy",  # 1FA70..1FA7C ; Common
    "Zzzz",  # 1FA7D..1FA7F ; Unknown
    "Zyyy",  # 1FA80..1FA8A ; Common
    "Zzzz",  # 1FA8B..1FA8D ; Unknown
    "Zyyy",  # 1FA8E..1FAC6 ; Common
    "Zzzz",  # 1FAC7..1FAC7 ; Unknown
    "Zyyy",  # 1FAC8..1FAC8 ; Common
    "Zzzz",  # 1FAC9..1FACC ; Unknown
    "Zyyy",  # 1FACD..1FADC ; Common
    "Zzzz",  # 1FADD..1FADE ; Unknown
    "Zyyy",  # 1FADF..1FAEA ; Common
    "Zzzz",  # 1FAEB..1FAEE ; Unknown
    "Zyyy",  # 1FAEF..1FAF8 ; Common
    "Zzzz",  # 1FAF9..1FAFF ; Unknown
    "Zyyy",  # 1FB00..1FB92 ; Common
    "Zzzz",  # 1FB93..1FB93 ; Unknown
    "Zyyy",  # 1FB94..1FBFA ; Common
    "Zzzz",  # 1FBFB..1FFFF ; Unknown
    "Hani",  # 20000..2A6DF ; Han
    "Zzzz",  # 2A6E0..2A6FF ; Unknown
    "Hani",  # 2A700..2B81D ; Han
    "Zzzz",  # 2B81E..2B81F ; Unknown
    "Hani",  # 2B820..2CEAD ; Han
    "Zzzz",  # 2CEAE..2CEAF ; Unknown
    "Hani",  # 2CEB0..2EBE0 ; Han
    "Zzzz",  # 2EBE1..2EBEF ; Unknown
    "Hani",  # 2EBF0..2EE5D ; Han
    "Zzzz",  # 2EE5E..2F7FF ; Unknown
    "Hani",  # 2F800..2FA1D ; Han
    "Zzzz",  # 2FA1E..2FFFF ; Unknown
    "Hani",  # 30000..3134A ; Han
    "Zzzz",  # 3134B..3134F ; Unknown
    "Hani",  # 31350..33479 ; Han
    "Zzzz",  # 3347A..E0000 ; Unknown
    "Zyyy",  # E0001..E0001 ; Common
    "Zzzz",  # E0002..E001F ; Unknown
    "Zyyy",  # E0020..E007F ; Common
    "Zzzz",  # E0080..E00FF ; Unknown
    "Zinh",  # E0100..E01EF ; Inherited
    "Zzzz",  # E01F0..10FFFF ; Unknown
]

NAMES = {
    "Adlm": "Adlam",
    "Aghb": "Caucasian_Albanian",
    "Ahom": "Ahom",
    "Arab": "Arabic",
    "Armi": "Imperial_Aramaic",
    "Armn": "Armenian",
    "Avst": "Avestan",
    "Bali": "Balinese",
    "Bamu": "Bamum",
    "Bass": "Bassa_Vah",
    "Batk": "Batak",
    "Beng": "Bengali",
    "Berf": "Beria_Erfe",
    "Bhks": "Bhaiksuki",
    "Bopo": "Bopomofo",
    "Brah": "Brahmi",
    "Brai": "Braille",
    "Bugi": "Buginese",
    "Buhd": "Buhid",
    "Cakm": "Chakma",
    "Cans": "Canadian_Aboriginal",
    "Cari": "Carian",
    "Cham": "Cham",
    "Cher": "Cherokee",
    "Chrs": "Chorasmian",
    "Copt": "Coptic",
    "Cpmn": "Cypro_Minoan",
    "Cprt": "Cypriot",
    "Cyrl": "Cyrillic",
    "Deva": "Devanagari",
    "Diak": "Dives_Akuru",
    "Dogr": "Dogra",
    "Dsrt": "Deseret",
    "Dupl": "Duployan",
    "Egyp": "Egyptian_Hieroglyphs",
    "Elba": "Elbasan",
    "Elym": "Elymaic",
    "Ethi": "Ethiopic",
    "Gara": "Garay",
    "Geor": "Georgian",
    "Glag": "Glagolitic",
    "Gong": "Gunjala_Gondi",
    "Gonm": "Masaram_Gondi",
    "Goth": "Gothic",
    "Gran": "Grantha",
    "Grek": "Greek",
    "Gujr": "Gujarati",
    "Gukh": "Gurung_Khema",
    "Guru": "Gurmukhi",
    "Hang": "Hangul",
    "Hani": "Han",
    "Hano": "Hanunoo",
    "Hatr": "Hatran",
    "Hebr": "Hebrew",
    "Hira": "Hiragana",
    "Hluw": "Anatolian_Hieroglyphs",
    "Hmng": "Pahawh_Hmong",
    "Hmnp": "Nyiakeng_Puachue_Hmong",
    "Hrkt": "Katakana_Or_Hiragana",
    "Hung": "Old_Hungarian",
    "Ital": "Old_Italic",
    "Java": "Javanese",
    "Kali": "Kayah_Li",
    "Kana": "Katakana",
    "Kawi": "Kawi",
    "Khar": "Kharoshthi",
    "Khmr": "Khmer",
    "Khoj": "Khojki",
    "Kits": "Khitan_Small_Script",
    "Knda": "Kannada",
    "Krai": "Kirat_Rai",
    "Kthi": "Kaithi",
    "Lana": "Tai_Tham",
    "Laoo": "Lao",
    "Latn": "Latin",
    "Lepc": "Lepcha",
    "Limb": "Limbu",
    "Lina": "Linear_A",
    "Linb": "Linear_B",
    "Lisu": "Lisu",
    "Lyci": "Lycian",
    "Lydi": "Lydian",
    "Mahj": "Mahajani",
    "Maka": "Makasar",
    "Mand": "Mandaic",
    "Mani": "Manichaean",
    "Marc": "Marchen",
    "Medf": "Medefaidrin",
    "Mend": "Mende_Kikakui",
    "Merc": "Meroitic_Cursive",
    "Mero": "Meroitic_Hieroglyphs",
    "Mlym": "Malayalam",
    "Modi": "Modi",
    "Mong": "Mongolian",
    "Mroo": "Mro",
    "Mtei": "Meetei_Mayek",
    "Mult": "Multani",
    "Mymr": "Myanmar",
    "Nagm": "Nag_Mundari",
    "Nand": "Nandinagari",
    "Narb": "Old_North_Arabian",
    "Nbat": "Nabataean",
    "Newa": "Newa",
    "Nkoo": "Nko",
    "Nshu": "Nushu",
    "Ogam": "Ogham",
    "Olck": "Ol_Chiki",
    "Onao": "Ol_Onal",
    "Orkh": "Old_Turkic",
    "Orya": "Oriya",
    "Osge": "Osage",
    "Osma": "Osmanya",
    "Ougr": "Old_Uyghur",
    "Palm": "Palmyrene",
    "Pauc": "Pau_Cin_Hau",
    "Perm": "Old_Permic",
    "Phag": "Phags_Pa",
    "Phli": "Inscriptional_Pahlavi",
    "Phlp": "Psalter_Pahlavi",
    "Phnx": "Phoenician",
    "Plrd": "Miao",
    "Prti": "Inscriptional_Parthian",
    "Rjng": "Rejang",
    "Rohg": "Hanifi_Rohingya",
    "Runr": "Runic",
    "Samr": "Samaritan",
    "Sarb": "Old_South_Arabian",
    "Saur": "Saurashtra",
    "Sgnw": "SignWriting",
    "Shaw": "Shavian",
    "Shrd": "Sharada",
    "Sidd": "Siddham",
    "Sidt": "Sidetic",
    "Sind": "Khudawadi",
    "Sinh": "Sinhala",
    "Sogd": "Sogdian",
    "Sogo": "Old_Sogdian",
    "Sora": "Sora_Sompeng",
    "Soyo": "Soyombo",
    "Sund": "Sundanese",
    "Sunu": "Sunuwar",
    "Sylo": "Syloti_Nagri",
    "Syrc": "Syriac",
    "Tagb": "Tagbanwa",
    "Takr": "Takri",
    "Tale": "Tai_Le",
    "Talu": "New_Tai_Lue",
    "Taml": "Tamil",
    "Tang": "Tangut",
    "Tavt": "Tai_Viet",
    "Tayo": "Tai_Yo",
    "Telu": "Telugu",
    "Tfng": "Tifinagh",
    "Tglg": "Tagalog",
    "Thaa": "Thaana",
    "Thai": "Thai",
    "Tibt": "Tibetan",
    "Tirh": "Tirhuta",
    "Tnsa": "Tangsa",
    "Todr": "Todhri",
    "Tols": "Tolong_Siki",
    "Toto": "Toto",
    "Tutg": "Tulu_Tigalari",
    "Ugar": "Ugaritic",
    "Vaii": "Vai",
    "Vith": "Vithkuqi",
    "Wara": "Warang_Citi",
    "Wcho": "Wancho",
    "Xpeo": "Old_Persian",
    "Xsux": "Cuneiform",
    "Yezi": "Yezidi",
    "Yiii": "Yi",
    "Zanb": "Zanabazar_Square",
    "Zinh": "Inherited",
    "Zyyy": "Common",
    "Zzzz": "Unknown",
}
